/**************************************************************************
 |                                                                         
 |                    STATA SETUP FILE FOR ICPSR 02347
 |         WASHINGTON, DC, METROPOLITAN AREA DRUG STUDY(DC*MADS),
 |        1992: DRUG USE AMONG DC WOMEN DELIVERING LIVE BIRTHS IN
 |                              DC HOSPITALS
 |                      (DATASET 0001: INFANT DATA)
 |
 |
 |  Please edit this file as instructed below.
 |  To execute, start Stata, change to the directory containing:
 |       - this do file
 |       - the ASCII data file
 |       - the dictionary file
 |
 |  Then execute the do file (e.g., do 02347-0001-statasetup.do)
 |
 **************************************************************************/

set mem 7m  /* Allocating 7 megabyte(s) of RAM for Stata SE to read the
                 data file into memory. */


set more off  /* This prevents the Stata output viewer from pausing the
                 process */

/****************************************************

Section 1: File Specifications
   This section assigns local macros to the necessary files.
   Please edit:
        "data-filename" ==> The name of data file downloaded from ICPSR
        "dictionary-filename" ==> The name of the dictionary file downloaded.
        "stata-datafile" ==> The name you wish to call your Stata data file.

   Note:  We assume that the raw data, dictionary, and setup (this do file) all
          reside in the same directory (or folder).  If that is not the case
          you will need to include paths as well as filenames in the macros.

********************************************************/

local raw_data "data-filename"
local dict "dictionary-filename"
local outfile "stata-datafile"

/********************************************************

Section 2: Infile Command

This section reads the raw data into Stata format.  If Section 1 was defined
properly, there should be no reason to modify this section.  These macros
should inflate automatically.

**********************************************************/

infile using `dict', using (`raw_data') clear


/*********************************************************

Section 3: Value Label Definitions
This section defines labels for the individual values of each variable.
We suggest that users do not modify this section.

**********************************************************/


label data "Washington, DC, Metropolitan Area Drug Study(DC*MADS), 1992: Drug Use Among DC Women Delivering Live Births in DC Hospitals, Dataset 0001"

#delimit ;
label define PRIMARY   0 "Duplicate Case" 1 "Primary Case" ;
label define Q2_LB     -9 "LEGITIMATE SKIP" -8 "MISSING" ;
label define Q2_OZ     -9 "LEGITIMATE SKIP" -8 "MISSING" ;
label define Q2_GR     -9 "LEGITIMATE SKIP" ;
label define Q3_WK     -9 "LEGITIMATE SKIP" -8 "MISSING" -4 "DON'T KNOW" ;
label define SPANISH   1 "SPANISH INTERVIEW ADMINISTERED"
                       2 "ENGLISH INTERVIEW ADMINISTERED" ;
label define A_1       1 "YES" 2 "NO" 3 "EDITED YES" ;
label define XA_1A     -9 "LEGITIMATE SKIP" -8 "MISSING" -4 "DON'T KNOW" ;
label define A_1B      -9 "LEGITIMATE SKIP" -8 "MISSING" -4 "DON'T KNOW" ;
label define A_1C      -9 "LEGITIMATE SKIP" -6 "MULTIPLE RESPONSE"
                       1 "PRIVATE DOCTOR/NURSE-MIDWIFE" 2 "HMO"
                       3 "HOSPITAL OUTPATIENT CLINIC"
                       4 "COMMU/CITY HEALTH DEPT CLINIC" 5 "SHELTER CLINIC"
                       6 "CLINIC AT SCHOOL/WORK" 7 "PRISON/JAIL/CLINIC"
                       8 "MOBILE OUTREACH TEAM" 9 "MILITARY FACILITY"
                       10 "HOSPITAL EMERGENCY ROOM" 11 "OTHER" ;
label define A_1D_01   -9 "LEGITIMATE SKIP" -8 "MISSING" 0 "NOT CIRCLED"
                       1 "CIRCLED" ;
label define A_1D_02   -9 "LEGITIMATE SKIP" -8 "MISSING" 0 "NOT CIRCLED"
                       1 "CIRCLED" ;
label define A_1D_03   -9 "LEGITIMATE SKIP" -8 "MISSING" 0 "NOT CIRCLED"
                       1 "CIRCLED" ;
label define A_1D_04   -9 "LEGITIMATE SKIP" -8 "MISSING" 0 "NOT CIRCLED"
                       1 "CIRCLED" ;
label define A_1D_05   -9 "LEGITIMATE SKIP" -8 "MISSING" 0 "NOT CIRCLED"
                       1 "CIRCLED" ;
label define A_1D_06   -9 "LEGITIMATE SKIP" -8 "MISSING" 0 "NOT CIRCLED"
                       1 "CIRCLED" ;
label define A_1D_07   -9 "LEGITIMATE SKIP" -8 "MISSING" 0 "NOT CIRCLED"
                       1 "CIRCLED" ;
label define A_1D_08   -9 "LEGITIMATE SKIP" -8 "MISSING" 0 "NOT CIRCLED"
                       1 "CIRCLED" ;
label define XA_2      -999 "LEGITIMATE SKIP" -888 "MISSING"
                       -444 "DON'T KNOW" ;
label define XA_3      -8 "MISSING" -4 "DON'T KNOW" ;
label define A_4       -8 "MISSING" 1 "YES" 2 "NO" 3 "EDITED YES" ;
label define A4_A_1    -9 "LEGITIMATE SKIP" -8 "MISSING" -4 "DON'T KNOW"
                       1 "BIRTH CONTROL PILL" 2 "DIAPHRAGM" 3 "INJECTIONS"
                       4 "CONDOM" 5 "FOAM/JELLY, CREAM, SUPPOSITORY"
                       6 "IUD, COIL, LLP"
                       7 "FEMALE STERILIZATION-TUBES TIED/WOMB REMOVED"
                       8 "MALE STERILIZATION-VASECTOMY" 9 "OTHER" 10 "SPONGE"
                       11 "RHYTHM" ;
label define A4_A_2    -9 "LEGITIMATE SKIP" -8 "MISSING" -4 "DON'T KNOW"
                       1 "BIRTH CONTROL PILL" 2 "DIAPHRAGM" 3 "INJECTIONS"
                       4 "CONDOM" 5 "FOAM, JELLY, CREAM, SUPPOSITORY"
                       6 "IUD, COIL, LLP"
                       7 "FEMALE STERILIZATION-TUBES TIED/WOMB REMOVED"
                       8 "MALE STERILIZATION-VASECTOMY" 9 "OTHER" 10 "SPONGE"
                       11 "RHYTHM" ;
label define A_5       -8 "MISSING" -4 "DON'T KNOW" 1 "WANTED TO-THAT TIME"
                       2 "WANTED TO-LATER" 3 "WANTED TO-EARLIER"
                       4 "DIDN'T WANT TO GET PREGNANT" ;
label define A_6       -8 "MISSING" 1 "YES" 2 "NO" 3 "EDITED YES" ;
label define A_6A      -9 "LEGITIMATE SKIP" -8 "MISSING" 1 "YES" 2 "NO" ;
label define A_7_01    -8 "MISSING" 1 "YES" 2 "NO" ;
label define A_7_02    -8 "MISSING" -6 "MULTIPLE RESPONSE" 1 "YES" 2 "NO" ;
label define A_7_03    -8 "MISSING" -6 "MULTIPLE RESPONSE" 1 "YES" 2 "NO" ;
label define A_7_04    -8 "MISSING" -6 "MULTIPLE RESPONSE" 1 "YES" 2 "NO" ;
label define A_7_05    -8 "MISSING" 1 "YES" 2 "NO" ;
label define A_7_06    -8 "MISSING" 1 "YES" 2 "NO" ;
label define A_7_07    -8 "MISSING" 1 "YES" 2 "NO" ;
label define A_7_08    -8 "MISSING" 1 "YES" 2 "NO" ;
label define A_7_09    -8 "MISSING" 1 "YES" 2 "NO" ;
label define A_7_10    -8 "MISSING" 1 "YES" 2 "NO" ;
label define A_7_11    -8 "MISSING" 1 "YES" 2 "NO" ;
label define A_7_12    -8 "MISSING" 1 "YES" 2 "NO" ;
label define A_7_SP    -9 "LEGITIMATE SKIP" -8 "MISSING"
                       11 "ASTHMA OR BRONCHITIS" 12 "YEAST INFECTION"
                       13 "SINUS PROBLEM" 14 "BACK PROBLEMS"
                       15 "SICKLE CELL ANEMIA" 16 "PLACENTAL PROBLEMS"
                       17 "STD, UNSPECIFIED" 18 "OVARIAN CYSTS OR FIBROIDS"
                       19 "OTHER INFECTIONS" 20 "HEART OR BLOOD PROBLEMS"
                       21 "ULCER" 22 "HERNIA" 23 "RUPTURED UTERUS"
                       24 "SEIZURES" 25 "DEHYDRATION" 26 "OTHER" ;
label define A_8_1     -8 "MISSING" 1 "YES" 2 "NO" 3 "EDITED YES" ;
label define A_8A_1    -9 "LEGITIMATE SKIP" -8 "MISSING" 1 "YES" 2 "NO" ;
label define A_8_2     -8 "MISSING" -6 "MULTIPLE RESPONSE" 1 "YES" 2 "NO" ;
label define A_8A_2    -9 "LEGITIMATE SKIP" -8 "MISSING" 1 "YES" 2 "NO" ;
label define A_8_3     -8 "MISSING" 1 "YES" 2 "NO" ;
label define A_8A_3    -9 "LEGITIMATE SKIP" -8 "MISSING" 1 "YES" 2 "NO" ;
label define A_8_4     -8 "MISSING" 1 "YES" 2 "NO" ;
label define A_8A_4    -9 "LEGITIMATE SKIP" -8 "MISSING" 1 "YES" 2 "NO" ;
label define A_8_5     -8 "MISSING" 1 "YES" 2 "NO" ;
label define A_8A_5    -9 "LEGITIMATE SKIP" -8 "MISSING" 1 "YES" 2 "NO" ;
label define A_8_6     -8 "MISSING" 1 "YES" 2 "NO" ;
label define A_8A_6    -9 "LEGITIMATE SKIP" -8 "MISSING" -4 "DON'T KNOW"
                       1 "YES" 2 "NO" ;
label define A_8_SP    -9 "LEGITIMATE SKIP" -8 "MISSING" -4 "DON'T KNOW"
                       11 "TRICHOMONAS" 12 "YEAST INFECTION"
                       13 "GENITAL WARTS" ;
label define A_9       -8 "MISSING" 1 "YES" 2 "NO" 3 "EDITED YES" ;
label define A_9_SP    -9 "LEGITIMATE SKIP" -8 "MISSING" -4 "DON'T KNOW"
                       11 "AMINOGLYCOSIDES"
                       12 "CEPHALOSPORINS AND PENICILLINS"
                       13 "ERYTHROMYCINS AND TETRACYCLINES"
                       14 "ARYNAGINAL ANTIMICROBIALS" ;
label define A_10      -8 "MISSING" 1 "YES" 2 "NO" 3 "EDITED YES" ;
label define A_10_A    -9 "LEGITIMATE SKIP" -8 "MISSING" ;
label define A_11      -8 "MISSING" -4 "DON'T KNOW" ;
label define A_12      -8 "MISSING" -5 "DATA OUT OF RANGE" -4 "DON'T KNOW" ;
label define A_13_FT   -8 "MISSING" -4 "DON'T KNOW" ;
label define A_13_IN   -8 "MISSING" -4 "DON'T KNOW" ;
label define A_14      -8 "MISSING" ;
label define A_14_A    -9 "LEGITIMATE SKIP" -8 "MISSING" ;
label define A_14_C    -9 "LEGITIMATE SKIP" -8 "MISSING" 1 "YES" 2 "NO" ;
label define A_15_A    -9 "LEGITIMATE SKIP" -8 "MISSING" ;
label define A_15_B    -9 "LEGITIMATE SKIP" -8 "MISSING" ;
label define A_15_C    -9 "LEGITIMATE SKIP" -8 "MISSING"
                       -6 "MULTIPLE RESPONSE" ;
label define A_15_D    -9 "LEGITIMATE SKIP" -8 "MISSING" ;
label define A17A1_LB  -9 "LEGITIMATE SKIP" ;
label define A17A1_OZ  -9 "LEGITIMATE SKIP" -8 "MISSING" -4 "DON'T KNOW" ;
label define XA17A1    -9 "LEGITIMATE SKIP" -8 "MISSING" -7 "ITEM REFUSAL"
                       -5 "DATA OUT OF RANGE" ;
label define A17A1_MF  -9 "LEGITIMATE SKIP" -8 "MISSING" 1 "MALE" 2 "FEMALE" ;
label define A17A1_YN  -9 "LEGITIMATE SKIP" -8 "MISSING" 1 "YES" 2 "NO" ;
label define A17A2_LB  -9 "LEGITIMATE SKIP" -4 "DON'T KNOW" ;
label define A17A2_OZ  -9 "LEGITIMATE SKIP" -8 "MISSING" -4 "DON'T KNOW" ;
label define XA17A2    -9 "LEGITIMATE SKIP" -8 "MISSING"
                       -5 "DATA OUT OF RANGE" -4 "DON'T KNOW" ;
label define A17A2_MF  -9 "LEGITIMATE SKIP" -8 "MISSING" 1 "MALE" 2 "FEMALE" ;
label define A17A2_YN  -9 "LEGITIMATE SKIP" -8 "MISSING" 1 "YES" 2 "NO" ;
label define A17A3_LB  -9 "LEGITIMATE SKIP" ;
label define A17A3_OZ  -9 "LEGITIMATE SKIP" -8 "MISSING" -4 "DON'T KNOW" ;
label define XA17A3    -9 "LEGITIMATE SKIP" -8 "MISSING" -4 "DON'T KNOW" ;
label define A17A3_MF  -9 "LEGITIMATE SKIP" 1 "MALE" 2 "FEMALE" ;
label define A17A3_YN  -9 "LEGITIMATE SKIP" -8 "MISSING" 1 "YES" 2 "NO" ;
label define A17A4_LB  -9 "LEGITIMATE SKIP" -4 "DON'T KNOW" ;
label define A17A4_OZ  -9 "LEGITIMATE SKIP" -8 "MISSING" -4 "DON'T KNOW" ;
label define XA17A4    -9 "LEGITIMATE SKIP" -8 "MISSING"
                       -5 "DATA OUT OF RANGE" -4 "DON'T KNOW" ;
label define A17A4_MF  -9 "LEGITIMATE SKIP" -8 "MISSING" 1 "MALE" 2 "FEMALE" ;
label define A17A4_YN  -9 "LEGITIMATE SKIP" -8 "MISSING" 1 "YES" 2 "NO" ;
label define A17A5_LB  -9 "LEGITIMATE SKIP" -4 "DON'T KNOW" ;
label define A17A5_OZ  -9 "LEGITIMATE SKIP" -8 "MISSING" -4 "DON'T KNOW" ;
label define XA17A5    -9 "LEGITIMATE SKIP" -8 "MISSING" -4 "DON'T KNOW" ;
label define A17A5_MF  -9 "LEGITIMATE SKIP" 1 "MALE" 2 "FEMALE" ;
label define A17A5_YN  -9 "LEGITIMATE SKIP" -8 "MISSING" 1 "YES" 2 "NO" ;
label define A17A6_LB  -9 "LEGITIMATE SKIP" ;
label define A17A6_OZ  -9 "LEGITIMATE SKIP" -4 "DON'T KNOW" ;
label define XA17A6    -9 "LEGITIMATE SKIP" ;
label define A17A6_MF  -9 "LEGITIMATE SKIP" 1 "MALE" 2 "FEMALE" ;
label define A17A6_YN  -9 "LEGITIMATE SKIP" -8 "MISSING" 1 "YES" 2 "NO" ;
label define A17A7_LB  -9 "LEGITIMATE SKIP" ;
label define A17A7_OZ  -9 "LEGITIMATE SKIP" ;
label define XA17A7    -9 "LEGITIMATE SKIP" ;
label define A17A7_MF  -9 "LEGITIMATE SKIP" 1 "MALE" 2 "FEMALE" ;
label define A17A7_YN  -9 "LEGITIMATE SKIP" 1 "YES" 2 "NO" ;
label define A17A8_LB  -9 "LEGITIMATE SKIP" ;
label define A17A8_OZ  -9 "LEGITIMATE SKIP" ;
label define XA17A8    -9 "LEGITIMATE SKIP" ;
label define A17A8_MF  -9 "LEGITIMATE SKIP" 1 "MALE" 2 "FEMALE" ;
label define A17A8_YN  -9 "LEGITIMATE SKIP" 1 "YES" 2 "NO" ;
label define A17A9_LB  -9 "LEGITIMATE SKIP" ;
label define A17A9_OZ  -9 "LEGITIMATE SKIP" ;
label define XA17A9    -9 "LEGITIMATE SKIP" ;
label define A17A9_MF  -9 "LEGITIMATE SKIP" 1 "MALE" 2 "FEMALE" ;
label define A17A9_YN  -9 "LEGITIMATE SKIP" 1 "YES" 2 "NO" ;
label define XAGECALC  -8 "MISSING" -7 "ITEM REFUSAL" -5 "DATA OUT OF RANGE" ;
label define B_2       -8 "MISSING" -7 "ITEM REFUSAL" -6 "MULTIPLE RESPONSE"
                       1 "MARRIED" 2 "WIDOWED" 3 "DIVORCED/SEPARATED"
                       4 "NOT MARRIED/LIVING W/A PARTNER" 5 "NEVER MARRIED" ;
label define B_3       -8 "MISSING" -7 "ITEM REFUSAL" 1 "YES" 2 "NO" ;
label define B_4       -8 "MISSING" -6 "MULTIPLE RESPONSE"
                       1 "BLACK/AFRICAN AMERICAN" 2 "WHITE"
                       3 "AMERICAN INDLAN/ALASKAN NATIVE"
                       4 "ASIAN/PACIFIC ISLANDER" 5 "SOME OTHER RACE"
                       6 "HISPANIC,RACE UNSPECIFIED" ;
label define B_5       -8 "MISSING" 0 "NO SCHOOLING" 1 "ELEMENTARY GRADE 1"
                       2 "ELEMENTARY GRADE 2" 3 "ELEMENTARY GRADE 3"
                       4 "ELEMENTARY GRADE 4" 5 "ELEMENTARY GRADE 5"
                       6 "ELEMENTARY GRADE 6" 7 "ELEMENTARY GRADE 7"
                       8 "ELEMENTARY GRADE 8" 9 "HIGH SCHOOL GRADE 9"
                       10 "HIGH SCHOOL GRADE 10" 11 "HIGH SCHOOL GRADE 11"
                       12 "HIGH SCHOOL GRADE 12" 13 "COLLEGE YEAR 1"
                       14 "COLLEGE YEAR 2" 15 "COLLEGE YEAR 3"
                       16 "COLLEGE YEAR 4" 17 "GRADUATE/PROFESSIONAL" ;
label define B_6       -8 "MISSING" -2 "RESPONSE ILLEGIBLE" ;
label define B_7       -8 "MISSING" -5 "DATA OUT OF RANGE" -4 "DON'T KNOW" ;
label define C_1       -5 "DATA OUT OF RANGE" -4 "DON'T KNOW"
                       91 "NEVER TRIED A CIGARETTE" ;
label define C_2       -8 "MISSING" 91 "NEVER SMOKED DAILY" ;
label define C_3       1 "WITHIN THE PAST WEEK" 2 "WITHIN THE PAST MONTH"
                       3 "1/MORE MON AGO/LESS THAN 3 MON AGO"
                       4 "3/MORE MON AGO/LESS THAN 6 MON AGO"
                       5 "6/MORE MON AGO/LESS THAN 1 YR AGO"
                       6 "1/MORE YR AGO/LESS THAN 3 YR AGO"
                       7 "3/MORE YEARS AGO" 8 "EDITED PREGNANCY USE"
                       9 "EDITED LIFETIME USE"
                       91 "NEVER SMOKED A CIGARETTE IN MY LIFE" ;
label define C_4       1 "LESS THAN ONE CIGARETTE A DAY"
                       2 "1 TO 5 CIGARETTES A DAY" 3 "ABOUT 1/2 PACK A DAY"
                       4 "ABOUT PACK DAY" 5 "ABOUT 1-1/2 PACKS A DAY"
                       6 "ABOUT 2 PACKS OR MORE DAY"
                       8 "EDITED PREGNANCY USE, FREQUENCY UNSPECIFIED"
                       91 "DID NOT SMOKE DURING THIS PREGNANCY" ;
label define C_5       -8 "MISSING" -6 "MULTIPLE RESPONSE" 1 "YES" 2 "NO" ;
label define C_6       -8 "MISSING" -5 "DATA OUT OF RANGE"
                       91 "NEVER HAD A DRINK IN MY LIFE" ;
label define C_7       -8 "MISSING" 1 "WITHIN THE PAST WEEK (7 DAYS)"
                       2 "WITHIN THE PAST MONTH (30 DAYS)"
                       3 "1/MORE MON AGO/LESS THAN 3 MON AGO"
                       4 "3/MORE MON AGO/LESS THAN 6 MON AGO"
                       5 "6/MORE MON AGO/LESS THAN 1 YR AGO"
                       6 "1/MORE YR AGO/LESS THAN 3 YR AGO"
                       7 "3/MORE YEARS AGO" 8 "EDITED PREGNANCY USE"
                       9 "EDITED LIFETIME USE"
                       91 "NEVER HAD A DRINK IN MY LIFE" ;
label define C_8       -8 "MISSING" 1 "DAILY"
                       2 "ALMOST DAILY/3 TO 6 DAYS A WEEK"
                       3 "1 TO 2 DAYS A WEEK" 4 "SEVERAL TIMES A MONTH"
                       5 "MONTHLY OR LESS (AT LEAST ONCE)"
                       8 "EDITED PREGNANCY USE, FREQUENCY UNSPECIFIED"
                       91 "DID NOT DRINK DURING THIS PREGNANCY" ;
label define C_9       -8 "MISSING" 91 "DID NOT DRINK DURING THIS PREGNANCY" ;
label define C_10      -8 "MISSING" -5 "DATA OUT OF RANGE"
                       91 "NEVER USED MARIJUANA IN MY LIFE" ;
label define C_11      -8 "MISSING" 1 "WITHIN THE PAST WEEK (7 DAYS)"
                       2 "WITHIN THE PAST MONTH (30 DAYS)"
                       3 "1/MORE MON AGO/LESS THAN 3 MON AGO"
                       4 "3/MORE MON AGO/LESS THAN 6 MON AGO"
                       5 "6/MORE MON AGO/LESS THAN 1 YR AGO"
                       6 "1/MORE YR AGO/LESS THAN 3 YR AGO"
                       7 "3/MORE YEARS AGO" 8 "EDITED PREGNANCY USE"
                       9 "EDITED LIFETIME USE"
                       91 "NEVER USED MARIJUANA IN MY LIFE" ;
label define C_12      -8 "MISSING" -5 "DATA OUT OF RANGE" 1 "DAILY"
                       2 "ALMOST DAILY/3 TO 6 DAYS A WEEK"
                       3 "1 TO 2 DAYS A WEEK" 4 "SEVERAL TIMES A MONTH"
                       5 "MONTHLY OR LESS (AT LEAST ONCE)"
                       8 "EDITED PREGNANCY USE, FREQUENCY UNSPECIFIED"
                       91 "DID NOT USE MARIJUANA DURING THIS PREGNANCY" ;
label define C_13      -8 "MISSING" -6 "MULTIPLE RESPONSE" 1 "YES" 2 "NO" ;
label define C_14      -8 "MISSING" -5 "DATA OUT OF RANGE"
                       91 "NEVER USED CRACK COCAINE IN MY LIFE" ;
label define C_15      -8 "MISSING" 1 "WITHIN THE PAST WEEK (7 DAYS)"
                       2 "WITHIN THE PAST MONTH (30 DAYS)"
                       3 "1/MORE MON AGO/LESS THAN 3 MON AGO"
                       4 "3/MORE MON AGO/LESS THAN 6 MON AGO"
                       5 "6/MORE MON AGO/LESS THAN 1 YR AGO"
                       6 "1/MORE YR AGO/LESS THAN 3 YR AGO"
                       7 "3/MORE YEARS AGO" 8 "EDITED PREGNANCY USE"
                       91 "NEVER USED CRACK COCAINE IN MY LIFE" ;
label define C_16      -8 "MISSING" 1 "DAILY"
                       2 "ALMOST DAILY/3 TO 6 DAYS A WEEK"
                       3 "1 TO 2 DAYS A WEEK" 4 "SEVERAL TIMES A MONTH"
                       5 "MONTHLY OR LESS (AT LEAST ONCE)"
                       8 "EDITED PREGNANCY USE, FREQUENCY UNSPECIFIED"
                       91 "DID NOT USE CRACK DURING THIS PREGNANCY" ;
label define C_17      -8 "MISSING" 1 "YES" 2 "NO" ;
label define C_18      -8 "MISSING" 1 "YES" 2 "NO" ;
label define C_19      -8 "MISSING" 1 "YES" 2 "NO" ;
label define C_20      -8 "MISSING" -5 "DATA OUT OF RANGE"
                       91 "NEVER TRIED OTHER FORMS OF COCAINE IN MY LIFE" ;
label define C_21      -8 "MISSING" 1 "WITHIN THE PAST WEEK (7 DAYS)"
                       2 "WITHIN THE PAST MONTH (30 DAYS)"
                       3 "1/MORE MON AGO/LESS THAN 3 MON AGO"
                       4 "3/MORE MON AGO/LESS THAN 6 MON AGO"
                       5 "6/MORE MON AGO/LESS THAN 1 YR AGO"
                       6 "1/MORE YR AGO/LESS THAN 3 YR AGO"
                       7 "3/MORE YEARS AGO" 8 "EDITED PREGNANCY USE"
                       9 "EDITED LIFETIME USE"
                       91 "NEVER TRIED OTHER FORMS OF COCAINE IN MY LIFE" ;
label define C_22      -8 "MISSING" 1 "DAILY"
                       2 "ALMOST DAILY/3 TO 6 DAYS A WEEK"
                       3 "1 TO 2 DAYS A WEEK" 4 "SEVERAL TIMES A MONTH"
                       5 "MONTHLY OR LESS"
                       8 "EDITED PREGNANCY USE, FREQUENCY UNSPECIFIED"
                       91 "DID NOT USE OTHER COCAINE THIS PREGNANCY" ;
label define C_23      -8 "MISSING" -5 "DATA OUT OF RANGE" 1 "YES" 2 "NO" ;
label define C_24      -8 "MISSING" 1 "YES" 2 "NO" ;
label define C_25      -8 "MISSING" -5 "DATA OUT OF RANGE"
                       91 "NEVER USED HEROIN IN MY LIFE" ;
label define C_26      -8 "MISSING" 1 "WITHIN THE PAST WEEK (7 DAYS)"
                       2 "WITHIN THE PAST MONTH (30 DAYS)"
                       3 "1/MORE MON AGO/LESS THAN 3 MON AGO"
                       4 "3/MORE MON AGO/LESS THAN 6 MON AGO"
                       5 "6/MORE MON AGO/LESS THAN 1 YR AGO"
                       6 "1/MORE YR AGO/LESS THAN 3 YR AGO"
                       7 "3/MORE YEARS AGO" 8 "EDITED PREGNANCY USE"
                       91 "NEVER TRIED HEROIN IN MY LIFE" ;
label define C_27      -8 "MISSING" 1 "DAILY"
                       2 "ALMOST DAILY/3 TO 6 DAYS A WEEK"
                       3 "1 TO 2 DAYS A WEEK" 4 "SEVERAL TIMES A MONTH"
                       5 "MONTHLY OR LESS"
                       8 "EDITED PREGNANCY USE, FREQUENCY UNSPECIFIED"
                       91 "DID NOT USE HEROIN DURING THIS PREGNANCY" ;
label define C_28      -8 "MISSING" 1 "YES" 2 "NO" ;
label define C_29_01   -8 "MISSING" -5 "DATA OUT OF RANGE" 0 "NOT CIRCLED"
                       1 "CIRCLED" ;
label define C_29_02   -8 "MISSING" -5 "DATA OUT OF RANGE" 0 "NOT CIRCLED"
                       1 "CIRCLED" ;
label define C_29_03   -8 "MISSING" -5 "DATA OUT OF RANGE" 0 "NOT CIRCLED"
                       1 "CIRCLED" ;
label define C_29_04   -8 "MISSING" -5 "DATA OUT OF RANGE" 0 "NOT CIRCLED"
                       1 "CIRCLED" ;
label define C_29_05   -8 "MISSING" -5 "DATA OUT OF RANGE" 0 "NOT CIRCLED"
                       1 "CIRCLED" ;
label define C_29_91   -8 "MISSING" -5 "DATA OUT OF RANGE" 0 "NOT CIRCLED"
                       1 "CIRCLED" ;
label define C_30      -8 "MISSING" 91 "NEVER USED FOR NON-MEDICAL PURPOSES" ;
label define C_31      -8 "MISSING" 1 "WITHIN THE PAST WEEK (7 DAYS)"
                       2 "WITHIN THE PAST MONTH (30 DAYS)"
                       3 "1 /MORE MON AGO/LESS THAN 3 MON AGO"
                       4 "3/MORE MON AGO/LESS THAN 6 MON AGO"
                       5 "6/MORE MON AGO/LESS THAN 1 YR AGO"
                       6 "1/MORE YR AGO/LESS THAN 3 YR AGO"
                       7 "3/MORE YEARS AGO" 8 "EDITED PREGNANCY USE"
                       9 "EDITED LIFETIME USE"
                       91 "NEVER USEDFOR NON-MEDICAL PURPOSES" ;
label define C_32      -8 "MISSING" 1 "YES" 2 "NO" 3 "EDITED YES" ;
label define C_33      -8 "MISSING" -5 "DATA OUT OF RANGE"
                       -2 "RESPONSE ILLEGIBLE"
                       91 "NEVER USED FOR NON-MEDICAL PURPOSES" ;
label define C_34      -8 "MISSING" 1 "WITHIN THE PAST WEEK(7 DAYS)"
                       2 "WITHIN THE PAST MONTH (30 DAYS)"
                       3 "1/MORE MON AGO/LESS THAN 3 MON AGO"
                       4 "3/MORE MON AGO/LESS THAN 6 MON AGO"
                       5 "6/MORE MON AGO/LESS THAN 1 YR AGO"
                       6 "1/MORE YR AGO/LESS THAN 3 YR AGO"
                       7 "3/MORE YEARS AGO"
                       91 "NEVER USED FOR NON-MEDICAL PURPOSES" ;
label define C_35      -8 "MISSING" 1 "YES" 2 "NO" 3 "EDITED YES" ;
label define D_1_01    -8 "MISSING" -5 "DATA OUT OF RANGE" 0 "NOT CIRCLED"
                       1 "CIRCLED" ;
label define D_1_02    -8 "MISSING" -5 "DATA OUT OF RANGE" 0 "NOT CIRCLED"
                       1 "CIRCLED" ;
label define D_1_03    -8 "MISSING" -5 "DATA OUT OF RANGE" 0 "NOT CIRCLED"
                       1 "CIRCLED" ;
label define D_1_04    -8 "MISSING" -5 "DATA OUT OF RANGE" 0 "NOT CIRCLED"
                       1 "CIRCLED" ;
label define D_1_05    -8 "MISSING" -5 "DATA OUT OF RANGE" 0 "NOT CIRCLED"
                       1 "CIRCLED" ;
label define D_1_06    -8 "MISSING" -5 "DATA OUT OF RANGE" 0 "NOT CIRCLED"
                       1 "CIRCLED" ;
label define D_1_07    -8 "MISSING" -5 "DATA OUT OF RANGE" 0 "NOT CIRCLED"
                       1 "CIRCLED" ;
label define D_1_08    -8 "MISSING" -5 "DATA OUT OF RANGE" 0 "NOT CIRCLED"
                       1 "CIRCLED" ;
label define D_1_09    -8 "MISSING" -5 "DATA OUT OF RANGE" 0 "NOT CIRCLED"
                       1 "CIRCLED" ;
label define D_1_10    -8 "MISSING" -5 "DATA OUT OF RANGE" 0 "NOT CIRCLED"
                       1 "CIRCLED" ;
label define D_1_11    -8 "MISSING" -5 "DATA OUT OF RANGE" 0 "NOT CIRCLED"
                       1 "CIRCLED" ;
label define D_1_12    -8 "MISSING" -5 "DATA OUT OF RANGE" 0 "NOT CIRCLED"
                       1 "CIRCLED" ;
label define D_1_13    -8 "MISSING" -5 "DATA OUT OF RANGE" 0 "NOT CIRCLED"
                       1 "CIRCLED" ;
label define D_1_14    -8 "MISSING" -5 "DATA OUT OF RANGE" 0 "NOT CIRCLED"
                       1 "CIRCLED" ;
label define D_1_15    -8 "MISSING" -5 "DATA OUT OF RANGE" 0 "NOT CIRCLED"
                       1 "CIRCLED" ;
label define D_1_16    -8 "MISSING" -5 "DATA OUT OF RANGE" 0 "NOT CIRCLED"
                       1 "CIRCLED" ;
label define D_1_91    -8 "MISSING" 0 "NOT CIRCLED" 1 "CIRCLED" ;
label define D_2       -8 "MISSING" 1 "YES" 2 "NO" 3 "EDITED YES" ;
label define D_3       -8 "MISSING" -5 "DATA OUT OF RANGE"
                       1 "WITHIN THE PAST WEEK (7 DAYS)"
                       2 "WITHIN THE PAST MONTH (30 DAYS)"
                       3 "1/MORE MON AGO/LESS THAN 3 MON AGO"
                       4 "3/MORE MON AGO/LESS THAN 6 MON AGO"
                       5 "6/MORE MON AGO/LESS THAN 1 YR AGO"
                       6 "1/MORE YR AGO/LESS THAN 3 YR AGO"
                       7 "3/MORE YEARS AGO"
                       91 "NEVER USED A NEEDLE FOR NON-MEDICAL PURPOSES" ;
label define D_4       -8 "MISSING" 1 "YES" 2 "NO" ;
label define D_5_A     -8 "MISSING" -6 "MULTIPLE RESPONSE" -4 "DON'T KNOW"
                       1 "NO RISK" 2 "SLIGHT RISK" 3 "MODERATE RISK"
                       4 "GREAT RISK" ;
label define D_5_B     -8 "MISSING" -6 "MULTIPLE RESPONSE" -4 "DON'T KNOW"
                       1 "NO RISK" 2 "SLIGHT RISK" 3 "MODERATE RISK"
                       4 "GREAT RISK" ;
label define D_5_C     -8 "MISSING" -6 "MULTIPLE RESPONSE" -4 "DON'T KNOW"
                       1 "NO RISK" 2 "SLIGHT RISK" 3 "MODERATE RISK"
                       4 "GREAT RISK" ;
label define D_5_D     -8 "MISSING" -6 "MULTIPLE RESPONSE" -4 "DON'T KNOW"
                       1 "NO RISK" 2 "SLIGHT RISK" 3 "MODERATE RISK"
                       4 "GREAT RISK" ;
label define D_5_E     -8 "MISSING" -6 "MULTIPLE RESPONSE" -4 "DON'T KNOW"
                       1 "NO RISK" 2 "SLIGHT RISK" 3 "MODERATE RISK"
                       4 "GREAT RISK" ;
label define E_1       -8 "MISSING" -5 "DATA OUT OF RANGE"
                       91 "NEVER TREATED FOR PROBLEMS IN MY LIFE" ;
label define E_2       -8 "MISSING" -5 "DATA OUT OF RANGE"
                       1 "ALCOHOL PROBLEM" 2 "DRUG PROBLEM" 3 "BOTH"
                       91 "NEVER TREATED FOR PROBLEMS IN MY LIFE" ;
label define E_3       -8 "MISSING" 1 "YES" 2 "NO" ;
label define E_4       -8 "MISSING" -6 "MULTIPLE RESPONSE" 1 "YES" 2 "NO" ;
label define F_1_A     -8 "MISSING" 1 "YES" 2 "NO" 3 "EDITED YES" ;
label define F_1_B     -9 "LEGITIMATE SKIP" -8 "MISSING" 1 "YES" 2 "NO" ;
label define F_2_A     -8 "MISSING" 1 "YES" 2 "NO" 3 "EDITED YES" ;
label define F_2_B     -9 "LEGITIMATE SKIP" -8 "MISSING" 1 "YES" 2 "NO" ;
label define F_3_A     -8 "MISSING" 1 "YES" 2 "NO" ;
label define F_3_B     -9 "LEGITIMATE SKIP" -8 "MISSING" 1 "YES" 2 "NO" ;
label define F_4_A     -8 "MISSING" 1 "YES" 2 "NO" ;
label define F_4_B     -9 "LEGITIMATE SKIP" -8 "MISSING" 1 "YES" 2 "NO" ;
label define F_5_A     -8 "MISSING" 1 "YES" 2 "NO" ;
label define F_5_B     -9 "LEGITIMATE SKIP" -8 "MISSING" 1 "YES" 2 "NO" ;
label define F_6_A     -8 "MISSING" -6 "MULTIPLE RESPONSE" 1 "YES" 2 "NO"
                       3 "EDITED YES" ;
label define F_6_B     -9 "LEGITIMATE SKIP" -8 "MISSING" 1 "YES" 2 "NO"
                       3 "EDITED YES" ;
label define F_7_A     -8 "MISSING" 1 "YES" 2 "NO" ;
label define F_7_B     -9 "LEGITIMATE SKIP" -8 "MISSING" 1 "YES" 2 "NO" ;
label define F_8_A     -8 "MISSING" 1 "YES" 2 "NO" ;
label define F_8_B     -9 "LEGITIMATE SKIP" -8 "MISSING" 1 "YES" 2 "NO" ;
label define F_8_A_A   -9 "LEGITIMATE SKIP" -8 "MISSING" 1 "YES" 2 "NO" ;
label define F_8_A_B   -9 "LEGITIMATE SKIP" -8 "MISSING" 1 "YES" 2 "NO" ;
label define F_9       -8 "MISSING" -5 "DATA OUT OF RANGE" ;
label define F_10      -8 "MISSING" ;
label define G_1       -8 "MISSING" -7 "ITEM REFUSAL" -6 "MULTIPLE RESPONSE"
                       1 "BLUE CROSS/BLUE SHIELD" 2 "OTHER PRIVATE INSURANCE"
                       3 "MEDICAID" 4 "STATE/LOCAL GOVERNMENT" 5 "CHAMPUS"
                       6 "HMO" 7 "SELF PAY/NON REFUNDABLE BY INSURANCE"
                       8 "SOME OTHER SOURCE" 9 "DON'T KNOW/UNABLE TO PAY" ;
label define G_2_INCO  -8 "MISSING" -7 "ITEM REFUSAL" -4 "DON'T KNOW"
                       1 "NO INCOME" 2 "UNDER $5,000" 3 "$5,000-6,300"
                       4 "$6,301-$8,450" 5 "$8,451-$10,600"
                       6 "$10,601-$12,700" 7 "$12,701-$14,850"
                       8 "$14,851-$17,000" 9 "$17,001-$19,000"
                       10 "$19,001-$21,300" 11 "$21,301-$25,000"
                       12 "$25,001-$30,000" 13 "$30,001-$40,000"
                       14 "$40,001-$50,000" 15 "$50,001-$75,000"
                       16 "$75,001 OR MORE" ;
label define G_3_1     -8 "MISSING" -7 "ITEM REFUSAL" -4 "DON'T KNOW" 1 "YES"
                       2 "NO" ;
label define G_3_2     -8 "MISSING" -7 "ITEM REFUSAL" -4 "DON'T KNOW" 1 "YES"
                       2 "NO" ;
label define G_3_4     -8 "MISSING" -7 "ITEM REFUSAL" -6 "MULTIPLE RESPONSE"
                       -4 "DON'T KNOW" 1 "YES" 2 "NO" ;
label define G_3_5     -8 "MISSING" -7 "ITEM REFUSAL" -4 "DON'T KNOW" 1 "YES"
                       2 "NO" ;
label define G_3_6     -8 "MISSING" -7 "ITEM REFUSAL" -4 "DON'T KNOW" 1 "YES"
                       2 "NO" ;
label define G_3_7     -8 "MISSING" -7 "ITEM REFUSAL" -4 "DON'T KNOW" 1 "YES"
                       2 "NO" ;
label define G_3_8     -8 "MISSING" -7 "ITEM REFUSAL" -4 "DON'T KNOW" 1 "YES"
                       2 "NO" ;
label define G_3_9     -8 "MISSING" -7 "ITEM REFUSAL" -6 "MULTIPLE RESPONSE"
                       -4 "DON'T KNOW" 1 "YES" 2 "NO" ;
label define G_3_10    -8 "MISSING" -7 "ITEM REFUSAL" -4 "DON'T KNOW" 1 "YES"
                       2 "NO" ;
label define G_3_11    -8 "MISSING" -7 "ITEM REFUSAL" -4 "DON'T KNOW" 1 "YES"
                       2 "NO" ;
label define G_3_SP    -9 "LEGITIMATE SKIP" -8 "MISSING" -7 "ITEM REFUSAL"
                       -4 "DON'T KNOW" 11 "INVESTMENTS, STOCKS" 12 "WIC"
                       13 "DISABILITY" 14 "INSURANCE" 15 "OTHER" ;
label define H_1       -8 "MISSING" 1 "COMPLETED" 2 "PARTIAL" ;
label define H_2       -8 "MISSING" -6 "MULTIPLE RESPONSE" 1 "HOSPITAL ROOM"
                       2 "HALLWAY" 3 "LOBBY" 4 "CHAPEL"
                       5 "OUTSIDE OF HOSPITAL" 6 "OTHER" ;
label define H_3       -8 "MISSING" 1 "YES" 2 "NO" 3 "EDITED YES" ;
label define H_4_1     -9 "LEGITIMATE SKIP" -8 "MISSING" 0 "NOT CIRCLED"
                       1 "CIRCLED" ;
label define H_4_2     -9 "LEGITIMATE SKIP" -8 "MISSING" 0 "NOT CIRCLED"
                       1 "CIRCLED" ;
label define H_4_3     -9 "LEGITIMATE SKIP" -8 "MISSING" 0 "NOT CIRCLED"
                       1 "CIRCLED" ;
label define H_4_4     -9 "LEGITIMATE SKIP" -8 "MISSING" 0 "NOT CIRCLED"
                       1 "CIRCLED" ;
label define H_5_A     -8 "MISSING" 1 "VERY CONFIDENT" 2 "CONFIDENT"
                       3 "UNSURE" 4 "DOUBTFUL" 5 "VERY DOUBTFUL" ;
label define H_5_B     -8 "MISSING" 1 "VERY CONFIDENT" 2 "CONFIDENT"
                       3 "UNSURE" 4 "DOUBTFUL" 5 "VERY DOUBTFUL" ;
label define H_5_C     -8 "MISSING" 1 "VERY CONFIDENT" 2 "CONFIDENT"
                       3 "UNSURE" 4 "DOUBTFUL" 5 "VERY DOUBTFUL" ;
label define H_6       -8 "MISSING" 1 "YES" 2 "NO" 3 "EDITED YES" ;
label define H_6_SP    -9 "LEGITIMATE SKIP" -8 "MISSING"
                       11 "INTERVIEWER COMPLETED DRUG USE ANS.SHEETS"
                       12 "OTHERS PRESENT DURING INTERVIEW"
                       13 "DIFFICULT LABOR"
                       14 "INDICATION THAT RESPONDENT USED DRUGS"
                       15 "BABY ILL (OR DIED)"
                       16 "R MAY NOT HAVE UNDERSTOOD QUESTIONS"
                       17 "MOTHER HAD OTHER MEDICAL/PSYCHOL PROBLEMS"
                       18 "R LEERY, RELUCTANT, OR QUESTIONED CONFIDENCE"
                       19 "OTHER" ;
label define MCOMPMN   -8 "MISSING" -1 "NO ABSTRACT DATA" ;
label define XMOMAGE   -8 "MISSING" -1 "NO ABSTRACT DATA" ;
label define M2RACE    -8 "MISSING" -1 "NO ABSTRACT DATA" 1 "WHITE"
                       2 "BLACK/AFRICAN AMERICAN" 3 "ASIAN/PACIFIC ISLANDER"
                       4 "ALEUT/ESKIMO/AMERICAN INDIAN" 8 "OTHER" ;
label define M2_OTH    -9 "LEGITIMATE SKIP" -8 "MISSING"
                       -1 "NO ABSTRACT DATA" 10 "LATINO/LATIN AMERICAN"
                       11 "SPANISH" 12 "FILIPINO" 13 "HISPANIC" ;
label define XM3ADM    -5 "DATA OUT OF RANGE" -1 "NO ABSTRACT DATA" ;
label define M4PAY     -8 "MISSING" -1 "NO ABSTRACT DATA"
                       1 "PRIVATE INSURANCE/HMO" 2 "MEDICAID/MEDICAID HMO"
                       3 "SELF PAID BY PATIENT/RELATIVE"
                       4 "STATE OR LOCAL ASSISTANCE" 8 "OTHER" ;
label define M5_01A    -9 "LEGITIMATE SKIP" -1 "NO ABSTRACT DATA" 1 "1581"
                       2 "4100" 3 "5419" 4 "7030" 5 "13100" 6 "13102"
                       7 "23770" 8 "25000" 9 "25001" 10 "28260" 11 "30390"
                       12 "30391" 13 "30500" 14 "30510" 15 "30511" 16 "30551"
                       17 "30561" 18 "30590" 19 "30591" 20 "34590" 21 "43101"
                       22 "47202" 23 "49390" 24 "49391" 25 "53390" 26 "57140"
                       27 "62421" 28 "63331" 29 "63492" 30 "63671" 31 "63801"
                       32 "64001" 33 "64111" 34 "64121" 35 "64191" 36 "64201"
                       37 "64221" 38 "64223" 39 "64231" 40 "64232" 41 "64241"
                       42 "64251" 43 "64261" 44 "64271" 45 "64291" 46 "64361"
                       47 "64381" 48 "64401" 49 "64411" 50 "64421" 51 "64501"
                       52 "64611" 53 "64651" 54 "64662" 55 "64671" 56 "64681"
                       57 "64701" 58 "64711" 59 "64721" 60 "64761" 61 "64781"
                       62 "64782" 63 "64791" 64 "64801" 65 "64811" 66 "64831"
                       67 "64845" 68 "64880" 69 "64881" 70 "64891" 71 "64892"
                       72 "64893" 73 "65101" 74 "65211" 75 "65221" 76 "65231"
                       77 "65241" 78 "65251" 79 "65261" 80 "65281" 81 "65291"
                       82 "65311" 83 "65341" 84 "65391" 85 "65401" 86 "65410"
                       87 "65411" 88 "65421" 89 "65441" 90 "65451" 91 "65491"
                       92 "65531" 93 "65611" 94 "65621" 95 "65631" 96 "65651"
                       97 "65661" 98 "65671" 99 "65681" 100 "65721"
                       101 "65801" 102 "65810" 103 "65811" 104 "65821"
                       105 "65831" 106 "65881" 107 "65901" 108 "65910"
                       109 "65911" 110 "65931" 111 "65941" 112 "65951"
                       113 "65981" 114 "65991" 115 "66001" 116 "66011"
                       117 "66021" 118 "66031" 119 "66041" 120 "66061"
                       121 "66071" 122 "66091" 123 "66101" 124 "66111"
                       125 "66131" 126 "66201" 127 "66221" 128 "66301"
                       129 "66311" 130 "66321" 131 "66331" 132 "66341"
                       133 "66351" 134 "66361" 135 "66381" 136 "66401"
                       137 "66411" 138 "66414" 139 "66421" 140 "66431"
                       141 "66451" 142 "66481" 143 "66531" 144 "66541"
                       145 "66551" 146 "66557" 147 "66602" 148 "66612"
                       149 "66622" 150 "66712" 151 "66901" 152 "66922"
                       153 "66951" 154 "66981" 155 "67002" 156 "67101"
                       157 "67111" 158 "67182" 159 "67202" 160 "67412"
                       161 "69821" 162 "74881" 163 "0380X" 164 "0410X"
                       165 "0411X" 166 "0414X" 167 "0449X" 168 "07030"
                       169 "0781X" 170 "0798X" 171 "0912X" 172 "0970X"
                       173 "0971X" 174 "0979X" 175 "0980X" 176 "1122X"
                       177 "13101" 178 "1310X" 179 "1748X" 180 "1923X"
                       181 "2181X" 182 "2189X" 183 "270XX" 184 "2780X"
                       185 "2809X" 186 "2825X" 187 "2830X" 188 "2851X"
                       189 "2859X" 190 "2875X" 191 "30520" 192 "30560"
                       193 "3432X" 194 "3439X" 195 "3510X" 196 "4019X"
                       197 "4240X" 198 "4553X" 199 "4556X" 200 "4659X"
                       201 "5185X" 202 "5282X" 203 "5559X" 204 "5680X"
                       205 "5990X" 206 "6159X" 207 "6160X" 208 "6162X"
                       209 "6202X" 210 "6215X" 211 "6238X" 212 "6245X"
                       213 "6410X" 214 "64661" 215 "64821" 216 "64822"
                       217 "64841" 218 "6500X" 219 "650XX" 220 "65581"
                       221 "65841" 222 "65921" 223 "6600X" 224 "66121"
                       225 "6620X" 226 "6640X" 227 "6641X" 228 "6698X"
                       229 "67432" 230 "6924X" 231 "6989X" 232 "7088X"
                       233 "7100X" 234 "7293X" 235 "7533X" 236 "7569X"
                       237 "7807X" 238 "7850X" 239 "7856X" 240 "7882X"
                       241 "7923X" 242 "7958X" 243 "9478X" 244 "9952X"
                       245 "9974X" 246 "9975X" 247 "9981X" 248 "E9387"
                       249 "V016X" 250 "V017X" 251 "V018X" 252 "V025X"
                       253 "V026X" 254 "V043X" 255 "V072X" 256 "V120X"
                       257 "V1581" 258 "V210X" 259 "V233X" 260 "V235X"
                       261 "V237X" 262 "V238X" 263 "V240X" 264 "V252X"
                       265 "V270X" 266 "V272X" 267 "V277X" 268 "V290X"
                       269 "V608X" 270 "V615X" ;
label define M5_02A    -9 "LEGITIMATE SKIP" -1 "NO ABSTRACT DATA" 1 "1581"
                       2 "4100" 3 "5419" 4 "7030" 5 "13100" 6 "13102"
                       7 "23770" 8 "25000" 9 "25001" 10 "28260" 11 "30390"
                       12 "30391" 13 "30500" 14 "30510" 15 "30511" 16 "30551"
                       17 "30561" 18 "30590" 19 "30591" 20 "34590" 21 "43101"
                       22 "47202" 23 "49390" 24 "49391" 25 "53390" 26 "57140"
                       27 "62421" 28 "63331" 29 "63492" 30 "63671" 31 "63801"
                       32 "64001" 33 "64111" 34 "64121" 35 "64191" 36 "64201"
                       37 "64221" 38 "64223" 39 "64231" 40 "64232" 41 "64241"
                       42 "64251" 43 "64261" 44 "64271" 45 "64291" 46 "64361"
                       47 "64381" 48 "64401" 49 "64411" 50 "64421" 51 "64501"
                       52 "64611" 53 "64651" 54 "64662" 55 "64671" 56 "64681"
                       57 "64701" 58 "64711" 59 "64721" 60 "64761" 61 "64781"
                       62 "64782" 63 "64791" 64 "64801" 65 "64811" 66 "64831"
                       67 "64845" 68 "64880" 69 "64881" 70 "64891" 71 "64892"
                       72 "64893" 73 "65101" 74 "65211" 75 "65221" 76 "65231"
                       77 "65241" 78 "65251" 79 "65261" 80 "65281" 81 "65291"
                       82 "65311" 83 "65341" 84 "65391" 85 "65401" 86 "65410"
                       87 "65411" 88 "65421" 89 "65441" 90 "65451" 91 "65491"
                       92 "65531" 93 "65611" 94 "65621" 95 "65631" 96 "65651"
                       97 "65661" 98 "65671" 99 "65681" 100 "65721"
                       101 "65801" 102 "65810" 103 "65811" 104 "65821"
                       105 "65831" 106 "65881" 107 "65901" 108 "65910"
                       109 "65911" 110 "65931" 111 "65941" 112 "65951"
                       113 "65981" 114 "65991" 115 "66001" 116 "66011"
                       117 "66021" 118 "66031" 119 "66041" 120 "66061"
                       121 "66071" 122 "66091" 123 "66101" 124 "66111"
                       125 "66131" 126 "66201" 127 "66221" 128 "66301"
                       129 "66311" 130 "66321" 131 "66331" 132 "66341"
                       133 "66351" 134 "66361" 135 "66381" 136 "66401"
                       137 "66411" 138 "66414" 139 "66421" 140 "66431"
                       141 "66451" 142 "66481" 143 "66531" 144 "66541"
                       145 "66551" 146 "66557" 147 "66602" 148 "66612"
                       149 "66622" 150 "66712" 151 "66901" 152 "66922"
                       153 "66951" 154 "66981" 155 "67002" 156 "67101"
                       157 "67111" 158 "67182" 159 "67202" 160 "67412"
                       161 "69821" 162 "74881" 163 "0380X" 164 "0410X"
                       165 "0411X" 166 "0414X" 167 "0449X" 168 "07030"
                       169 "0781X" 170 "0798X" 171 "0912X" 172 "0970X"
                       173 "0971X" 174 "0979X" 175 "0980X" 176 "1122X"
                       177 "13101" 178 "1310X" 179 "1748X" 180 "1923X"
                       181 "2181X" 182 "2189X" 183 "270XX" 184 "2780X"
                       185 "2809X" 186 "2825X" 187 "2830X" 188 "2851X"
                       189 "2859X" 190 "2875X" 191 "30520" 192 "30560"
                       193 "3432X" 194 "3439X" 195 "3510X" 196 "4019X"
                       197 "4240X" 198 "4553X" 199 "4556X" 200 "4659X"
                       201 "5185X" 202 "5282X" 203 "5559X" 204 "5680X"
                       205 "5990X" 206 "6159X" 207 "6160X" 208 "6162X"
                       209 "6202X" 210 "6215X" 211 "6238X" 212 "6245X"
                       213 "6410X" 214 "64661" 215 "64821" 216 "64822"
                       217 "64841" 218 "6500X" 219 "650XX" 220 "65581"
                       221 "65841" 222 "65921" 223 "6600X" 224 "66121"
                       225 "6620X" 226 "6640X" 227 "6641X" 228 "6698X"
                       229 "67432" 230 "6924X" 231 "6989X" 232 "7088X"
                       233 "7100X" 234 "7293X" 235 "7533X" 236 "7569X"
                       237 "7807X" 238 "7850X" 239 "7856X" 240 "7882X"
                       241 "7923X" 242 "7958X" 243 "9478X" 244 "9952X"
                       245 "9974X" 246 "9975X" 247 "9981X" 248 "E9387"
                       249 "V016X" 250 "V017X" 251 "V018X" 252 "V025X"
                       253 "V026X" 254 "V043X" 255 "V072X" 256 "V120X"
                       257 "V1581" 258 "V210X" 259 "V233X" 260 "V235X"
                       261 "V237X" 262 "V238X" 263 "V240X" 264 "V252X"
                       265 "V270X" 266 "V272X" 267 "V277X" 268 "V290X"
                       269 "V608X" 270 "V615X" ;
label define M5_03A    -9 "LEGITIMATE SKIP" -1 "NO ABSTRACT DATA" 1 "1581"
                       2 "4100" 3 "5419" 4 "7030" 5 "13100" 6 "13102"
                       7 "23770" 8 "25000" 9 "25001" 10 "28260" 11 "30390"
                       12 "30391" 13 "30500" 14 "30510" 15 "30511" 16 "30551"
                       17 "30561" 18 "30590" 19 "30591" 20 "34590" 21 "43101"
                       22 "47202" 23 "49390" 24 "49391" 25 "53390" 26 "57140"
                       27 "62421" 28 "63331" 29 "63492" 30 "63671" 31 "63801"
                       32 "64001" 33 "64111" 34 "64121" 35 "64191" 36 "64201"
                       37 "64221" 38 "64223" 39 "64231" 40 "64232" 41 "64241"
                       42 "64251" 43 "64261" 44 "64271" 45 "64291" 46 "64361"
                       47 "64381" 48 "64401" 49 "64411" 50 "64421" 51 "64501"
                       52 "64611" 53 "64651" 54 "64662" 55 "64671" 56 "64681"
                       57 "64701" 58 "64711" 59 "64721" 60 "64761" 61 "64781"
                       62 "64782" 63 "64791" 64 "64801" 65 "64811" 66 "64831"
                       67 "64845" 68 "64880" 69 "64881" 70 "64891" 71 "64892"
                       72 "64893" 73 "65101" 74 "65211" 75 "65221" 76 "65231"
                       77 "65241" 78 "65251" 79 "65261" 80 "65281" 81 "65291"
                       82 "65311" 83 "65341" 84 "65391" 85 "65401" 86 "65410"
                       87 "65411" 88 "65421" 89 "65441" 90 "65451" 91 "65491"
                       92 "65531" 93 "65611" 94 "65621" 95 "65631" 96 "65651"
                       97 "65661" 98 "65671" 99 "65681" 100 "65721"
                       101 "65801" 102 "65810" 103 "65811" 104 "65821"
                       105 "65831" 106 "65881" 107 "65901" 108 "65910"
                       109 "65911" 110 "65931" 111 "65941" 112 "65951"
                       113 "65981" 114 "65991" 115 "66001" 116 "66011"
                       117 "66021" 118 "66031" 119 "66041" 120 "66061"
                       121 "66071" 122 "66091" 123 "66101" 124 "66111"
                       125 "66131" 126 "66201" 127 "66221" 128 "66301"
                       129 "66311" 130 "66321" 131 "66331" 132 "66341"
                       133 "66351" 134 "66361" 135 "66381" 136 "66401"
                       137 "66411" 138 "66414" 139 "66421" 140 "66431"
                       141 "66451" 142 "66481" 143 "66531" 144 "66541"
                       145 "66551" 146 "66557" 147 "66602" 148 "66612"
                       149 "66622" 150 "66712" 151 "66901" 152 "66922"
                       153 "66951" 154 "66981" 155 "67002" 156 "67101"
                       157 "67111" 158 "67182" 159 "67202" 160 "67412"
                       161 "69821" 162 "74881" 163 "0380X" 164 "0410X"
                       165 "0411X" 166 "0414X" 167 "0449X" 168 "07030"
                       169 "0781X" 170 "0798X" 171 "0912X" 172 "0970X"
                       173 "0971X" 174 "0979X" 175 "0980X" 176 "1122X"
                       177 "13101" 178 "1310X" 179 "1748X" 180 "1923X"
                       181 "2181X" 182 "2189X" 183 "270XX" 184 "2780X"
                       185 "2809X" 186 "2825X" 187 "2830X" 188 "2851X"
                       189 "2859X" 190 "2875X" 191 "30520" 192 "30560"
                       193 "3432X" 194 "3439X" 195 "3510X" 196 "4019X"
                       197 "4240X" 198 "4553X" 199 "4556X" 200 "4659X"
                       201 "5185X" 202 "5282X" 203 "5559X" 204 "5680X"
                       205 "5990X" 206 "6159X" 207 "6160X" 208 "6162X"
                       209 "6202X" 210 "6215X" 211 "6238X" 212 "6245X"
                       213 "6410X" 214 "64661" 215 "64821" 216 "64822"
                       217 "64841" 218 "6500X" 219 "650XX" 220 "65581"
                       221 "65841" 222 "65921" 223 "6600X" 224 "66121"
                       225 "6620X" 226 "6640X" 227 "6641X" 228 "6698X"
                       229 "67432" 230 "6924X" 231 "6989X" 232 "7088X"
                       233 "7100X" 234 "7293X" 235 "7533X" 236 "7569X"
                       237 "7807X" 238 "7850X" 239 "7856X" 240 "7882X"
                       241 "7923X" 242 "7958X" 243 "9478X" 244 "9952X"
                       245 "9974X" 246 "9975X" 247 "9981X" 248 "E9387"
                       249 "V016X" 250 "V017X" 251 "V018X" 252 "V025X"
                       253 "V026X" 254 "V043X" 255 "V072X" 256 "V120X"
                       257 "V1581" 258 "V210X" 259 "V233X" 260 "V235X"
                       261 "V237X" 262 "V238X" 263 "V240X" 264 "V252X"
                       265 "V270X" 266 "V272X" 267 "V277X" 268 "V290X"
                       269 "V608X" 270 "V615X" ;
label define M5_04A    -9 "LEGITIMATE SKIP" -1 "NO ABSTRACT DATA" 1 "1581"
                       2 "4100" 3 "5419" 4 "7030" 5 "13100" 6 "13102"
                       7 "23770" 8 "25000" 9 "25001" 10 "28260" 11 "30390"
                       12 "30391" 13 "30500" 14 "30510" 15 "30511" 16 "30551"
                       17 "30561" 18 "30590" 19 "30591" 20 "34590" 21 "43101"
                       22 "47202" 23 "49390" 24 "49391" 25 "53390" 26 "57140"
                       27 "62421" 28 "63331" 29 "63492" 30 "63671" 31 "63801"
                       32 "64001" 33 "64111" 34 "64121" 35 "64191" 36 "64201"
                       37 "64221" 38 "64223" 39 "64231" 40 "64232" 41 "64241"
                       42 "64251" 43 "64261" 44 "64271" 45 "64291" 46 "64361"
                       47 "64381" 48 "64401" 49 "64411" 50 "64421" 51 "64501"
                       52 "64611" 53 "64651" 54 "64662" 55 "64671" 56 "64681"
                       57 "64701" 58 "64711" 59 "64721" 60 "64761" 61 "64781"
                       62 "64782" 63 "64791" 64 "64801" 65 "64811" 66 "64831"
                       67 "64845" 68 "64880" 69 "64881" 70 "64891" 71 "64892"
                       72 "64893" 73 "65101" 74 "65211" 75 "65221" 76 "65231"
                       77 "65241" 78 "65251" 79 "65261" 80 "65281" 81 "65291"
                       82 "65311" 83 "65341" 84 "65391" 85 "65401" 86 "65410"
                       87 "65411" 88 "65421" 89 "65441" 90 "65451" 91 "65491"
                       92 "65531" 93 "65611" 94 "65621" 95 "65631" 96 "65651"
                       97 "65661" 98 "65671" 99 "65681" 100 "65721"
                       101 "65801" 102 "65810" 103 "65811" 104 "65821"
                       105 "65831" 106 "65881" 107 "65901" 108 "65910"
                       109 "65911" 110 "65931" 111 "65941" 112 "65951"
                       113 "65981" 114 "65991" 115 "66001" 116 "66011"
                       117 "66021" 118 "66031" 119 "66041" 120 "66061"
                       121 "66071" 122 "66091" 123 "66101" 124 "66111"
                       125 "66131" 126 "66201" 127 "66221" 128 "66301"
                       129 "66311" 130 "66321" 131 "66331" 132 "66341"
                       133 "66351" 134 "66361" 135 "66381" 136 "66401"
                       137 "66411" 138 "66414" 139 "66421" 140 "66431"
                       141 "66451" 142 "66481" 143 "66531" 144 "66541"
                       145 "66551" 146 "66557" 147 "66602" 148 "66612"
                       149 "66622" 150 "66712" 151 "66901" 152 "66922"
                       153 "66951" 154 "66981" 155 "67002" 156 "67101"
                       157 "67111" 158 "67182" 159 "67202" 160 "67412"
                       161 "69821" 162 "74881" 163 "0380X" 164 "0410X"
                       165 "0411X" 166 "0414X" 167 "0449X" 168 "07030"
                       169 "0781X" 170 "0798X" 171 "0912X" 172 "0970X"
                       173 "0971X" 174 "0979X" 175 "0980X" 176 "1122X"
                       177 "13101" 178 "1310X" 179 "1748X" 180 "1923X"
                       181 "2181X" 182 "2189X" 183 "270XX" 184 "2780X"
                       185 "2809X" 186 "2825X" 187 "2830X" 188 "2851X"
                       189 "2859X" 190 "2875X" 191 "30520" 192 "30560"
                       193 "3432X" 194 "3439X" 195 "3510X" 196 "4019X"
                       197 "4240X" 198 "4553X" 199 "4556X" 200 "4659X"
                       201 "5185X" 202 "5282X" 203 "5559X" 204 "5680X"
                       205 "5990X" 206 "6159X" 207 "6160X" 208 "6162X"
                       209 "6202X" 210 "6215X" 211 "6238X" 212 "6245X"
                       213 "6410X" 214 "64661" 215 "64821" 216 "64822"
                       217 "64841" 218 "6500X" 219 "650XX" 220 "65581"
                       221 "65841" 222 "65921" 223 "6600X" 224 "66121"
                       225 "6620X" 226 "6640X" 227 "6641X" 228 "6698X"
                       229 "67432" 230 "6924X" 231 "6989X" 232 "7088X"
                       233 "7100X" 234 "7293X" 235 "7533X" 236 "7569X"
                       237 "7807X" 238 "7850X" 239 "7856X" 240 "7882X"
                       241 "7923X" 242 "7958X" 243 "9478X" 244 "9952X"
                       245 "9974X" 246 "9975X" 247 "9981X" 248 "E9387"
                       249 "V016X" 250 "V017X" 251 "V018X" 252 "V025X"
                       253 "V026X" 254 "V043X" 255 "V072X" 256 "V120X"
                       257 "V1581" 258 "V210X" 259 "V233X" 260 "V235X"
                       261 "V237X" 262 "V238X" 263 "V240X" 264 "V252X"
                       265 "V270X" 266 "V272X" 267 "V277X" 268 "V290X"
                       269 "V608X" 270 "V615X" ;
label define M5_05A    -9 "LEGITIMATE SKIP" -1 "NO ABSTRACT DATA" 1 "1581"
                       2 "4100" 3 "5419" 4 "7030" 5 "13100" 6 "13102"
                       7 "23770" 8 "25000" 9 "25001" 10 "28260" 11 "30390"
                       12 "30391" 13 "30500" 14 "30510" 15 "30511" 16 "30551"
                       17 "30561" 18 "30590" 19 "30591" 20 "34590" 21 "43101"
                       22 "47202" 23 "49390" 24 "49391" 25 "53390" 26 "57140"
                       27 "62421" 28 "63331" 29 "63492" 30 "63671" 31 "63801"
                       32 "64001" 33 "64111" 34 "64121" 35 "64191" 36 "64201"
                       37 "64221" 38 "64223" 39 "64231" 40 "64232" 41 "64241"
                       42 "64251" 43 "64261" 44 "64271" 45 "64291" 46 "64361"
                       47 "64381" 48 "64401" 49 "64411" 50 "64421" 51 "64501"
                       52 "64611" 53 "64651" 54 "64662" 55 "64671" 56 "64681"
                       57 "64701" 58 "64711" 59 "64721" 60 "64761" 61 "64781"
                       62 "64782" 63 "64791" 64 "64801" 65 "64811" 66 "64831"
                       67 "64845" 68 "64880" 69 "64881" 70 "64891" 71 "64892"
                       72 "64893" 73 "65101" 74 "65211" 75 "65221" 76 "65231"
                       77 "65241" 78 "65251" 79 "65261" 80 "65281" 81 "65291"
                       82 "65311" 83 "65341" 84 "65391" 85 "65401" 86 "65410"
                       87 "65411" 88 "65421" 89 "65441" 90 "65451" 91 "65491"
                       92 "65531" 93 "65611" 94 "65621" 95 "65631" 96 "65651"
                       97 "65661" 98 "65671" 99 "65681" 100 "65721"
                       101 "65801" 102 "65810" 103 "65811" 104 "65821"
                       105 "65831" 106 "65881" 107 "65901" 108 "65910"
                       109 "65911" 110 "65931" 111 "65941" 112 "65951"
                       113 "65981" 114 "65991" 115 "66001" 116 "66011"
                       117 "66021" 118 "66031" 119 "66041" 120 "66061"
                       121 "66071" 122 "66091" 123 "66101" 124 "66111"
                       125 "66131" 126 "66201" 127 "66221" 128 "66301"
                       129 "66311" 130 "66321" 131 "66331" 132 "66341"
                       133 "66351" 134 "66361" 135 "66381" 136 "66401"
                       137 "66411" 138 "66414" 139 "66421" 140 "66431"
                       141 "66451" 142 "66481" 143 "66531" 144 "66541"
                       145 "66551" 146 "66557" 147 "66602" 148 "66612"
                       149 "66622" 150 "66712" 151 "66901" 152 "66922"
                       153 "66951" 154 "66981" 155 "67002" 156 "67101"
                       157 "67111" 158 "67182" 159 "67202" 160 "67412"
                       161 "69821" 162 "74881" 163 "0380X" 164 "0410X"
                       165 "0411X" 166 "0414X" 167 "0449X" 168 "07030"
                       169 "0781X" 170 "0798X" 171 "0912X" 172 "0970X"
                       173 "0971X" 174 "0979X" 175 "0980X" 176 "1122X"
                       177 "13101" 178 "1310X" 179 "1748X" 180 "1923X"
                       181 "2181X" 182 "2189X" 183 "270XX" 184 "2780X"
                       185 "2809X" 186 "2825X" 187 "2830X" 188 "2851X"
                       189 "2859X" 190 "2875X" 191 "30520" 192 "30560"
                       193 "3432X" 194 "3439X" 195 "3510X" 196 "4019X"
                       197 "4240X" 198 "4553X" 199 "4556X" 200 "4659X"
                       201 "5185X" 202 "5282X" 203 "5559X" 204 "5680X"
                       205 "5990X" 206 "6159X" 207 "6160X" 208 "6162X"
                       209 "6202X" 210 "6215X" 211 "6238X" 212 "6245X"
                       213 "6410X" 214 "64661" 215 "64821" 216 "64822"
                       217 "64841" 218 "6500X" 219 "650XX" 220 "65581"
                       221 "65841" 222 "65921" 223 "6600X" 224 "66121"
                       225 "6620X" 226 "6640X" 227 "6641X" 228 "6698X"
                       229 "67432" 230 "6924X" 231 "6989X" 232 "7088X"
                       233 "7100X" 234 "7293X" 235 "7533X" 236 "7569X"
                       237 "7807X" 238 "7850X" 239 "7856X" 240 "7882X"
                       241 "7923X" 242 "7958X" 243 "9478X" 244 "9952X"
                       245 "9974X" 246 "9975X" 247 "9981X" 248 "E9387"
                       249 "V016X" 250 "V017X" 251 "V018X" 252 "V025X"
                       253 "V026X" 254 "V043X" 255 "V072X" 256 "V120X"
                       257 "V1581" 258 "V210X" 259 "V233X" 260 "V235X"
                       261 "V237X" 262 "V238X" 263 "V240X" 264 "V252X"
                       265 "V270X" 266 "V272X" 267 "V277X" 268 "V290X"
                       269 "V608X" 270 "V615X" ;
label define M5_06A    -9 "LEGITIMATE SKIP" -1 "NO ABSTRACT DATA" 1 "1581"
                       2 "4100" 3 "5419" 4 "7030" 5 "13100" 6 "13102"
                       7 "23770" 8 "25000" 9 "25001" 10 "28260" 11 "30390"
                       12 "30391" 13 "30500" 14 "30510" 15 "30511" 16 "30551"
                       17 "30561" 18 "30590" 19 "30591" 20 "34590" 21 "43101"
                       22 "47202" 23 "49390" 24 "49391" 25 "53390" 26 "57140"
                       27 "62421" 28 "63331" 29 "63492" 30 "63671" 31 "63801"
                       32 "64001" 33 "64111" 34 "64121" 35 "64191" 36 "64201"
                       37 "64221" 38 "64223" 39 "64231" 40 "64232" 41 "64241"
                       42 "64251" 43 "64261" 44 "64271" 45 "64291" 46 "64361"
                       47 "64381" 48 "64401" 49 "64411" 50 "64421" 51 "64501"
                       52 "64611" 53 "64651" 54 "64662" 55 "64671" 56 "64681"
                       57 "64701" 58 "64711" 59 "64721" 60 "64761" 61 "64781"
                       62 "64782" 63 "64791" 64 "64801" 65 "64811" 66 "64831"
                       67 "64845" 68 "64880" 69 "64881" 70 "64891" 71 "64892"
                       72 "64893" 73 "65101" 74 "65211" 75 "65221" 76 "65231"
                       77 "65241" 78 "65251" 79 "65261" 80 "65281" 81 "65291"
                       82 "65311" 83 "65341" 84 "65391" 85 "65401" 86 "65410"
                       87 "65411" 88 "65421" 89 "65441" 90 "65451" 91 "65491"
                       92 "65531" 93 "65611" 94 "65621" 95 "65631" 96 "65651"
                       97 "65661" 98 "65671" 99 "65681" 100 "65721"
                       101 "65801" 102 "65810" 103 "65811" 104 "65821"
                       105 "65831" 106 "65881" 107 "65901" 108 "65910"
                       109 "65911" 110 "65931" 111 "65941" 112 "65951"
                       113 "65981" 114 "65991" 115 "66001" 116 "66011"
                       117 "66021" 118 "66031" 119 "66041" 120 "66061"
                       121 "66071" 122 "66091" 123 "66101" 124 "66111"
                       125 "66131" 126 "66201" 127 "66221" 128 "66301"
                       129 "66311" 130 "66321" 131 "66331" 132 "66341"
                       133 "66351" 134 "66361" 135 "66381" 136 "66401"
                       137 "66411" 138 "66414" 139 "66421" 140 "66431"
                       141 "66451" 142 "66481" 143 "66531" 144 "66541"
                       145 "66551" 146 "66557" 147 "66602" 148 "66612"
                       149 "66622" 150 "66712" 151 "66901" 152 "66922"
                       153 "66951" 154 "66981" 155 "67002" 156 "67101"
                       157 "67111" 158 "67182" 159 "67202" 160 "67412"
                       161 "69821" 162 "74881" 163 "0380X" 164 "0410X"
                       165 "0411X" 166 "0414X" 167 "0449X" 168 "07030"
                       169 "0781X" 170 "0798X" 171 "0912X" 172 "0970X"
                       173 "0971X" 174 "0979X" 175 "0980X" 176 "1122X"
                       177 "13101" 178 "1310X" 179 "1748X" 180 "1923X"
                       181 "2181X" 182 "2189X" 183 "270XX" 184 "2780X"
                       185 "2809X" 186 "2825X" 187 "2830X" 188 "2851X"
                       189 "2859X" 190 "2875X" 191 "30520" 192 "30560"
                       193 "3432X" 194 "3439X" 195 "3510X" 196 "4019X"
                       197 "4240X" 198 "4553X" 199 "4556X" 200 "4659X"
                       201 "5185X" 202 "5282X" 203 "5559X" 204 "5680X"
                       205 "5990X" 206 "6159X" 207 "6160X" 208 "6162X"
                       209 "6202X" 210 "6215X" 211 "6238X" 212 "6245X"
                       213 "6410X" 214 "64661" 215 "64821" 216 "64822"
                       217 "64841" 218 "6500X" 219 "650XX" 220 "65581"
                       221 "65841" 222 "65921" 223 "6600X" 224 "66121"
                       225 "6620X" 226 "6640X" 227 "6641X" 228 "6698X"
                       229 "67432" 230 "6924X" 231 "6989X" 232 "7088X"
                       233 "7100X" 234 "7293X" 235 "7533X" 236 "7569X"
                       237 "7807X" 238 "7850X" 239 "7856X" 240 "7882X"
                       241 "7923X" 242 "7958X" 243 "9478X" 244 "9952X"
                       245 "9974X" 246 "9975X" 247 "9981X" 248 "E9387"
                       249 "V016X" 250 "V017X" 251 "V018X" 252 "V025X"
                       253 "V026X" 254 "V043X" 255 "V072X" 256 "V120X"
                       257 "V1581" 258 "V210X" 259 "V233X" 260 "V235X"
                       261 "V237X" 262 "V238X" 263 "V240X" 264 "V252X"
                       265 "V270X" 266 "V272X" 267 "V277X" 268 "V290X"
                       269 "V608X" 270 "V615X" ;
label define M5_07A    -9 "LEGITIMATE SKIP" -1 "NO ABSTRACT DATA" 1 "1581"
                       2 "4100" 3 "5419" 4 "7030" 5 "13100" 6 "13102"
                       7 "23770" 8 "25000" 9 "25001" 10 "28260" 11 "30390"
                       12 "30391" 13 "30500" 14 "30510" 15 "30511" 16 "30551"
                       17 "30561" 18 "30590" 19 "30591" 20 "34590" 21 "43101"
                       22 "47202" 23 "49390" 24 "49391" 25 "53390" 26 "57140"
                       27 "62421" 28 "63331" 29 "63492" 30 "63671" 31 "63801"
                       32 "64001" 33 "64111" 34 "64121" 35 "64191" 36 "64201"
                       37 "64221" 38 "64223" 39 "64231" 40 "64232" 41 "64241"
                       42 "64251" 43 "64261" 44 "64271" 45 "64291" 46 "64361"
                       47 "64381" 48 "64401" 49 "64411" 50 "64421" 51 "64501"
                       52 "64611" 53 "64651" 54 "64662" 55 "64671" 56 "64681"
                       57 "64701" 58 "64711" 59 "64721" 60 "64761" 61 "64781"
                       62 "64782" 63 "64791" 64 "64801" 65 "64811" 66 "64831"
                       67 "64845" 68 "64880" 69 "64881" 70 "64891" 71 "64892"
                       72 "64893" 73 "65101" 74 "65211" 75 "65221" 76 "65231"
                       77 "65241" 78 "65251" 79 "65261" 80 "65281" 81 "65291"
                       82 "65311" 83 "65341" 84 "65391" 85 "65401" 86 "65410"
                       87 "65411" 88 "65421" 89 "65441" 90 "65451" 91 "65491"
                       92 "65531" 93 "65611" 94 "65621" 95 "65631" 96 "65651"
                       97 "65661" 98 "65671" 99 "65681" 100 "65721"
                       101 "65801" 102 "65810" 103 "65811" 104 "65821"
                       105 "65831" 106 "65881" 107 "65901" 108 "65910"
                       109 "65911" 110 "65931" 111 "65941" 112 "65951"
                       113 "65981" 114 "65991" 115 "66001" 116 "66011"
                       117 "66021" 118 "66031" 119 "66041" 120 "66061"
                       121 "66071" 122 "66091" 123 "66101" 124 "66111"
                       125 "66131" 126 "66201" 127 "66221" 128 "66301"
                       129 "66311" 130 "66321" 131 "66331" 132 "66341"
                       133 "66351" 134 "66361" 135 "66381" 136 "66401"
                       137 "66411" 138 "66414" 139 "66421" 140 "66431"
                       141 "66451" 142 "66481" 143 "66531" 144 "66541"
                       145 "66551" 146 "66557" 147 "66602" 148 "66612"
                       149 "66622" 150 "66712" 151 "66901" 152 "66922"
                       153 "66951" 154 "66981" 155 "67002" 156 "67101"
                       157 "67111" 158 "67182" 159 "67202" 160 "67412"
                       161 "69821" 162 "74881" 163 "0380X" 164 "0410X"
                       165 "0411X" 166 "0414X" 167 "0449X" 168 "07030"
                       169 "0781X" 170 "0798X" 171 "0912X" 172 "0970X"
                       173 "0971X" 174 "0979X" 175 "0980X" 176 "1122X"
                       177 "13101" 178 "1310X" 179 "1748X" 180 "1923X"
                       181 "2181X" 182 "2189X" 183 "270XX" 184 "2780X"
                       185 "2809X" 186 "2825X" 187 "2830X" 188 "2851X"
                       189 "2859X" 190 "2875X" 191 "30520" 192 "30560"
                       193 "3432X" 194 "3439X" 195 "3510X" 196 "4019X"
                       197 "4240X" 198 "4553X" 199 "4556X" 200 "4659X"
                       201 "5185X" 202 "5282X" 203 "5559X" 204 "5680X"
                       205 "5990X" 206 "6159X" 207 "6160X" 208 "6162X"
                       209 "6202X" 210 "6215X" 211 "6238X" 212 "6245X"
                       213 "6410X" 214 "64661" 215 "64821" 216 "64822"
                       217 "64841" 218 "6500X" 219 "650XX" 220 "65581"
                       221 "65841" 222 "65921" 223 "6600X" 224 "66121"
                       225 "6620X" 226 "6640X" 227 "6641X" 228 "6698X"
                       229 "67432" 230 "6924X" 231 "6989X" 232 "7088X"
                       233 "7100X" 234 "7293X" 235 "7533X" 236 "7569X"
                       237 "7807X" 238 "7850X" 239 "7856X" 240 "7882X"
                       241 "7923X" 242 "7958X" 243 "9478X" 244 "9952X"
                       245 "9974X" 246 "9975X" 247 "9981X" 248 "E9387"
                       249 "V016X" 250 "V017X" 251 "V018X" 252 "V025X"
                       253 "V026X" 254 "V043X" 255 "V072X" 256 "V120X"
                       257 "V1581" 258 "V210X" 259 "V233X" 260 "V235X"
                       261 "V237X" 262 "V238X" 263 "V240X" 264 "V252X"
                       265 "V270X" 266 "V272X" 267 "V277X" 268 "V290X"
                       269 "V608X" 270 "V615X" ;
label define M5_08A    -9 "LEGITIMATE SKIP" -1 "NO ABSTRACT DATA" 1 "1581"
                       2 "4100" 3 "5419" 4 "7030" 5 "13100" 6 "13102"
                       7 "23770" 8 "25000" 9 "25001" 10 "28260" 11 "30390"
                       12 "30391" 13 "30500" 14 "30510" 15 "30511" 16 "30551"
                       17 "30561" 18 "30590" 19 "30591" 20 "34590" 21 "43101"
                       22 "47202" 23 "49390" 24 "49391" 25 "53390" 26 "57140"
                       27 "62421" 28 "63331" 29 "63492" 30 "63671" 31 "63801"
                       32 "64001" 33 "64111" 34 "64121" 35 "64191" 36 "64201"
                       37 "64221" 38 "64223" 39 "64231" 40 "64232" 41 "64241"
                       42 "64251" 43 "64261" 44 "64271" 45 "64291" 46 "64361"
                       47 "64381" 48 "64401" 49 "64411" 50 "64421" 51 "64501"
                       52 "64611" 53 "64651" 54 "64662" 55 "64671" 56 "64681"
                       57 "64701" 58 "64711" 59 "64721" 60 "64761" 61 "64781"
                       62 "64782" 63 "64791" 64 "64801" 65 "64811" 66 "64831"
                       67 "64845" 68 "64880" 69 "64881" 70 "64891" 71 "64892"
                       72 "64893" 73 "65101" 74 "65211" 75 "65221" 76 "65231"
                       77 "65241" 78 "65251" 79 "65261" 80 "65281" 81 "65291"
                       82 "65311" 83 "65341" 84 "65391" 85 "65401" 86 "65410"
                       87 "65411" 88 "65421" 89 "65441" 90 "65451" 91 "65491"
                       92 "65531" 93 "65611" 94 "65621" 95 "65631" 96 "65651"
                       97 "65661" 98 "65671" 99 "65681" 100 "65721"
                       101 "65801" 102 "65810" 103 "65811" 104 "65821"
                       105 "65831" 106 "65881" 107 "65901" 108 "65910"
                       109 "65911" 110 "65931" 111 "65941" 112 "65951"
                       113 "65981" 114 "65991" 115 "66001" 116 "66011"
                       117 "66021" 118 "66031" 119 "66041" 120 "66061"
                       121 "66071" 122 "66091" 123 "66101" 124 "66111"
                       125 "66131" 126 "66201" 127 "66221" 128 "66301"
                       129 "66311" 130 "66321" 131 "66331" 132 "66341"
                       133 "66351" 134 "66361" 135 "66381" 136 "66401"
                       137 "66411" 138 "66414" 139 "66421" 140 "66431"
                       141 "66451" 142 "66481" 143 "66531" 144 "66541"
                       145 "66551" 146 "66557" 147 "66602" 148 "66612"
                       149 "66622" 150 "66712" 151 "66901" 152 "66922"
                       153 "66951" 154 "66981" 155 "67002" 156 "67101"
                       157 "67111" 158 "67182" 159 "67202" 160 "67412"
                       161 "69821" 162 "74881" 163 "0380X" 164 "0410X"
                       165 "0411X" 166 "0414X" 167 "0449X" 168 "07030"
                       169 "0781X" 170 "0798X" 171 "0912X" 172 "0970X"
                       173 "0971X" 174 "0979X" 175 "0980X" 176 "1122X"
                       177 "13101" 178 "1310X" 179 "1748X" 180 "1923X"
                       181 "2181X" 182 "2189X" 183 "270XX" 184 "2780X"
                       185 "2809X" 186 "2825X" 187 "2830X" 188 "2851X"
                       189 "2859X" 190 "2875X" 191 "30520" 192 "30560"
                       193 "3432X" 194 "3439X" 195 "3510X" 196 "4019X"
                       197 "4240X" 198 "4553X" 199 "4556X" 200 "4659X"
                       201 "5185X" 202 "5282X" 203 "5559X" 204 "5680X"
                       205 "5990X" 206 "6159X" 207 "6160X" 208 "6162X"
                       209 "6202X" 210 "6215X" 211 "6238X" 212 "6245X"
                       213 "6410X" 214 "64661" 215 "64821" 216 "64822"
                       217 "64841" 218 "6500X" 219 "650XX" 220 "65581"
                       221 "65841" 222 "65921" 223 "6600X" 224 "66121"
                       225 "6620X" 226 "6640X" 227 "6641X" 228 "6698X"
                       229 "67432" 230 "6924X" 231 "6989X" 232 "7088X"
                       233 "7100X" 234 "7293X" 235 "7533X" 236 "7569X"
                       237 "7807X" 238 "7850X" 239 "7856X" 240 "7882X"
                       241 "7923X" 242 "7958X" 243 "9478X" 244 "9952X"
                       245 "9974X" 246 "9975X" 247 "9981X" 248 "E9387"
                       249 "V016X" 250 "V017X" 251 "V018X" 252 "V025X"
                       253 "V026X" 254 "V043X" 255 "V072X" 256 "V120X"
                       257 "V1581" 258 "V210X" 259 "V233X" 260 "V235X"
                       261 "V237X" 262 "V238X" 263 "V240X" 264 "V252X"
                       265 "V270X" 266 "V272X" 267 "V277X" 268 "V290X"
                       269 "V608X" 270 "V615X" ;
label define M5_09A    -9 "LEGITIMATE SKIP" -1 "NO ABSTRACT DATA" 1 "1581"
                       2 "4100" 3 "5419" 4 "7030" 5 "13100" 6 "13102"
                       7 "23770" 8 "25000" 9 "25001" 10 "28260" 11 "30390"
                       12 "30391" 13 "30500" 14 "30510" 15 "30511" 16 "30551"
                       17 "30561" 18 "30590" 19 "30591" 20 "34590" 21 "43101"
                       22 "47202" 23 "49390" 24 "49391" 25 "53390" 26 "57140"
                       27 "62421" 28 "63331" 29 "63492" 30 "63671" 31 "63801"
                       32 "64001" 33 "64111" 34 "64121" 35 "64191" 36 "64201"
                       37 "64221" 38 "64223" 39 "64231" 40 "64232" 41 "64241"
                       42 "64251" 43 "64261" 44 "64271" 45 "64291" 46 "64361"
                       47 "64381" 48 "64401" 49 "64411" 50 "64421" 51 "64501"
                       52 "64611" 53 "64651" 54 "64662" 55 "64671" 56 "64681"
                       57 "64701" 58 "64711" 59 "64721" 60 "64761" 61 "64781"
                       62 "64782" 63 "64791" 64 "64801" 65 "64811" 66 "64831"
                       67 "64845" 68 "64880" 69 "64881" 70 "64891" 71 "64892"
                       72 "64893" 73 "65101" 74 "65211" 75 "65221" 76 "65231"
                       77 "65241" 78 "65251" 79 "65261" 80 "65281" 81 "65291"
                       82 "65311" 83 "65341" 84 "65391" 85 "65401" 86 "65410"
                       87 "65411" 88 "65421" 89 "65441" 90 "65451" 91 "65491"
                       92 "65531" 93 "65611" 94 "65621" 95 "65631" 96 "65651"
                       97 "65661" 98 "65671" 99 "65681" 100 "65721"
                       101 "65801" 102 "65810" 103 "65811" 104 "65821"
                       105 "65831" 106 "65881" 107 "65901" 108 "65910"
                       109 "65911" 110 "65931" 111 "65941" 112 "65951"
                       113 "65981" 114 "65991" 115 "66001" 116 "66011"
                       117 "66021" 118 "66031" 119 "66041" 120 "66061"
                       121 "66071" 122 "66091" 123 "66101" 124 "66111"
                       125 "66131" 126 "66201" 127 "66221" 128 "66301"
                       129 "66311" 130 "66321" 131 "66331" 132 "66341"
                       133 "66351" 134 "66361" 135 "66381" 136 "66401"
                       137 "66411" 138 "66414" 139 "66421" 140 "66431"
                       141 "66451" 142 "66481" 143 "66531" 144 "66541"
                       145 "66551" 146 "66557" 147 "66602" 148 "66612"
                       149 "66622" 150 "66712" 151 "66901" 152 "66922"
                       153 "66951" 154 "66981" 155 "67002" 156 "67101"
                       157 "67111" 158 "67182" 159 "67202" 160 "67412"
                       161 "69821" 162 "74881" 163 "0380X" 164 "0410X"
                       165 "0411X" 166 "0414X" 167 "0449X" 168 "07030"
                       169 "0781X" 170 "0798X" 171 "0912X" 172 "0970X"
                       173 "0971X" 174 "0979X" 175 "0980X" 176 "1122X"
                       177 "13101" 178 "1310X" 179 "1748X" 180 "1923X"
                       181 "2181X" 182 "2189X" 183 "270XX" 184 "2780X"
                       185 "2809X" 186 "2825X" 187 "2830X" 188 "2851X"
                       189 "2859X" 190 "2875X" 191 "30520" 192 "30560"
                       193 "3432X" 194 "3439X" 195 "3510X" 196 "4019X"
                       197 "4240X" 198 "4553X" 199 "4556X" 200 "4659X"
                       201 "5185X" 202 "5282X" 203 "5559X" 204 "5680X"
                       205 "5990X" 206 "6159X" 207 "6160X" 208 "6162X"
                       209 "6202X" 210 "6215X" 211 "6238X" 212 "6245X"
                       213 "6410X" 214 "64661" 215 "64821" 216 "64822"
                       217 "64841" 218 "6500X" 219 "650XX" 220 "65581"
                       221 "65841" 222 "65921" 223 "6600X" 224 "66121"
                       225 "6620X" 226 "6640X" 227 "6641X" 228 "6698X"
                       229 "67432" 230 "6924X" 231 "6989X" 232 "7088X"
                       233 "7100X" 234 "7293X" 235 "7533X" 236 "7569X"
                       237 "7807X" 238 "7850X" 239 "7856X" 240 "7882X"
                       241 "7923X" 242 "7958X" 243 "9478X" 244 "9952X"
                       245 "9974X" 246 "9975X" 247 "9981X" 248 "E9387"
                       249 "V016X" 250 "V017X" 251 "V018X" 252 "V025X"
                       253 "V026X" 254 "V043X" 255 "V072X" 256 "V120X"
                       257 "V1581" 258 "V210X" 259 "V233X" 260 "V235X"
                       261 "V237X" 262 "V238X" 263 "V240X" 264 "V252X"
                       265 "V270X" 266 "V272X" 267 "V277X" 268 "V290X"
                       269 "V608X" 270 "V615X" ;
label define M5_10A    -9 "LEGITIMATE SKIP" -1 "NO ABSTRACT DATA" 1 "1581"
                       2 "4100" 3 "5419" 4 "7030" 5 "13100" 6 "13102"
                       7 "23770" 8 "25000" 9 "25001" 10 "28260" 11 "30390"
                       12 "30391" 13 "30500" 14 "30510" 15 "30511" 16 "30551"
                       17 "30561" 18 "30590" 19 "30591" 20 "34590" 21 "43101"
                       22 "47202" 23 "49390" 24 "49391" 25 "53390" 26 "57140"
                       27 "62421" 28 "63331" 29 "63492" 30 "63671" 31 "63801"
                       32 "64001" 33 "64111" 34 "64121" 35 "64191" 36 "64201"
                       37 "64221" 38 "64223" 39 "64231" 40 "64232" 41 "64241"
                       42 "64251" 43 "64261" 44 "64271" 45 "64291" 46 "64361"
                       47 "64381" 48 "64401" 49 "64411" 50 "64421" 51 "64501"
                       52 "64611" 53 "64651" 54 "64662" 55 "64671" 56 "64681"
                       57 "64701" 58 "64711" 59 "64721" 60 "64761" 61 "64781"
                       62 "64782" 63 "64791" 64 "64801" 65 "64811" 66 "64831"
                       67 "64845" 68 "64880" 69 "64881" 70 "64891" 71 "64892"
                       72 "64893" 73 "65101" 74 "65211" 75 "65221" 76 "65231"
                       77 "65241" 78 "65251" 79 "65261" 80 "65281" 81 "65291"
                       82 "65311" 83 "65341" 84 "65391" 85 "65401" 86 "65410"
                       87 "65411" 88 "65421" 89 "65441" 90 "65451" 91 "65491"
                       92 "65531" 93 "65611" 94 "65621" 95 "65631" 96 "65651"
                       97 "65661" 98 "65671" 99 "65681" 100 "65721"
                       101 "65801" 102 "65810" 103 "65811" 104 "65821"
                       105 "65831" 106 "65881" 107 "65901" 108 "65910"
                       109 "65911" 110 "65931" 111 "65941" 112 "65951"
                       113 "65981" 114 "65991" 115 "66001" 116 "66011"
                       117 "66021" 118 "66031" 119 "66041" 120 "66061"
                       121 "66071" 122 "66091" 123 "66101" 124 "66111"
                       125 "66131" 126 "66201" 127 "66221" 128 "66301"
                       129 "66311" 130 "66321" 131 "66331" 132 "66341"
                       133 "66351" 134 "66361" 135 "66381" 136 "66401"
                       137 "66411" 138 "66414" 139 "66421" 140 "66431"
                       141 "66451" 142 "66481" 143 "66531" 144 "66541"
                       145 "66551" 146 "66557" 147 "66602" 148 "66612"
                       149 "66622" 150 "66712" 151 "66901" 152 "66922"
                       153 "66951" 154 "66981" 155 "67002" 156 "67101"
                       157 "67111" 158 "67182" 159 "67202" 160 "67412"
                       161 "69821" 162 "74881" 163 "0380X" 164 "0410X"
                       165 "0411X" 166 "0414X" 167 "0449X" 168 "07030"
                       169 "0781X" 170 "0798X" 171 "0912X" 172 "0970X"
                       173 "0971X" 174 "0979X" 175 "0980X" 176 "1122X"
                       177 "13101" 178 "1310X" 179 "1748X" 180 "1923X"
                       181 "2181X" 182 "2189X" 183 "270XX" 184 "2780X"
                       185 "2809X" 186 "2825X" 187 "2830X" 188 "2851X"
                       189 "2859X" 190 "2875X" 191 "30520" 192 "30560"
                       193 "3432X" 194 "3439X" 195 "3510X" 196 "4019X"
                       197 "4240X" 198 "4553X" 199 "4556X" 200 "4659X"
                       201 "5185X" 202 "5282X" 203 "5559X" 204 "5680X"
                       205 "5990X" 206 "6159X" 207 "6160X" 208 "6162X"
                       209 "6202X" 210 "6215X" 211 "6238X" 212 "6245X"
                       213 "6410X" 214 "64661" 215 "64821" 216 "64822"
                       217 "64841" 218 "6500X" 219 "650XX" 220 "65581"
                       221 "65841" 222 "65921" 223 "6600X" 224 "66121"
                       225 "6620X" 226 "6640X" 227 "6641X" 228 "6698X"
                       229 "67432" 230 "6924X" 231 "6989X" 232 "7088X"
                       233 "7100X" 234 "7293X" 235 "7533X" 236 "7569X"
                       237 "7807X" 238 "7850X" 239 "7856X" 240 "7882X"
                       241 "7923X" 242 "7958X" 243 "9478X" 244 "9952X"
                       245 "9974X" 246 "9975X" 247 "9981X" 248 "E9387"
                       249 "V016X" 250 "V017X" 251 "V018X" 252 "V025X"
                       253 "V026X" 254 "V043X" 255 "V072X" 256 "V120X"
                       257 "V1581" 258 "V210X" 259 "V233X" 260 "V235X"
                       261 "V237X" 262 "V238X" 263 "V240X" 264 "V252X"
                       265 "V270X" 266 "V272X" 267 "V277X" 268 "V290X"
                       269 "V608X" 270 "V615X" ;
label define XM6DIS    -1 "NO ABSTRACT DATA" ;
label define M7DISPO   -8 "MISSING" -1 "NO ABSTRACT DATA" 1 "SENT HOME"
                       2 "TRANSFERRED TO OTHER HOSPITAL" 3 "MATERNAL DEATH"
                       8 "OTHER" ;
label define M8REFER   -8 "MISSING" -1 "ABSTRACT DATA" 1 "YES" 2 "NO" ;
label define M8_OTH    -9 "LEGITIMATE SKIP" -8 "MISSING"
                       -1 "NO ABSTRACT DATA" 10 "COCAINE" 11 "CRACK" ;
label define M9LABOR   -8 "MISSING" -1 "NO ABSTRACT DATA" 1 "YES" 2 "NO" ;
label define M10DEL    -1 "NO ABSTRACT DATA" 1 "VAGINAL DELIVERY"
                       2 "CESAREAN SECTION," 3 "CESAREAN SECTION, EMERGENCY"
                       4 "CESAREAN SECTION, UNSPECIFIED" 8 "OTHER" ;
label define M11ANEM   -8 "MISSING" -1 "NO ABSTRACT DATA" 1 "YES" 2 "NO" ;
label define M12GES    -8 "MISSING" -1 "NO ABSTRACT DATA" 1 "YES" 2 "NO" ;
label define M13DIA    -8 "MISSING" -1 "NO ABSTRACT DATA" 1 "YES" 2 "NO" ;
label define M14HRT    -8 "MISSING" -1 "NO ABSTRACT DATA" 1 "YES" 2 "NO" ;
label define M15HIV    -8 "MISSING" -1 "NO ABSTRACT DATA" 1 "YES" 2 "NO" ;
label define M16HYP    -8 "MISSING" -1 "NO ABSTRACT DATA" 1 "YES" 2 "NO" ;
label define M17SKL    -8 "MISSING" -1 "NO ABSTRACT DATA" 1 "YES" 2 "NO" ;
label define M18STD    -8 "MISSING" -1 "NO ABSTRACT DATA" 1 "YES" 2 "NO" ;
label define M19ACAF   -8 "MISSING" -1 "NO ABSTRACT DATA" 1 "YES" 2 "NO" ;
label define M19BTOB   -8 "MISSING" -1 "NO ABSTRACT DATA" 1 "YES" 2 "NO" ;
label define M19CMAR   -8 "MISSING" -1 "NO ABSTRACT DATA" 1 "YES" 2 "NO" ;
label define M19DALC   -8 "MISSING" -1 "NO ABSTRACT DATA" 1 "YES" 2 "NO" ;
label define M19EAMP   -8 "MISSING" -1 "NO ABSTRACT DATA" 1 "YES" 2 "NO" ;
label define M19FHER   -8 "MISSING" -1 "NO ABSTRACT DATA" 1 "YES" 2 "NO" ;
label define M19GOPI   -8 "MISSING" -1 "NO ABSTRACT DATA" 1 "ES" 2 "NO" ;
label define M19HMET   -8 "MISSING" -1 "NO ABSTRACT DATA" 1 "YES" 2 "NO" ;
label define M19ICRK   -8 "MISSING" -1 "NO ABSTRACT DATA" 1 "YES" 2 "NO" ;
label define M19JCOC   -8 "MISSING" -1 "NO ABSTRACT DATA" 1 "YES" 2 "NO" ;
label define M19KPCP   -8 "MISSING" -1 "NO ABSTRACT DATA" 1 "YES" 2 "NO" ;
label define M20EVID   -1 "NO ABSTRACT DATA" 1 "YES" 2 "NO" ;
label define M21ARSLT  -9 "LEGITIMATE SKIP" -8 "MISSING"
                       -1 "NO ABSTRACT DATA" 1 "CONFIRMED POSITIVE"
                       2 "NEGATIVE" ;
label define M21BRSLT  -9 "LEGITIMATE SKIP" -8 "MISSING"
                       -1 "NO ABSTRACT DATA" 1 "CONFIRMED POSITIVE"
                       2 "NEGATIVE" ;
label define M21CRSLT  -9 "LEGITIMATE SKIP" -8 "MISSING"
                       -1 "NO ABSTRACT DATA" 1 "CONFIRMED POSITIVE"
                       2 "NEGATIVE" ;
label define M21DRSLT  -9 "LEGITIMATE SKIP" -8 "MISSING"
                       -1 "NO ABSTRACT DATA" 1 "CONFIRMED POSITIVE"
                       2 "NEGATIVE" ;
label define M21ERSLT  -9 "LEGITIMATE SKIP" -8 "MISSING"
                       -1 "NO ABSTRACT DATA" 1 "CONFIRMED POSITIVE"
                       2 "NEGATIVE" ;
label define MBOXA_A1  -1 "NO ABSTRACT DATA" ;
label define MBOXA_A2  -8 "MISSING" -1 "NO ABSTRACT DATA" 1 "YES" 2 "NO" ;
label define MSPECPRO  -1 "NO ABSTRACT DATA"
                       1 "YES, THERE WERE SPECIAL PROBLEMS"
                       2 "NO, THERE AREN'T ANY SPECIAL PROBLEMS" ;
label define M5CNTR    -1 "NO ABSTRACT DATA" ;
label define A_EDUC    -9 "LEGITIMATE SKIP" -8 "MISSING"
                       1 "LESS THAN HIGH SCHOOL" 2 "HIGH SCHOOL GRADUATE"
                       3 "SOME COLLEGE" 4 "COLLEGE GRADUATE" ;
label define AGE       -8 "MISSING" -7 "ITEM REFUSAL" -5 "DATA OUT OF RANGE"
                       1 "12-17 YEARS" 2 "18-25 YEARS" 3 "26-34 YEARS"
                       4 "35+ YEARS" ;
label define AGE_YR    -8 "MISSING" -7 "ITEM REFUSAL" -5 "DATA OUT OF RANGE" ;
label define ALC_AMT   -8 "MISSING" ;
label define ALC_AMT3  1 "NONE" 2 "UP TO 0.5 DRINK PER DAY"
                       3 "1/2 TO 1 DRINK PER DAY" 4 "UNKNOWN" ;
label define ALC_CAT   -8 "MISSING" 1 "NO ALCOHOL USE DURING PREGNANCY"
                       2 "LIGHT ALCOHOL USE DURING PREGNANCY"
                       3 "MODERATE/HEAVY" ;
label define ALC_DAY   -8 "MISSING" ;
label define ALCFLAG   -8 "MISSING" 0 "NO" 1 "YES" ;
label define ALCMON    -8 "MISSING" 0 "NO" 1 "YES" ;
label define ALCPREG   -8 "MISSING" 0 "NO" 1 "YES" ;
label define ALCYR     -8 "MISSING" 0 "NO" 1 "YES" ;
label define ANYBWG    -8 "MISSING" -4 "DON'T KNOW"
                       1 "NORMAL BIRTHWEIGHT, TERM"
                       2 "NORMAL BIRTHWEIGHT, PRETERM"
                       3 "LOW BIRTHWEIGHT, TERM" 4 "LOW BIRTHWEIGHT, PRETERM" ;
label define ANYBWT    -8 "MISSING" 1 "NORMAL" 2 "INTERMEDIATE" 3 "VERY LOW" ;
label define ANYCARE   1 "ANY PRENATAL CARE" 2 "LATE OR NO PRENATAL CARE" ;
label define ANYFLAG   -8 "MISSING" 0 "NO" 1 "YES" ;
label define ANYMON    -8 "MISSING" 0 "NO" 1 "YES" ;
label define ANYPREG   0 "NO" 1 "YES" ;
label define ANYYR     -8 "MISSING" 0 "NO" 1 "YES" ;
label define AV_ETHAN  -8 "MISSING" 0 "LESS THAN 1.00 OUNCE DAILY"
                       1 "BETWEEN 1.00 AND 1.99 OUNCES DAILY"
                       2 "BETWEEN 2.00 AND 2.99 OUNCES DAILY"
                       3 "MORE THAN 3.00 OUNCES DAILY" ;
label define BIRTHWT   -8 "MISSING" 1 "NORMAL" 2 "INTERMEDIATE" 3 "VERY LOW" ;
label define BW_GEST   -9 "LEGITIMATE SKIP" -8 "MISSING" -4 "MISSING"
                       1 "NORMAL BIRTHWEIGHT, TERM"
                       2 "NORMAL BIRTHWEIGHT, PRETERM"
                       3 "LOW BIRTHWEIGHT, TERM" 4 "LOW BIRTHWEIGHT, PRETERM" ;
label define BWGRAMS   -8 "MISSING" ;
label define CIG_AMT   -8 "MISSING" 1 "NONE" 2 "LESS THAN 1 PACK/DAY"
                       3 "1 PACK/DAY OR MORE" ;
label define CIGFLAG   0 "NO" 1 "YES" ;
label define CIGMON    0 "NO" 1 "YES" ;
label define CIGPREG   0 "NO" 1 "YES" ;
label define CIGYR     0 "NO" 1 "YES" ;
label define COCFLAG   -8 "MISSING" 0 "NO" 1 "YES" ;
label define COCMON    -8 "MISSING" 0 "NO" 1 "YES" ;
label define COCPREG   -8 "MISSING" 0 "NO" 1 "YES" ;
label define COCYR     -8 "MISSING" 0 "NO" 1 "YES" ;
label define COO_FRQ   -8 "MISSING" 1 "NONE" 2 "LESS THAN WEEKLY"
                       3 "WEEKLY OR MORE" ;
label define COOFLAG   -8 "MISSING" 0 "NO" 1 "YES" ;
label define COOMON    -8 "MISSING" 0 "NO" 1 "YES" ;
label define COOPREG   -8 "MISSING" 0 "NO" 1 "YES" ;
label define COOYR     -8 "MISSING" 0 "NO" 1 "YES" ;
label define CONTRA    -8 "MISSING" -4 "DON'T KNOW" 1 "NONE"
                       2 "BIRTH CONTROL PILL" 3 "CONDOM" 4 "OTHER TYPE" ;
label define CRK_FRQ   -8 "MISSING" 1 "NONE" 2 "LESS THAN WEEKLY"
                       3 "WEEKLY OR MORE" ;
label define CRKFLAG   -8 "MISSING" 0 "NO" 1 "YES" ;
label define CRKMON    -8 "MISSING" 0 "NO" 1 "YES" ;
label define CRKPREG   -8 "MISSING" 0 "NO" 1 "YES" ;
label define CRKYR     -8 "MISSING" 0 "NO" 1 "YES" ;
label define G3_GOVT   1 "ANY GOVERNMENT SOURCE OF INCOME"
                       2 "NO GOVERNMENT SOURCE OF INCOME" ;
label define G3_NONE   1 "NO SOURCE OF INCOME" 2 "ANY SOURCE OF INCOME NOTED" ;
label define G3_OTH    1 "ANY OTHER SOURCE OF INCOME"
                       2 "NO OTHER SOURCE OF INCOME NOTED" ;
label define GESTAGE   -9 "LEGITIMATE SKIP" -8 "MISSING" -4 "DON'T KNOW"
                       1 "TERM" 2 "PRETERM" ;
label define HERFLAG   -8 "MISSING" 0 "NO" 1 "YES" ;
label define HERMON    -8 "MISSING" 0 "NO" 1 "YES" ;
label define HERPREG   -8 "MISSING" 0 "NO" 1 "YES" ;
label define HERYR     -8 "MISSING" 0 "NO" 1 "YES" ;
label define HH_INC    -8 "MISSING" -7 "REFUSAL" -4 "DON'T KNOW"
                       1 "UNDER $5,000" 2 "$5,000 $10,600"
                       3 "$10,601-$19,000" 4 "$19,001- $30,000"
                       5 "$30,001-$50,000" 6 "OVER $50,000" ;
label define HH_SIZ18  -8 "MISSING" -5 "NO PEOPLE UNDER 18" -4 "DON'T KNOW"
                       1 "1 PERSON" 2 "2 PEOPLE" 3 "3 PEOPLE"
                       4 "4 OR MORE PEOPLE" ;
label define HH_SIZE   -8 "MISSING" -2 "RESPONSE ILLEGIBLE" 1 "2 PEOPLE"
                       2 "3 PEOPLE" 3 "4 PEOPLE" 4 "5 PEOPLE"
                       5 "6 OR MORE PEOPLE" ;
label define HRDPRG    -8 "MISSING" 1 "NONE" 2 "LESS THAN WEEKLY"
                       3 "WEEKLY OR MORE" ;
label define M_ANEMIA  -1 "NO ABSTRACT DATA" 1 "NOTED IN CHART"
                       2 "NOT NOTED IN CHART" ;
label define M_DRUG    -1 "NO ABSTRACT DATA" 1 "NOTED IN CHART"
                       2 "NOT NOTED IN CHART" ;
label define M_FDIS    -1 "NO ABSTRACT DATA" 1 "NOTED IN CHART"
                       2 "NOT NOTED IN CHART" ;
label define M_GUI     -1 "NO ABSTRACT DATA" 1 "NOTED IN CHART"
                       2 "NOT NOTED IN CHART" ;
label define M_HYPER   -1 "NO ABSTRACT DATA" 1 "NOTED IN CHART"
                       2 "NOT NOTED IN CHART" ;
label define M_IPC     -1 "NO ABSTRACT DATA" 1 "NOTED IN CHART"
                       2 "NOT NOTED IN CHART" ;
label define M_MENTAL  -1 "NO ABSTRACT DATA" 1 "NOTED IN CHART"
                       2 "NOT NOTED IN CHART" ;
label define M_RUPT    -1 "NO ABSTRACT DATA" 1 "NOTED IN CHART"
                       2 "NOT NOTED IN CHART" ;
label define M_VD      -1 "NO ABSTRACT DATA" 1 "NOTED IN CHART"
                       2 "NOT NOTED IN CHART" ;
label define MARITAL   -8 "MISSING" -7 "ITEM REFUSAL" -6 "MULTIPLE RESPONSE"
                       1 "SINGLE" 2 "MARRIED" 3 "WIDOWED/DIVORCED/SEPARATED" ;
label define MET_PAY   -8 "MISSING" -7 "ITEM REFUSAL" 1 "PRIVATE INSURANCE"
                       2 "MEDICAL" 3 "HMO" 4 "OTHER OR UNKNOWN" ;
label define MED_USE   -8 "MISSING" 1 "ANTIBIOTIC USE DURING PREGNANCY"
                       2 "NO ANTIBIOTIC USE DURING PREGNANCY" ;
label define MRJ_FRQ   -8 "MISSING" -5 "DATA OUT OF RANGE" 1 "NONE"
                       2 "LESS THAN WEEKLY" 3 "WEEKLY OR MORE" ;
label define MRJFLAG   -8 "MISSING" 0 "NO" 1 "YES" ;
label define MRJMON    -8 "MISSING" 0 "NO" 1 "YES" ;
label define MRJPREG   -8 "MISSING" -5 "DATA OUT OF RANGE" 0 "NO" 1 "YES" ;
label define MRJYR     -8 "MISSING" 0 "NO" 1 "YES" ;
label define NOMJFLAG  -8 "MISSING" 0 "NO" 1 "YES" ;
label define NOMJMON   -8 "MISSING" 0 "NO" 1 "YES" ;
label define NOMJPREG  0 "NO" 1 "YES" ;
label define NOMJYR    -8 "MISSING" 0 "NO" 1 "YES" ;
label define PARITY    -8 "MISSING" 1 "NO PREVIOUS LIVE BIRTHS"
                       2 "ONE PREVIOUS LIVE BIRTH"
                       3 "TWO OR MORE PREVIOUS LIVE BIRTHS" ;
label define PDRINK    -8 "MISSING" 0 "LESS THAN 100% PROBABILITY"
                       1 "100% PROBABILITY" ;
label define PN_CARE   1 "NO PRENATAL CARE" 2 "PRIVATE MD" 3 "HMO"
                       4 "HOSPITAL OUTPATIENT CLINIC"
                       5 "HEALTH DEPT/COMMUNITY CLINIC"
                       6 "OTHER OR UNKNOWN FACILITY" ;
label define PN_NUM    1 "NO PRENATAL CARE" 2 "LESS THAN ONCE/MONTH"
                       3 "AT LEAST ONCE/MONTH, BUT NOT MORE"
                       4 "TWICE/MONTH OR MORE" 5 "UNKNOWN NUMBER OF VISITS" ;
label define PN_TRI    -9 "LEGITIMATE SKIP" -8 "MISSING"
                       -5 "DATA OUT OF RANGE" -4 "DON'T KNOW"
                       1 "FIRST TRIMESTER" 2 "SECOND TRIMESTER"
                       3 "THIRD TRIMESTER" ;
label define PN_WK     -9 "LEGITIMATE SKIP" -8 "MISSING"
                       -5 "DATA OUT OF RANGE" -4 "DON'T KNOW" ;
label define PR_USE3   -8 "MISSING" 1 "NO DRUG, ALCOHOL, OR CIGARETTE USE"
                       2 "ALCOHOL AND/OR ALCOHOL USE, BUT NO DRUG USE"
                       3 "DRUG USE, WITH OR W/O CIGARETTES OR ALCOHOL" ;
label define PR_USE8   -8 "MISSING" 1 "NO DRUG, ALCOHOL, OR CIGARETTE USE"
                       2 "NO DRUG OR ALCOHOL USE, BUT CIGARETTE USE"
                       3 "NO DRUG OR CIGARETTE USE, BUT ALCOHOL USE"
                       4 "NO DRUG USE, BUT BOTH ALCHL AND CIGARETTE USE"
                       5 "DRUG USE, BUT NO ALCOHOL OR CIGARETTE USE"
                       6 "DRUG AND CIGARETTE USE, BUT NO ALCOHOL USE"
                       7 "DRUG AND ALCOHOL USE, BUT NO CIGARETTE USE"
                       8 "DRUG, ALCOHOL, AND CIGARETTE USE" ;
label define PSYFLAG   -8 "MISSING" 0 "NO" 1 "YES" ;
label define PSYMON    -8 "MISSING" 0 "NO" 1 "YES" ;
label define PSYPREG   0 "NO" 1 "YES" ;
label define PSYYR     -8 "MISSING" 0 "NO" 1 "YES" ;
label define R1BIRT    -9 "LEGITIMATE SKIP" -8 "MISSING"
                       1 "VERY LOW BIRTHWEIGHT" 2 "NORMAL BIRTHWEIGHT" ;
label define R2BIRT    -9 "LEGITIMATE SKIP" -8 "MISSING"
                       1 "INTERMEDIATE LOW BIRTHWEIGHT"
                       2 "NORMAL BIRTHWEIGHT" ;
label define R3BIRT    -8 "MISSING" 1 "LOW BIRTHWEIGHT"
                       2 "NORMAL BIRTHWEIGHT" ;
label define RACE      -8 "MISSING" -6 "MULTIPLE RESPONSE" 1 "WHITE"
                       2 "BLACK" 3 "HISPANIC" 4 "OTHER" ;
label define RESIDE    1 "DC RESIDENT" 2 "NON-DC RESIDENT" ;
label define RISKLEV2  -8 "MISSING" -5 "DATA OUT OF RANGE" 1 "HIGH RISK BABY"
                       2 "LOW RISK BABY" ;
label define STAFLAG   -8 "MISSING" 0 "NO" 1 "YES" ;
label define STAMON    -8 "MISSING" 0 "NO" 1 "YES" ;
label define STAPREG   0 "NO" 1 "YES" ;
label define STAYR     -8 "MISSING" 0 "NO" 1 "YES" ;
label define STATUS    1 "NON-INTERVIEW"
                       2 "NO ABSTRACT DATA-COMPLETED INTER."
                       3 "MOTHER AND BABY ABSTRACT-COMPLETED INTER."
                       4 "MOTHER ABSTRACT ONLY-COMPLETED INTER." ;
label define STMFLAG   -8 "MISSING" 0 "NO" 1 "YES" ;
label define STMMON    -8 "MISSING" 0 "NO" 1 "YES" ;
label define STMPREG   -8 "MISSING" 0 "NO" 1 "YES" ;
label define STMYR     -8 "MISSING" 0 "NO" 1 "YES" ;
label define TWINS     1 "YES" 2 "NO" ;
label define XAGE      -8 "MISSING" -7 "ITEM REFUSAL" -5 "DATA OUT OF RANGE"
                       1 "12-17 YEARS" 2 "18-25 YEARS" 3 "26-34 YEARS"
                       4 "35+YEARS" ;
label define I_COC     -8 "MISSING" -1 "NO ABSTRACT DATA" 1 "NOTED IN CHART"
                       2 "NOT NOTED IN CHART" ;
label define I_DRUG    -8 "MISSING" -1 "NO ABSTRACT DATA" 1 "NOTED IN CHART"
                       2 "NOT NOTED IN CHART" ;
label define I_INF     -8 "MISSING" -1 "NO ABSTRACT DATA" 1 "NOTED IN CHART"
                       2 "NOT NOTED IN CHART" ;
label define I_JAUND   -8 "MISSING" -1 "NO ABSTRACT DATA" 1 "NOTED IN CHART"
                       2 "NOT NOTED IN CHART" ;
label define I_RDS     -8 "MISSING" -1 "NO ABSTRACT DATA" 1 "NOTED IN CHART"
                       2 "NOT NOTED IN CHART" ;
label define I_RESP    -8 "MISSING" -1 "NO ABSTRACT DATA" 1 "NOTED IN CHART"
                       2 "NOT NOTED IN CHART" ;
label define I_VENT    -8 "MISSING" -1 "NO ABSTRACT DATA" 1 "NOTED IN CHART"
                       2 "NOT NOTED IN CHART" ;
label define IBCOMPMN  -8 "MISSING" -1 "NO ABSTRACT DATA" ;
label define IINFNUM   -8 "MISSING" -1 "NO ABSTRACT DATA" ;
label define ITOTNUM   -8 "MISSING" -1 "NO ABSTRACT DATA" ;
label define IB2RACE   -8 "MISSING" -1 "NO ABSTRACT DATA" 1 "WHITE"
                       2 "BLACK/AFRICAN AMERICAN" 3 "ASIAN/PACIFIC ISLANDER"
                       4 "ALEUT/ESKIMO/AMERICAN INDIAN" 8 "OTHER" ;
label define IB2_OTH   -9 "LEGITIMATE SKIP" -8 "MISSING"
                       -1 "NO ABSTRACT DATA" 10 "LATINO/LATIN AMERICAN"
                       11 "SPANISH" 12 "FILIPINO" 13 "HISPANIC" ;
label define I3GEN     -8 "MISSING" -1 "NO ABSTRACT DATA" 1 "MALE" 2 "FEMALE" ;
label define I4_1MN    -8 "MISSING" -1 "NO ABSTRACT DATA" ;
label define I4_5MN    -8 "MISSING" -1 "NO ABSTRACT DATA" ;
label define IB5_01A   -9 "LEGITIMATE SKIP" -8 "MISSING"
                       -1 "NO ABSTRACT DATA" 1 "23771" 2 "32089" 3 "36330"
                       4 "37992" 5 "37993" 6 "42761" 7 "42789" 8 "48232"
                       9 "55010" 10 "73320" 11 "74343" 12 "74602" 13 "74922"
                       14 "75249" 15 "75319" 16 "75430" 17 "75432" 18 "75453"
                       19 "75462" 20 "75470" 21 "75500" 22 "75501" 23 "75502"
                       24 "75563" 25 "75733" 26 "76015" 27 "76065" 28 "76072"
                       29 "76073" 30 "76079" 31 "76300" 32 "76402" 33 "76403"
                       34 "76405" 35 "76406" 36 "76407" 37 "76418" 38 "76497"
                       39 "76498" 40 "76502" 41 "76503" 42 "76504" 43 "76510"
                       44 "76512" 45 "76514" 46 "76515" 47 "76516" 48 "76517"
                       49 "76518" 50 "76519" 51 "76803" 52 "77016" 53 "77181"
                       54 "77417" 55 "77460" 56 "77950" 57 "78512" 58 "78609"
                       59 "87341" 60 "0380X" 61 "0388X" 62 "0410X" 63 "0411X"
                       64 "0413X" 65 "0414X" 66 "0900X" 67 "0901X" 68 "0902X"
                       69 "0909X" 70 "0910X" 71 "0971X" 72 "1110X" 73 "1120X"
                       74 "1125X" 75 "2754X" 76 "2761X" 77 "2762X" 78 "2765X"
                       79 "2767X" 80 "2769X" 81 "30000" 82 "36221" 83 "4253X"
                       84 "4279X" 85 "47874" 86 "5206X" 87 "5301X" 88 "55092"
                       89 "5531X" 90 "5845X" 91 "6828X" 92 "6851X" 93 "690XX"
                       94 "6910X" 95 "7099X" 96 "7284X" 97 "73001" 98 "7423X"
                       99 "7424X" 100 "7443X" 101 "744XX" 102 "7452X"
                       103 "7455X" 104 "74689" 105 "7470X" 106 "7473X"
                       107 "7475X" 108 "7479X" 109 "7483X" 110 "7515X"
                       111 "7525X" 112 "7526X" 113 "7528X" 114 "7532X"
                       115 "7560X" 116 "7576X" 117 "7600X" 118 "7601X"
                       119 "7602X" 120 "76071" 121 "76075" 122 "7608X"
                       123 "7611X" 124 "7612X" 125 "7617X" 126 "7618X"
                       127 "7621X" 128 "7624X" 129 "7625X" 130 "7626X"
                       131 "7631X" 132 "7632X" 133 "7634X" 134 "7635X"
                       135 "7637X" 136 "7638X" 137 "76408" 138 "7642X"
                       139 "7650X" 140 "7651X" 141 "7660X" 142 "7661X"
                       143 "7662X" 144 "766XX" 145 "7671X" 146 "7672X"
                       147 "7673X" 148 "7675X" 149 "7678X" 150 "7679X"
                       151 "7683X" 152 "7684X" 153 "7685X" 154 "7686X"
                       155 "769XX" 156 "7700X" 157 "7701X" 158 "7702X"
                       159 "7703X" 160 "7704X" 161 "7705X" 162 "7706X"
                       163 "7707X" 164 "7708X" 165 "7714X" 166 "7716X"
                       167 "7717X" 168 "7718X" 169 "7721X" 170 "7722X"
                       171 "7724X" 172 "7726X" 173 "7731X" 174 "7732X"
                       175 "7742X" 176 "7746X" 177 "7747X" 178 "7750X"
                       179 "7755X" 180 "7756X" 181 "7757X" 182 "7758X"
                       183 "7759X" 184 "7761X" 185 "7764X" 186 "7765X"
                       187 "7766X" 188 "7767X" 189 "7771X" 190 "7774X"
                       191 "7775X" 192 "7776X" 193 "7778X" 194 "7783X"
                       195 "7784X" 196 "7786X" 197 "7788X" 198 "7790X"
                       199 "7793X" 200 "7795X" 201 "7796X" 202 "7798X"
                       203 "7852X" 204 "7919X" 205 "7923X" 206 "7931X"
                       207 "7948X" 208 "7958X" 209 "7961X" 210 "7963X"
                       211 "9396X" 212 "9961X" 213 "E8798" 214 "E9209"
                       215 "P0331" 216 "P2301" 217 "P2309" 218 "P3404"
                       219 "P3891" 220 "P3892" 221 "P3893" 222 "P5310"
                       223 "P5711" 224 "P640X" 225 "P8626" 226 "P8703"
                       227 "P8733" 228 "P8871" 229 "P8872" 230 "P8874"
                       231 "P8876" 232 "P8954" 233 "P8965" 234 "P9204"
                       235 "P9390" 236 "P9396" 237 "P9406" 238 "P9547"
                       239 "P9603" 240 "P9604" 241 "P9605" 242 "P960X"
                       243 "P9671" 244 "P9672" 245 "P9904" 246 "P9905"
                       247 "P9921" 248 "P9929" 249 "P9954" 250 "P9955"
                       251 "P9959" 252 "P9983" 253 "S7718" 254 "V016X"
                       255 "V017X" 256 "V018X" 257 "V025X" 258 "V058X"
                       259 "V200X" 260 "V290X" 261 "V3000" 262 "V3001"
                       263 "V300X" 264 "V301X" 265 "V3100" 266 "V3101"
                       267 "V3106" 268 "V604X" 269 "V650X" 270 "V718X"
                       271 "V7620" ;
label define IB5_02A   -9 "LEGITIMATE SKIP" -8 "MISSING"
                       -1 "NO ABSTRACT DATA" 1 "23771" 2 "32089" 3 "36330"
                       4 "37992" 5 "37993" 6 "42761" 7 "42789" 8 "48232"
                       9 "55010" 10 "73320" 11 "74343" 12 "74602" 13 "74922"
                       14 "75249" 15 "75319" 16 "75430" 17 "75432" 18 "75453"
                       19 "75462" 20 "75470" 21 "75500" 22 "75501" 23 "75502"
                       24 "75563" 25 "75733" 26 "76015" 27 "76065" 28 "76072"
                       29 "76073" 30 "76079" 31 "76300" 32 "76402" 33 "76403"
                       34 "76405" 35 "76406" 36 "76407" 37 "76418" 38 "76497"
                       39 "76498" 40 "76502" 41 "76503" 42 "76504" 43 "76510"
                       44 "76512" 45 "76514" 46 "76515" 47 "76516" 48 "76517"
                       49 "76518" 50 "76519" 51 "76803" 52 "77016" 53 "77181"
                       54 "77417" 55 "77460" 56 "77950" 57 "78512" 58 "78609"
                       59 "87341" 60 "0380X" 61 "0388X" 62 "0410X" 63 "0411X"
                       64 "0413X" 65 "0414X" 66 "0900X" 67 "0901X" 68 "0902X"
                       69 "0909X" 70 "0910X" 71 "0971X" 72 "1110X" 73 "1120X"
                       74 "1125X" 75 "2754X" 76 "2761X" 77 "2762X" 78 "2765X"
                       79 "2767X" 80 "2769X" 81 "30000" 82 "36221" 83 "4253X"
                       84 "4279X" 85 "47874" 86 "5206X" 87 "5301X" 88 "55092"
                       89 "5531X" 90 "5845X" 91 "6828X" 92 "6851X" 93 "690XX"
                       94 "6910X" 95 "7099X" 96 "7284X" 97 "73001" 98 "7423X"
                       99 "7424X" 100 "7443X" 101 "744XX" 102 "7452X"
                       103 "7455X" 104 "74689" 105 "7470X" 106 "7473X"
                       107 "7475X" 108 "7479X" 109 "7483X" 110 "7515X"
                       111 "7525X" 112 "7526X" 113 "7528X" 114 "7532X"
                       115 "7560X" 116 "7576X" 117 "7600X" 118 "7601X"
                       119 "7602X" 120 "76071" 121 "76075" 122 "7608X"
                       123 "7611X" 124 "7612X" 125 "7617X" 126 "7618X"
                       127 "7621X" 128 "7624X" 129 "7625X" 130 "7626X"
                       131 "7631X" 132 "7632X" 133 "7634X" 134 "7635X"
                       135 "7637X" 136 "7638X" 137 "76408" 138 "7642X"
                       139 "7650X" 140 "7651X" 141 "7660X" 142 "7661X"
                       143 "7662X" 144 "766XX" 145 "7671X" 146 "7672X"
                       147 "7673X" 148 "7675X" 149 "7678X" 150 "7679X"
                       151 "7683X" 152 "7684X" 153 "7685X" 154 "7686X"
                       155 "769XX" 156 "7700X" 157 "7701X" 158 "7702X"
                       159 "7703X" 160 "7704X" 161 "7705X" 162 "7706X"
                       163 "7707X" 164 "7708X" 165 "7714X" 166 "7716X"
                       167 "7717X" 168 "7718X" 169 "7721X" 170 "7722X"
                       171 "7724X" 172 "7726X" 173 "7731X" 174 "7732X"
                       175 "7742X" 176 "7746X" 177 "7747X" 178 "7750X"
                       179 "7755X" 180 "7756X" 181 "7757X" 182 "7758X"
                       183 "7759X" 184 "7761X" 185 "7764X" 186 "7765X"
                       187 "7766X" 188 "7767X" 189 "7771X" 190 "7774X"
                       191 "7775X" 192 "7776X" 193 "7778X" 194 "7783X"
                       195 "7784X" 196 "7786X" 197 "7788X" 198 "7790X"
                       199 "7793X" 200 "7795X" 201 "7796X" 202 "7798X"
                       203 "7852X" 204 "7919X" 205 "7923X" 206 "7931X"
                       207 "7948X" 208 "7958X" 209 "7961X" 210 "7963X"
                       211 "9396X" 212 "9961X" 213 "E8798" 214 "E9209"
                       215 "P0331" 216 "P2301" 217 "P2309" 218 "P3404"
                       219 "P3891" 220 "P3892" 221 "P3893" 222 "P5310"
                       223 "P5711" 224 "P640X" 225 "P8626" 226 "P8703"
                       227 "P8733" 228 "P8871" 229 "P8872" 230 "P8874"
                       231 "P8876" 232 "P8954" 233 "P8965" 234 "P9204"
                       235 "P9390" 236 "P9396" 237 "P9406" 238 "P9547"
                       239 "P9603" 240 "P9604" 241 "P9605" 242 "P960X"
                       243 "P9671" 244 "P9672" 245 "P9904" 246 "P9905"
                       247 "P9921" 248 "P9929" 249 "P9954" 250 "P9955"
                       251 "P9959" 252 "P9983" 253 "S7718" 254 "V016X"
                       255 "V017X" 256 "V018X" 257 "V025X" 258 "V058X"
                       259 "V200X" 260 "V290X" 261 "V3000" 262 "V3001"
                       263 "V300X" 264 "V301X" 265 "V3100" 266 "V3101"
                       267 "V3106" 268 "V604X" 269 "V650X" 270 "V718X"
                       271 "V7620" ;
label define IB5_03A   -9 "LEGITIMATE SKIP" -8 "MISSING"
                       -1 "NO ABSTRACT DATA" 1 "23771" 2 "32089" 3 "36330"
                       4 "37992" 5 "37993" 6 "42761" 7 "42789" 8 "48232"
                       9 "55010" 10 "73320" 11 "74343" 12 "74602" 13 "74922"
                       14 "75249" 15 "75319" 16 "75430" 17 "75432" 18 "75453"
                       19 "75462" 20 "75470" 21 "75500" 22 "75501" 23 "75502"
                       24 "75563" 25 "75733" 26 "76015" 27 "76065" 28 "76072"
                       29 "76073" 30 "76079" 31 "76300" 32 "76402" 33 "76403"
                       34 "76405" 35 "76406" 36 "76407" 37 "76418" 38 "76497"
                       39 "76498" 40 "76502" 41 "76503" 42 "76504" 43 "76510"
                       44 "76512" 45 "76514" 46 "76515" 47 "76516" 48 "76517"
                       49 "76518" 50 "76519" 51 "76803" 52 "77016" 53 "77181"
                       54 "77417" 55 "77460" 56 "77950" 57 "78512" 58 "78609"
                       59 "87341" 60 "0380X" 61 "0388X" 62 "0410X" 63 "0411X"
                       64 "0413X" 65 "0414X" 66 "0900X" 67 "0901X" 68 "0902X"
                       69 "0909X" 70 "0910X" 71 "0971X" 72 "1110X" 73 "1120X"
                       74 "1125X" 75 "2754X" 76 "2761X" 77 "2762X" 78 "2765X"
                       79 "2767X" 80 "2769X" 81 "30000" 82 "36221" 83 "4253X"
                       84 "4279X" 85 "47874" 86 "5206X" 87 "5301X" 88 "55092"
                       89 "5531X" 90 "5845X" 91 "6828X" 92 "6851X" 93 "690XX"
                       94 "6910X" 95 "7099X" 96 "7284X" 97 "73001" 98 "7423X"
                       99 "7424X" 100 "7443X" 101 "744XX" 102 "7452X"
                       103 "7455X" 104 "74689" 105 "7470X" 106 "7473X"
                       107 "7475X" 108 "7479X" 109 "7483X" 110 "7515X"
                       111 "7525X" 112 "7526X" 113 "7528X" 114 "7532X"
                       115 "7560X" 116 "7576X" 117 "7600X" 118 "7601X"
                       119 "7602X" 120 "76071" 121 "76075" 122 "7608X"
                       123 "7611X" 124 "7612X" 125 "7617X" 126 "7618X"
                       127 "7621X" 128 "7624X" 129 "7625X" 130 "7626X"
                       131 "7631X" 132 "7632X" 133 "7634X" 134 "7635X"
                       135 "7637X" 136 "7638X" 137 "76408" 138 "7642X"
                       139 "7650X" 140 "7651X" 141 "7660X" 142 "7661X"
                       143 "7662X" 144 "766XX" 145 "7671X" 146 "7672X"
                       147 "7673X" 148 "7675X" 149 "7678X" 150 "7679X"
                       151 "7683X" 152 "7684X" 153 "7685X" 154 "7686X"
                       155 "769XX" 156 "7700X" 157 "7701X" 158 "7702X"
                       159 "7703X" 160 "7704X" 161 "7705X" 162 "7706X"
                       163 "7707X" 164 "7708X" 165 "7714X" 166 "7716X"
                       167 "7717X" 168 "7718X" 169 "7721X" 170 "7722X"
                       171 "7724X" 172 "7726X" 173 "7731X" 174 "7732X"
                       175 "7742X" 176 "7746X" 177 "7747X" 178 "7750X"
                       179 "7755X" 180 "7756X" 181 "7757X" 182 "7758X"
                       183 "7759X" 184 "7761X" 185 "7764X" 186 "7765X"
                       187 "7766X" 188 "7767X" 189 "7771X" 190 "7774X"
                       191 "7775X" 192 "7776X" 193 "7778X" 194 "7783X"
                       195 "7784X" 196 "7786X" 197 "7788X" 198 "7790X"
                       199 "7793X" 200 "7795X" 201 "7796X" 202 "7798X"
                       203 "7852X" 204 "7919X" 205 "7923X" 206 "7931X"
                       207 "7948X" 208 "7958X" 209 "7961X" 210 "7963X"
                       211 "9396X" 212 "9961X" 213 "E8798" 214 "E9209"
                       215 "P0331" 216 "P2301" 217 "P2309" 218 "P3404"
                       219 "P3891" 220 "P3892" 221 "P3893" 222 "P5310"
                       223 "P5711" 224 "P640X" 225 "P8626" 226 "P8703"
                       227 "P8733" 228 "P8871" 229 "P8872" 230 "P8874"
                       231 "P8876" 232 "P8954" 233 "P8965" 234 "P9204"
                       235 "P9390" 236 "P9396" 237 "P9406" 238 "P9547"
                       239 "P9603" 240 "P9604" 241 "P9605" 242 "P960X"
                       243 "P9671" 244 "P9672" 245 "P9904" 246 "P9905"
                       247 "P9921" 248 "P9929" 249 "P9954" 250 "P9955"
                       251 "P9959" 252 "P9983" 253 "S7718" 254 "V016X"
                       255 "V017X" 256 "V018X" 257 "V025X" 258 "V058X"
                       259 "V200X" 260 "V290X" 261 "V3000" 262 "V3001"
                       263 "V300X" 264 "V301X" 265 "V3100" 266 "V3101"
                       267 "V3106" 268 "V604X" 269 "V650X" 270 "V718X"
                       271 "V7620" ;
label define IB5_04A   -9 "LEGITIMATE SKIP" -8 "MISSING"
                       -1 "NO ABSTRACT DATA" 1 "23771" 2 "32089" 3 "36330"
                       4 "37992" 5 "37993" 6 "42761" 7 "42789" 8 "48232"
                       9 "55010" 10 "73320" 11 "74343" 12 "74602" 13 "74922"
                       14 "75249" 15 "75319" 16 "75430" 17 "75432" 18 "75453"
                       19 "75462" 20 "75470" 21 "75500" 22 "75501" 23 "75502"
                       24 "75563" 25 "75733" 26 "76015" 27 "76065" 28 "76072"
                       29 "76073" 30 "76079" 31 "76300" 32 "76402" 33 "76403"
                       34 "76405" 35 "76406" 36 "76407" 37 "76418" 38 "76497"
                       39 "76498" 40 "76502" 41 "76503" 42 "76504" 43 "76510"
                       44 "76512" 45 "76514" 46 "76515" 47 "76516" 48 "76517"
                       49 "76518" 50 "76519" 51 "76803" 52 "77016" 53 "77181"
                       54 "77417" 55 "77460" 56 "77950" 57 "78512" 58 "78609"
                       59 "87341" 60 "0380X" 61 "0388X" 62 "0410X" 63 "0411X"
                       64 "0413X" 65 "0414X" 66 "0900X" 67 "0901X" 68 "0902X"
                       69 "0909X" 70 "0910X" 71 "0971X" 72 "1110X" 73 "1120X"
                       74 "1125X" 75 "2754X" 76 "2761X" 77 "2762X" 78 "2765X"
                       79 "2767X" 80 "2769X" 81 "30000" 82 "36221" 83 "4253X"
                       84 "4279X" 85 "47874" 86 "5206X" 87 "5301X" 88 "55092"
                       89 "5531X" 90 "5845X" 91 "6828X" 92 "6851X" 93 "690XX"
                       94 "6910X" 95 "7099X" 96 "7284X" 97 "73001" 98 "7423X"
                       99 "7424X" 100 "7443X" 101 "744XX" 102 "7452X"
                       103 "7455X" 104 "74689" 105 "7470X" 106 "7473X"
                       107 "7475X" 108 "7479X" 109 "7483X" 110 "7515X"
                       111 "7525X" 112 "7526X" 113 "7528X" 114 "7532X"
                       115 "7560X" 116 "7576X" 117 "7600X" 118 "7601X"
                       119 "7602X" 120 "76071" 121 "76075" 122 "7608X"
                       123 "7611X" 124 "7612X" 125 "7617X" 126 "7618X"
                       127 "7621X" 128 "7624X" 129 "7625X" 130 "7626X"
                       131 "7631X" 132 "7632X" 133 "7634X" 134 "7635X"
                       135 "7637X" 136 "7638X" 137 "76408" 138 "7642X"
                       139 "7650X" 140 "7651X" 141 "7660X" 142 "7661X"
                       143 "7662X" 144 "766XX" 145 "7671X" 146 "7672X"
                       147 "7673X" 148 "7675X" 149 "7678X" 150 "7679X"
                       151 "7683X" 152 "7684X" 153 "7685X" 154 "7686X"
                       155 "769XX" 156 "7700X" 157 "7701X" 158 "7702X"
                       159 "7703X" 160 "7704X" 161 "7705X" 162 "7706X"
                       163 "7707X" 164 "7708X" 165 "7714X" 166 "7716X"
                       167 "7717X" 168 "7718X" 169 "7721X" 170 "7722X"
                       171 "7724X" 172 "7726X" 173 "7731X" 174 "7732X"
                       175 "7742X" 176 "7746X" 177 "7747X" 178 "7750X"
                       179 "7755X" 180 "7756X" 181 "7757X" 182 "7758X"
                       183 "7759X" 184 "7761X" 185 "7764X" 186 "7765X"
                       187 "7766X" 188 "7767X" 189 "7771X" 190 "7774X"
                       191 "7775X" 192 "7776X" 193 "7778X" 194 "7783X"
                       195 "7784X" 196 "7786X" 197 "7788X" 198 "7790X"
                       199 "7793X" 200 "7795X" 201 "7796X" 202 "7798X"
                       203 "7852X" 204 "7919X" 205 "7923X" 206 "7931X"
                       207 "7948X" 208 "7958X" 209 "7961X" 210 "7963X"
                       211 "9396X" 212 "9961X" 213 "E8798" 214 "E9209"
                       215 "P0331" 216 "P2301" 217 "P2309" 218 "P3404"
                       219 "P3891" 220 "P3892" 221 "P3893" 222 "P5310"
                       223 "P5711" 224 "P640X" 225 "P8626" 226 "P8703"
                       227 "P8733" 228 "P8871" 229 "P8872" 230 "P8874"
                       231 "P8876" 232 "P8954" 233 "P8965" 234 "P9204"
                       235 "P9390" 236 "P9396" 237 "P9406" 238 "P9547"
                       239 "P9603" 240 "P9604" 241 "P9605" 242 "P960X"
                       243 "P9671" 244 "P9672" 245 "P9904" 246 "P9905"
                       247 "P9921" 248 "P9929" 249 "P9954" 250 "P9955"
                       251 "P9959" 252 "P9983" 253 "S7718" 254 "V016X"
                       255 "V017X" 256 "V018X" 257 "V025X" 258 "V058X"
                       259 "V200X" 260 "V290X" 261 "V3000" 262 "V3001"
                       263 "V300X" 264 "V301X" 265 "V3100" 266 "V3101"
                       267 "V3106" 268 "V604X" 269 "V650X" 270 "V718X"
                       271 "V7620" ;
label define IB5_05A   -9 "LEGITIMATE SKIP" -8 "MISSING"
                       -1 "NO ABSTRACT DATA" 1 "23771" 2 "32089" 3 "36330"
                       4 "37992" 5 "37993" 6 "42761" 7 "42789" 8 "48232"
                       9 "55010" 10 "73320" 11 "74343" 12 "74602" 13 "74922"
                       14 "75249" 15 "75319" 16 "75430" 17 "75432" 18 "75453"
                       19 "75462" 20 "75470" 21 "75500" 22 "75501" 23 "75502"
                       24 "75563" 25 "75733" 26 "76015" 27 "76065" 28 "76072"
                       29 "76073" 30 "76079" 31 "76300" 32 "76402" 33 "76403"
                       34 "76405" 35 "76406" 36 "76407" 37 "76418" 38 "76497"
                       39 "76498" 40 "76502" 41 "76503" 42 "76504" 43 "76510"
                       44 "76512" 45 "76514" 46 "76515" 47 "76516" 48 "76517"
                       49 "76518" 50 "76519" 51 "76803" 52 "77016" 53 "77181"
                       54 "77417" 55 "77460" 56 "77950" 57 "78512" 58 "78609"
                       59 "87341" 60 "0380X" 61 "0388X" 62 "0410X" 63 "0411X"
                       64 "0413X" 65 "0414X" 66 "0900X" 67 "0901X" 68 "0902X"
                       69 "0909X" 70 "0910X" 71 "0971X" 72 "1110X" 73 "1120X"
                       74 "1125X" 75 "2754X" 76 "2761X" 77 "2762X" 78 "2765X"
                       79 "2767X" 80 "2769X" 81 "30000" 82 "36221" 83 "4253X"
                       84 "4279X" 85 "47874" 86 "5206X" 87 "5301X" 88 "55092"
                       89 "5531X" 90 "5845X" 91 "6828X" 92 "6851X" 93 "690XX"
                       94 "6910X" 95 "7099X" 96 "7284X" 97 "73001" 98 "7423X"
                       99 "7424X" 100 "7443X" 101 "744XX" 102 "7452X"
                       103 "7455X" 104 "74689" 105 "7470X" 106 "7473X"
                       107 "7475X" 108 "7479X" 109 "7483X" 110 "7515X"
                       111 "7525X" 112 "7526X" 113 "7528X" 114 "7532X"
                       115 "7560X" 116 "7576X" 117 "7600X" 118 "7601X"
                       119 "7602X" 120 "76071" 121 "76075" 122 "7608X"
                       123 "7611X" 124 "7612X" 125 "7617X" 126 "7618X"
                       127 "7621X" 128 "7624X" 129 "7625X" 130 "7626X"
                       131 "7631X" 132 "7632X" 133 "7634X" 134 "7635X"
                       135 "7637X" 136 "7638X" 137 "76408" 138 "7642X"
                       139 "7650X" 140 "7651X" 141 "7660X" 142 "7661X"
                       143 "7662X" 144 "766XX" 145 "7671X" 146 "7672X"
                       147 "7673X" 148 "7675X" 149 "7678X" 150 "7679X"
                       151 "7683X" 152 "7684X" 153 "7685X" 154 "7686X"
                       155 "769XX" 156 "7700X" 157 "7701X" 158 "7702X"
                       159 "7703X" 160 "7704X" 161 "7705X" 162 "7706X"
                       163 "7707X" 164 "7708X" 165 "7714X" 166 "7716X"
                       167 "7717X" 168 "7718X" 169 "7721X" 170 "7722X"
                       171 "7724X" 172 "7726X" 173 "7731X" 174 "7732X"
                       175 "7742X" 176 "7746X" 177 "7747X" 178 "7750X"
                       179 "7755X" 180 "7756X" 181 "7757X" 182 "7758X"
                       183 "7759X" 184 "7761X" 185 "7764X" 186 "7765X"
                       187 "7766X" 188 "7767X" 189 "7771X" 190 "7774X"
                       191 "7775X" 192 "7776X" 193 "7778X" 194 "7783X"
                       195 "7784X" 196 "7786X" 197 "7788X" 198 "7790X"
                       199 "7793X" 200 "7795X" 201 "7796X" 202 "7798X"
                       203 "7852X" 204 "7919X" 205 "7923X" 206 "7931X"
                       207 "7948X" 208 "7958X" 209 "7961X" 210 "7963X"
                       211 "9396X" 212 "9961X" 213 "E8798" 214 "E9209"
                       215 "P0331" 216 "P2301" 217 "P2309" 218 "P3404"
                       219 "P3891" 220 "P3892" 221 "P3893" 222 "P5310"
                       223 "P5711" 224 "P640X" 225 "P8626" 226 "P8703"
                       227 "P8733" 228 "P8871" 229 "P8872" 230 "P8874"
                       231 "P8876" 232 "P8954" 233 "P8965" 234 "P9204"
                       235 "P9390" 236 "P9396" 237 "P9406" 238 "P9547"
                       239 "P9603" 240 "P9604" 241 "P9605" 242 "P960X"
                       243 "P9671" 244 "P9672" 245 "P9904" 246 "P9905"
                       247 "P9921" 248 "P9929" 249 "P9954" 250 "P9955"
                       251 "P9959" 252 "P9983" 253 "S7718" 254 "V016X"
                       255 "V017X" 256 "V018X" 257 "V025X" 258 "V058X"
                       259 "V200X" 260 "V290X" 261 "V3000" 262 "V3001"
                       263 "V300X" 264 "V301X" 265 "V3100" 266 "V3101"
                       267 "V3106" 268 "V604X" 269 "V650X" 270 "V718X"
                       271 "V7620" ;
label define IB5_06A   -9 "LEGITIMATE SKIP" -8 "MISSING"
                       -1 "NO ABSTRACT DATA" 1 "23771" 2 "32089" 3 "36330"
                       4 "37992" 5 "37993" 6 "42761" 7 "42789" 8 "48232"
                       9 "55010" 10 "73320" 11 "74343" 12 "74602" 13 "74922"
                       14 "75249" 15 "75319" 16 "75430" 17 "75432" 18 "75453"
                       19 "75462" 20 "75470" 21 "75500" 22 "75501" 23 "75502"
                       24 "75563" 25 "75733" 26 "76015" 27 "76065" 28 "76072"
                       29 "76073" 30 "76079" 31 "76300" 32 "76402" 33 "76403"
                       34 "76405" 35 "76406" 36 "76407" 37 "76418" 38 "76497"
                       39 "76498" 40 "76502" 41 "76503" 42 "76504" 43 "76510"
                       44 "76512" 45 "76514" 46 "76515" 47 "76516" 48 "76517"
                       49 "76518" 50 "76519" 51 "76803" 52 "77016" 53 "77181"
                       54 "77417" 55 "77460" 56 "77950" 57 "78512" 58 "78609"
                       59 "87341" 60 "0380X" 61 "0388X" 62 "0410X" 63 "0411X"
                       64 "0413X" 65 "0414X" 66 "0900X" 67 "0901X" 68 "0902X"
                       69 "0909X" 70 "0910X" 71 "0971X" 72 "1110X" 73 "1120X"
                       74 "1125X" 75 "2754X" 76 "2761X" 77 "2762X" 78 "2765X"
                       79 "2767X" 80 "2769X" 81 "30000" 82 "36221" 83 "4253X"
                       84 "4279X" 85 "47874" 86 "5206X" 87 "5301X" 88 "55092"
                       89 "5531X" 90 "5845X" 91 "6828X" 92 "6851X" 93 "690XX"
                       94 "6910X" 95 "7099X" 96 "7284X" 97 "73001" 98 "7423X"
                       99 "7424X" 100 "7443X" 101 "744XX" 102 "7452X"
                       103 "7455X" 104 "74689" 105 "7470X" 106 "7473X"
                       107 "7475X" 108 "7479X" 109 "7483X" 110 "7515X"
                       111 "7525X" 112 "7526X" 113 "7528X" 114 "7532X"
                       115 "7560X" 116 "7576X" 117 "7600X" 118 "7601X"
                       119 "7602X" 120 "76071" 121 "76075" 122 "7608X"
                       123 "7611X" 124 "7612X" 125 "7617X" 126 "7618X"
                       127 "7621X" 128 "7624X" 129 "7625X" 130 "7626X"
                       131 "7631X" 132 "7632X" 133 "7634X" 134 "7635X"
                       135 "7637X" 136 "7638X" 137 "76408" 138 "7642X"
                       139 "7650X" 140 "7651X" 141 "7660X" 142 "7661X"
                       143 "7662X" 144 "766XX" 145 "7671X" 146 "7672X"
                       147 "7673X" 148 "7675X" 149 "7678X" 150 "7679X"
                       151 "7683X" 152 "7684X" 153 "7685X" 154 "7686X"
                       155 "769XX" 156 "7700X" 157 "7701X" 158 "7702X"
                       159 "7703X" 160 "7704X" 161 "7705X" 162 "7706X"
                       163 "7707X" 164 "7708X" 165 "7714X" 166 "7716X"
                       167 "7717X" 168 "7718X" 169 "7721X" 170 "7722X"
                       171 "7724X" 172 "7726X" 173 "7731X" 174 "7732X"
                       175 "7742X" 176 "7746X" 177 "7747X" 178 "7750X"
                       179 "7755X" 180 "7756X" 181 "7757X" 182 "7758X"
                       183 "7759X" 184 "7761X" 185 "7764X" 186 "7765X"
                       187 "7766X" 188 "7767X" 189 "7771X" 190 "7774X"
                       191 "7775X" 192 "7776X" 193 "7778X" 194 "7783X"
                       195 "7784X" 196 "7786X" 197 "7788X" 198 "7790X"
                       199 "7793X" 200 "7795X" 201 "7796X" 202 "7798X"
                       203 "7852X" 204 "7919X" 205 "7923X" 206 "7931X"
                       207 "7948X" 208 "7958X" 209 "7961X" 210 "7963X"
                       211 "9396X" 212 "9961X" 213 "E8798" 214 "E9209"
                       215 "P0331" 216 "P2301" 217 "P2309" 218 "P3404"
                       219 "P3891" 220 "P3892" 221 "P3893" 222 "P5310"
                       223 "P5711" 224 "P640X" 225 "P8626" 226 "P8703"
                       227 "P8733" 228 "P8871" 229 "P8872" 230 "P8874"
                       231 "P8876" 232 "P8954" 233 "P8965" 234 "P9204"
                       235 "P9390" 236 "P9396" 237 "P9406" 238 "P9547"
                       239 "P9603" 240 "P9604" 241 "P9605" 242 "P960X"
                       243 "P9671" 244 "P9672" 245 "P9904" 246 "P9905"
                       247 "P9921" 248 "P9929" 249 "P9954" 250 "P9955"
                       251 "P9959" 252 "P9983" 253 "S7718" 254 "V016X"
                       255 "V017X" 256 "V018X" 257 "V025X" 258 "V058X"
                       259 "V200X" 260 "V290X" 261 "V3000" 262 "V3001"
                       263 "V300X" 264 "V301X" 265 "V3100" 266 "V3101"
                       267 "V3106" 268 "V604X" 269 "V650X" 270 "V718X"
                       271 "V7620" ;
label define IB5_07A   -9 "LEGITIMATE SKIP" -8 "MISSING"
                       -1 "NO ABSTRACT DATA" 1 "23771" 2 "32089" 3 "36330"
                       4 "37992" 5 "37993" 6 "42761" 7 "42789" 8 "48232"
                       9 "55010" 10 "73320" 11 "74343" 12 "74602" 13 "74922"
                       14 "75249" 15 "75319" 16 "75430" 17 "75432" 18 "75453"
                       19 "75462" 20 "75470" 21 "75500" 22 "75501" 23 "75502"
                       24 "75563" 25 "75733" 26 "76015" 27 "76065" 28 "76072"
                       29 "76073" 30 "76079" 31 "76300" 32 "76402" 33 "76403"
                       34 "76405" 35 "76406" 36 "76407" 37 "76418" 38 "76497"
                       39 "76498" 40 "76502" 41 "76503" 42 "76504" 43 "76510"
                       44 "76512" 45 "76514" 46 "76515" 47 "76516" 48 "76517"
                       49 "76518" 50 "76519" 51 "76803" 52 "77016" 53 "77181"
                       54 "77417" 55 "77460" 56 "77950" 57 "78512" 58 "78609"
                       59 "87341" 60 "0380X" 61 "0388X" 62 "0410X" 63 "0411X"
                       64 "0413X" 65 "0414X" 66 "0900X" 67 "0901X" 68 "0902X"
                       69 "0909X" 70 "0910X" 71 "0971X" 72 "1110X" 73 "1120X"
                       74 "1125X" 75 "2754X" 76 "2761X" 77 "2762X" 78 "2765X"
                       79 "2767X" 80 "2769X" 81 "30000" 82 "36221" 83 "4253X"
                       84 "4279X" 85 "47874" 86 "5206X" 87 "5301X" 88 "55092"
                       89 "5531X" 90 "5845X" 91 "6828X" 92 "6851X" 93 "690XX"
                       94 "6910X" 95 "7099X" 96 "7284X" 97 "73001" 98 "7423X"
                       99 "7424X" 100 "7443X" 101 "744XX" 102 "7452X"
                       103 "7455X" 104 "74689" 105 "7470X" 106 "7473X"
                       107 "7475X" 108 "7479X" 109 "7483X" 110 "7515X"
                       111 "7525X" 112 "7526X" 113 "7528X" 114 "7532X"
                       115 "7560X" 116 "7576X" 117 "7600X" 118 "7601X"
                       119 "7602X" 120 "76071" 121 "76075" 122 "7608X"
                       123 "7611X" 124 "7612X" 125 "7617X" 126 "7618X"
                       127 "7621X" 128 "7624X" 129 "7625X" 130 "7626X"
                       131 "7631X" 132 "7632X" 133 "7634X" 134 "7635X"
                       135 "7637X" 136 "7638X" 137 "76408" 138 "7642X"
                       139 "7650X" 140 "7651X" 141 "7660X" 142 "7661X"
                       143 "7662X" 144 "766XX" 145 "7671X" 146 "7672X"
                       147 "7673X" 148 "7675X" 149 "7678X" 150 "7679X"
                       151 "7683X" 152 "7684X" 153 "7685X" 154 "7686X"
                       155 "769XX" 156 "7700X" 157 "7701X" 158 "7702X"
                       159 "7703X" 160 "7704X" 161 "7705X" 162 "7706X"
                       163 "7707X" 164 "7708X" 165 "7714X" 166 "7716X"
                       167 "7717X" 168 "7718X" 169 "7721X" 170 "7722X"
                       171 "7724X" 172 "7726X" 173 "7731X" 174 "7732X"
                       175 "7742X" 176 "7746X" 177 "7747X" 178 "7750X"
                       179 "7755X" 180 "7756X" 181 "7757X" 182 "7758X"
                       183 "7759X" 184 "7761X" 185 "7764X" 186 "7765X"
                       187 "7766X" 188 "7767X" 189 "7771X" 190 "7774X"
                       191 "7775X" 192 "7776X" 193 "7778X" 194 "7783X"
                       195 "7784X" 196 "7786X" 197 "7788X" 198 "7790X"
                       199 "7793X" 200 "7795X" 201 "7796X" 202 "7798X"
                       203 "7852X" 204 "7919X" 205 "7923X" 206 "7931X"
                       207 "7948X" 208 "7958X" 209 "7961X" 210 "7963X"
                       211 "9396X" 212 "9961X" 213 "E8798" 214 "E9209"
                       215 "P0331" 216 "P2301" 217 "P2309" 218 "P3404"
                       219 "P3891" 220 "P3892" 221 "P3893" 222 "P5310"
                       223 "P5711" 224 "P640X" 225 "P8626" 226 "P8703"
                       227 "P8733" 228 "P8871" 229 "P8872" 230 "P8874"
                       231 "P8876" 232 "P8954" 233 "P8965" 234 "P9204"
                       235 "P9390" 236 "P9396" 237 "P9406" 238 "P9547"
                       239 "P9603" 240 "P9604" 241 "P9605" 242 "P960X"
                       243 "P9671" 244 "P9672" 245 "P9904" 246 "P9905"
                       247 "P9921" 248 "P9929" 249 "P9954" 250 "P9955"
                       251 "P9959" 252 "P9983" 253 "S7718" 254 "V016X"
                       255 "V017X" 256 "V018X" 257 "V025X" 258 "V058X"
                       259 "V200X" 260 "V290X" 261 "V3000" 262 "V3001"
                       263 "V300X" 264 "V301X" 265 "V3100" 266 "V3101"
                       267 "V3106" 268 "V604X" 269 "V650X" 270 "V718X"
                       271 "V7620" ;
label define IB5_08A   -9 "LEGITIMATE SKIP" -8 "MISSING"
                       -1 "NO ABSTRACT DATA" 1 "23771" 2 "32089" 3 "36330"
                       4 "37992" 5 "37993" 6 "42761" 7 "42789" 8 "48232"
                       9 "55010" 10 "73320" 11 "74343" 12 "74602" 13 "74922"
                       14 "75249" 15 "75319" 16 "75430" 17 "75432" 18 "75453"
                       19 "75462" 20 "75470" 21 "75500" 22 "75501" 23 "75502"
                       24 "75563" 25 "75733" 26 "76015" 27 "76065" 28 "76072"
                       29 "76073" 30 "76079" 31 "76300" 32 "76402" 33 "76403"
                       34 "76405" 35 "76406" 36 "76407" 37 "76418" 38 "76497"
                       39 "76498" 40 "76502" 41 "76503" 42 "76504" 43 "76510"
                       44 "76512" 45 "76514" 46 "76515" 47 "76516" 48 "76517"
                       49 "76518" 50 "76519" 51 "76803" 52 "77016" 53 "77181"
                       54 "77417" 55 "77460" 56 "77950" 57 "78512" 58 "78609"
                       59 "87341" 60 "0380X" 61 "0388X" 62 "0410X" 63 "0411X"
                       64 "0413X" 65 "0414X" 66 "0900X" 67 "0901X" 68 "0902X"
                       69 "0909X" 70 "0910X" 71 "0971X" 72 "1110X" 73 "1120X"
                       74 "1125X" 75 "2754X" 76 "2761X" 77 "2762X" 78 "2765X"
                       79 "2767X" 80 "2769X" 81 "30000" 82 "36221" 83 "4253X"
                       84 "4279X" 85 "47874" 86 "5206X" 87 "5301X" 88 "55092"
                       89 "5531X" 90 "5845X" 91 "6828X" 92 "6851X" 93 "690XX"
                       94 "6910X" 95 "7099X" 96 "7284X" 97 "73001" 98 "7423X"
                       99 "7424X" 100 "7443X" 101 "744XX" 102 "7452X"
                       103 "7455X" 104 "74689" 105 "7470X" 106 "7473X"
                       107 "7475X" 108 "7479X" 109 "7483X" 110 "7515X"
                       111 "7525X" 112 "7526X" 113 "7528X" 114 "7532X"
                       115 "7560X" 116 "7576X" 117 "7600X" 118 "7601X"
                       119 "7602X" 120 "76071" 121 "76075" 122 "7608X"
                       123 "7611X" 124 "7612X" 125 "7617X" 126 "7618X"
                       127 "7621X" 128 "7624X" 129 "7625X" 130 "7626X"
                       131 "7631X" 132 "7632X" 133 "7634X" 134 "7635X"
                       135 "7637X" 136 "7638X" 137 "76408" 138 "7642X"
                       139 "7650X" 140 "7651X" 141 "7660X" 142 "7661X"
                       143 "7662X" 144 "766XX" 145 "7671X" 146 "7672X"
                       147 "7673X" 148 "7675X" 149 "7678X" 150 "7679X"
                       151 "7683X" 152 "7684X" 153 "7685X" 154 "7686X"
                       155 "769XX" 156 "7700X" 157 "7701X" 158 "7702X"
                       159 "7703X" 160 "7704X" 161 "7705X" 162 "7706X"
                       163 "7707X" 164 "7708X" 165 "7714X" 166 "7716X"
                       167 "7717X" 168 "7718X" 169 "7721X" 170 "7722X"
                       171 "7724X" 172 "7726X" 173 "7731X" 174 "7732X"
                       175 "7742X" 176 "7746X" 177 "7747X" 178 "7750X"
                       179 "7755X" 180 "7756X" 181 "7757X" 182 "7758X"
                       183 "7759X" 184 "7761X" 185 "7764X" 186 "7765X"
                       187 "7766X" 188 "7767X" 189 "7771X" 190 "7774X"
                       191 "7775X" 192 "7776X" 193 "7778X" 194 "7783X"
                       195 "7784X" 196 "7786X" 197 "7788X" 198 "7790X"
                       199 "7793X" 200 "7795X" 201 "7796X" 202 "7798X"
                       203 "7852X" 204 "7919X" 205 "7923X" 206 "7931X"
                       207 "7948X" 208 "7958X" 209 "7961X" 210 "7963X"
                       211 "9396X" 212 "9961X" 213 "E8798" 214 "E9209"
                       215 "P0331" 216 "P2301" 217 "P2309" 218 "P3404"
                       219 "P3891" 220 "P3892" 221 "P3893" 222 "P5310"
                       223 "P5711" 224 "P640X" 225 "P8626" 226 "P8703"
                       227 "P8733" 228 "P8871" 229 "P8872" 230 "P8874"
                       231 "P8876" 232 "P8954" 233 "P8965" 234 "P9204"
                       235 "P9390" 236 "P9396" 237 "P9406" 238 "P9547"
                       239 "P9603" 240 "P9604" 241 "P9605" 242 "P960X"
                       243 "P9671" 244 "P9672" 245 "P9904" 246 "P9905"
                       247 "P9921" 248 "P9929" 249 "P9954" 250 "P9955"
                       251 "P9959" 252 "P9983" 253 "S7718" 254 "V016X"
                       255 "V017X" 256 "V018X" 257 "V025X" 258 "V058X"
                       259 "V200X" 260 "V290X" 261 "V3000" 262 "V3001"
                       263 "V300X" 264 "V301X" 265 "V3100" 266 "V3101"
                       267 "V3106" 268 "V604X" 269 "V650X" 270 "V718X"
                       271 "V7620" ;
label define IB5_09A   -9 "LEGITIMATE SKIP" -8 "MISSING"
                       -1 "NO ABSTRACT DATA" 1 "23771" 2 "32089" 3 "36330"
                       4 "37992" 5 "37993" 6 "42761" 7 "42789" 8 "48232"
                       9 "55010" 10 "73320" 11 "74343" 12 "74602" 13 "74922"
                       14 "75249" 15 "75319" 16 "75430" 17 "75432" 18 "75453"
                       19 "75462" 20 "75470" 21 "75500" 22 "75501" 23 "75502"
                       24 "75563" 25 "75733" 26 "76015" 27 "76065" 28 "76072"
                       29 "76073" 30 "76079" 31 "76300" 32 "76402" 33 "76403"
                       34 "76405" 35 "76406" 36 "76407" 37 "76418" 38 "76497"
                       39 "76498" 40 "76502" 41 "76503" 42 "76504" 43 "76510"
                       44 "76512" 45 "76514" 46 "76515" 47 "76516" 48 "76517"
                       49 "76518" 50 "76519" 51 "76803" 52 "77016" 53 "77181"
                       54 "77417" 55 "77460" 56 "77950" 57 "78512" 58 "78609"
                       59 "87341" 60 "0380X" 61 "0388X" 62 "0410X" 63 "0411X"
                       64 "0413X" 65 "0414X" 66 "0900X" 67 "0901X" 68 "0902X"
                       69 "0909X" 70 "0910X" 71 "0971X" 72 "1110X" 73 "1120X"
                       74 "1125X" 75 "2754X" 76 "2761X" 77 "2762X" 78 "2765X"
                       79 "2767X" 80 "2769X" 81 "30000" 82 "36221" 83 "4253X"
                       84 "4279X" 85 "47874" 86 "5206X" 87 "5301X" 88 "55092"
                       89 "5531X" 90 "5845X" 91 "6828X" 92 "6851X" 93 "690XX"
                       94 "6910X" 95 "7099X" 96 "7284X" 97 "73001" 98 "7423X"
                       99 "7424X" 100 "7443X" 101 "744XX" 102 "7452X"
                       103 "7455X" 104 "74689" 105 "7470X" 106 "7473X"
                       107 "7475X" 108 "7479X" 109 "7483X" 110 "7515X"
                       111 "7525X" 112 "7526X" 113 "7528X" 114 "7532X"
                       115 "7560X" 116 "7576X" 117 "7600X" 118 "7601X"
                       119 "7602X" 120 "76071" 121 "76075" 122 "7608X"
                       123 "7611X" 124 "7612X" 125 "7617X" 126 "7618X"
                       127 "7621X" 128 "7624X" 129 "7625X" 130 "7626X"
                       131 "7631X" 132 "7632X" 133 "7634X" 134 "7635X"
                       135 "7637X" 136 "7638X" 137 "76408" 138 "7642X"
                       139 "7650X" 140 "7651X" 141 "7660X" 142 "7661X"
                       143 "7662X" 144 "766XX" 145 "7671X" 146 "7672X"
                       147 "7673X" 148 "7675X" 149 "7678X" 150 "7679X"
                       151 "7683X" 152 "7684X" 153 "7685X" 154 "7686X"
                       155 "769XX" 156 "7700X" 157 "7701X" 158 "7702X"
                       159 "7703X" 160 "7704X" 161 "7705X" 162 "7706X"
                       163 "7707X" 164 "7708X" 165 "7714X" 166 "7716X"
                       167 "7717X" 168 "7718X" 169 "7721X" 170 "7722X"
                       171 "7724X" 172 "7726X" 173 "7731X" 174 "7732X"
                       175 "7742X" 176 "7746X" 177 "7747X" 178 "7750X"
                       179 "7755X" 180 "7756X" 181 "7757X" 182 "7758X"
                       183 "7759X" 184 "7761X" 185 "7764X" 186 "7765X"
                       187 "7766X" 188 "7767X" 189 "7771X" 190 "7774X"
                       191 "7775X" 192 "7776X" 193 "7778X" 194 "7783X"
                       195 "7784X" 196 "7786X" 197 "7788X" 198 "7790X"
                       199 "7793X" 200 "7795X" 201 "7796X" 202 "7798X"
                       203 "7852X" 204 "7919X" 205 "7923X" 206 "7931X"
                       207 "7948X" 208 "7958X" 209 "7961X" 210 "7963X"
                       211 "9396X" 212 "9961X" 213 "E8798" 214 "E9209"
                       215 "P0331" 216 "P2301" 217 "P2309" 218 "P3404"
                       219 "P3891" 220 "P3892" 221 "P3893" 222 "P5310"
                       223 "P5711" 224 "P640X" 225 "P8626" 226 "P8703"
                       227 "P8733" 228 "P8871" 229 "P8872" 230 "P8874"
                       231 "P8876" 232 "P8954" 233 "P8965" 234 "P9204"
                       235 "P9390" 236 "P9396" 237 "P9406" 238 "P9547"
                       239 "P9603" 240 "P9604" 241 "P9605" 242 "P960X"
                       243 "P9671" 244 "P9672" 245 "P9904" 246 "P9905"
                       247 "P9921" 248 "P9929" 249 "P9954" 250 "P9955"
                       251 "P9959" 252 "P9983" 253 "S7718" 254 "V016X"
                       255 "V017X" 256 "V018X" 257 "V025X" 258 "V058X"
                       259 "V200X" 260 "V290X" 261 "V3000" 262 "V3001"
                       263 "V300X" 264 "V301X" 265 "V3100" 266 "V3101"
                       267 "V3106" 268 "V604X" 269 "V650X" 270 "V718X"
                       271 "V7620" ;
label define IB5_10A   -9 "LEGITIMATE SKIP" -8 "MISSING"
                       -1 "NO ABSTRACT DATA" 1 "23771" 2 "32089" 3 "36330"
                       4 "37992" 5 "37993" 6 "42761" 7 "42789" 8 "48232"
                       9 "55010" 10 "73320" 11 "74343" 12 "74602" 13 "74922"
                       14 "75249" 15 "75319" 16 "75430" 17 "75432" 18 "75453"
                       19 "75462" 20 "75470" 21 "75500" 22 "75501" 23 "75502"
                       24 "75563" 25 "75733" 26 "76015" 27 "76065" 28 "76072"
                       29 "76073" 30 "76079" 31 "76300" 32 "76402" 33 "76403"
                       34 "76405" 35 "76406" 36 "76407" 37 "76418" 38 "76497"
                       39 "76498" 40 "76502" 41 "76503" 42 "76504" 43 "76510"
                       44 "76512" 45 "76514" 46 "76515" 47 "76516" 48 "76517"
                       49 "76518" 50 "76519" 51 "76803" 52 "77016" 53 "77181"
                       54 "77417" 55 "77460" 56 "77950" 57 "78512" 58 "78609"
                       59 "87341" 60 "0380X" 61 "0388X" 62 "0410X" 63 "0411X"
                       64 "0413X" 65 "0414X" 66 "0900X" 67 "0901X" 68 "0902X"
                       69 "0909X" 70 "0910X" 71 "0971X" 72 "1110X" 73 "1120X"
                       74 "1125X" 75 "2754X" 76 "2761X" 77 "2762X" 78 "2765X"
                       79 "2767X" 80 "2769X" 81 "30000" 82 "36221" 83 "4253X"
                       84 "4279X" 85 "47874" 86 "5206X" 87 "5301X" 88 "55092"
                       89 "5531X" 90 "5845X" 91 "6828X" 92 "6851X" 93 "690XX"
                       94 "6910X" 95 "7099X" 96 "7284X" 97 "73001" 98 "7423X"
                       99 "7424X" 100 "7443X" 101 "744XX" 102 "7452X"
                       103 "7455X" 104 "74689" 105 "7470X" 106 "7473X"
                       107 "7475X" 108 "7479X" 109 "7483X" 110 "7515X"
                       111 "7525X" 112 "7526X" 113 "7528X" 114 "7532X"
                       115 "7560X" 116 "7576X" 117 "7600X" 118 "7601X"
                       119 "7602X" 120 "76071" 121 "76075" 122 "7608X"
                       123 "7611X" 124 "7612X" 125 "7617X" 126 "7618X"
                       127 "7621X" 128 "7624X" 129 "7625X" 130 "7626X"
                       131 "7631X" 132 "7632X" 133 "7634X" 134 "7635X"
                       135 "7637X" 136 "7638X" 137 "76408" 138 "7642X"
                       139 "7650X" 140 "7651X" 141 "7660X" 142 "7661X"
                       143 "7662X" 144 "766XX" 145 "7671X" 146 "7672X"
                       147 "7673X" 148 "7675X" 149 "7678X" 150 "7679X"
                       151 "7683X" 152 "7684X" 153 "7685X" 154 "7686X"
                       155 "769XX" 156 "7700X" 157 "7701X" 158 "7702X"
                       159 "7703X" 160 "7704X" 161 "7705X" 162 "7706X"
                       163 "7707X" 164 "7708X" 165 "7714X" 166 "7716X"
                       167 "7717X" 168 "7718X" 169 "7721X" 170 "7722X"
                       171 "7724X" 172 "7726X" 173 "7731X" 174 "7732X"
                       175 "7742X" 176 "7746X" 177 "7747X" 178 "7750X"
                       179 "7755X" 180 "7756X" 181 "7757X" 182 "7758X"
                       183 "7759X" 184 "7761X" 185 "7764X" 186 "7765X"
                       187 "7766X" 188 "7767X" 189 "7771X" 190 "7774X"
                       191 "7775X" 192 "7776X" 193 "7778X" 194 "7783X"
                       195 "7784X" 196 "7786X" 197 "7788X" 198 "7790X"
                       199 "7793X" 200 "7795X" 201 "7796X" 202 "7798X"
                       203 "7852X" 204 "7919X" 205 "7923X" 206 "7931X"
                       207 "7948X" 208 "7958X" 209 "7961X" 210 "7963X"
                       211 "9396X" 212 "9961X" 213 "E8798" 214 "E9209"
                       215 "P0331" 216 "P2301" 217 "P2309" 218 "P3404"
                       219 "P3891" 220 "P3892" 221 "P3893" 222 "P5310"
                       223 "P5711" 224 "P640X" 225 "P8626" 226 "P8703"
                       227 "P8733" 228 "P8871" 229 "P8872" 230 "P8874"
                       231 "P8876" 232 "P8954" 233 "P8965" 234 "P9204"
                       235 "P9390" 236 "P9396" 237 "P9406" 238 "P9547"
                       239 "P9603" 240 "P9604" 241 "P9605" 242 "P960X"
                       243 "P9671" 244 "P9672" 245 "P9904" 246 "P9905"
                       247 "P9921" 248 "P9929" 249 "P9954" 250 "P9955"
                       251 "P9959" 252 "P9983" 253 "S7718" 254 "V016X"
                       255 "V017X" 256 "V018X" 257 "V025X" 258 "V058X"
                       259 "V200X" 260 "V290X" 261 "V3000" 262 "V3001"
                       263 "V300X" 264 "V301X" 265 "V3100" 266 "V3101"
                       267 "V3106" 268 "V604X" 269 "V650X" 270 "V718X"
                       271 "V7620" ;
label define I6WTGM    -9 "LEGITIMATE SKIP" -8 "MISSING"
                       -1 "NO ABSTRACT DATA" ;
label define I6WTLB    -9 "LEGITIMATE SKIP" -8 "MISSING"
                       -1 "NO ABSTRACT DATA" ;
label define I6WTOZ    -9 "LEGITIMATE SKIP" -8 "MISSING"
                       -1 "NO ABSTRACT DATA" ;
label define LONGIN    -8.0 "MISSING" -5.0 "DATA OUT OF RANGE"
                       -1.0 "NO ABSTRACT DATA" ;
label define LONGCM    -8.0 "MISSING" -5.0 "DATA OUT OF RANGE"
                       -1.0 "NO ABSTRACT DATA" ;
label define HEADIN    -8.0 "MISSING" -5.0 "DATA OUT OF RANGE"
                       -1.0 "NO ABSTRACT DATA" ;
label define HEADCM    -8.0 "MISSING" -5.0 "DATA OUT OF RANGE"
                       -1.0 "NO ABSTRACT DATA" ;
label define I9BIRTH   -8 "MISSING" -1 "NO ABSTRACT DATA" 1 "SINGLETON"
                       2 "TWINS" 3 "TRIPLETS OR MORE" ;
label define I10RESUS  -8 "MISSING" -1 "NO ABSTRACT DATA" 1 "NONE"
                       2 "ASPIRATION WITH BULB SYRINGE OR CATHETER"
                       3 "NO.2 PLUS OXYGEN" 4 "NO.2 + IPPV W/MASK & BAG"
                       5 "NO.2 & 3 + IPPV W/ENDOTRACHAEL TUBE" 8 "OTHER" ;
label define I11DIS    -8 "MISSING" -5 "DATA OUT OF RANGE"
                       -1 "NO ABSTRACT DATA" ;
label define I12STAT   -8 "MISSING" -1 "NO ABSTRACT DATA"
                       1 "WITH MOTHER/FATHER"
                       2 "RELATIVE OTHER THAN MOTHER/FATHER/ADOPTIVE PARENT"
                       3 "FOSTER CARE OR CHILDREN'S WELFARE SVCS/PROT. SVCS"
                       4 "TRANSFERRED TO ANOTHER HOSPITAL" 5 "DECEASED"
                       8 "OTHER" ;
label define I13NORM   -8 "MISSING" -1 "NO ABSTRACT DATA" 1 "YES" 2 "NO" ;
label define I14SPEC   -8 "MISSING" -1 "NO ABSTRACT DATA" 1 "YES" 2 "NO" ;
label define I15NICU   -8 "MISSING" -1 "NO ABSTRACT DATA" 1 "YES" 2 "NO" ;
label define I16ASTR   -8 "MISSING" -1 "NO ABSTRACT DATA" 1 "YES" 2 "NO" ;
label define I16BMTR   -8 "MISSING" -1 "NO ABSTRACT DATA" 1 "YES" 2 "NO" ;
label define I16CNUR   -8 "MISSING" -1 "NO ABSTRACT DATA" 1 "YES" 2 "NO" ;
label define I16DCRY   -8 "MISSING" -1 "NO ABSTRACT DATA" 1 "YES" 2 "NO" ;
label define I16ESWT   -8 "MISSING" -1 "NO ABSTRACT DATA" 1 "YES" 2 "NO" ;
label define I16FHYP   -8 "MISSING" -1 "NO ABSTRACT DATA" 1 "YES" 2 "NO" ;
label define I16GIRR   -8 "MISSING" -1 "NO ABSTRACT DATA" 1 "YES" 2 "NO" ;
label define I16HDRG   -8 "MISSING" -1 "NO ABSTRACT DATA" 1 "YES" 2 "NO"
                       9 "NO MENTION OR UNKNOWN" ;
label define I17EVID   -8 "MISSING" -1 "NO ABSTRACT DATA" 1 "YES" 2 "NO" ;
label define I18A      -9 "LEGITIMATE SKIP" -8 "MISSING"
                       -1 "NO ABSTRACT DATA" ;
label define I18ARSLT  -9 "LEGITIMATE SKIP" -8 "MISSING"
                       -1 "NO ABSTRACT DATA" 1 "CONFIRMED POSITIVE"
                       2 "NEGATIVE" ;
label define I18B      -9 "LEGITIMATE SKIP" -8 "MISSING"
                       -1 "NO ABSTRACT DATA" ;
label define I18BRSLT  -9 "LEGITIMATE SKIP" -8 "MISSING"
                       -1 "NO ABSTRACT DATA" 1 "CONFIRMED POSITIVE"
                       2 "NEGATIVE" ;
label define I18C      -9 "LEGITIMATE SKIP" -8 "MISSING"
                       -1 "NO ABSTRACT DATA" ;
label define I18CRSLT  -9 "LEGITIMATE SKIP" -8 "MISSING"
                       -1 "NO ABSTRACT DATA" 1 "CONFIRMED POSITIVE"
                       2 "NEGATIVE" ;
label define I18D      -9 "LEGITIMATE SKIP" -8 "MISSING"
                       -1 "NO ABSTRACT DATA" ;
label define I18DRSLT  -9 "LEGITIMATE SKIP" -8 "MISSING"
                       -1 "NO ABSTRACT DATA" 1 "CONFIRMED POSITIVE"
                       2 "NEGATIVE" ;
label define I18E      -9 "LEGITIMATE SKIP" -8 "MISSING"
                       -1 "NO ABSTRACT DATA" ;
label define I18ERSLT  -9 "LEGITIMATE SKIP" -8 "MISSING"
                       -1 "NO ABSTRACT DATA" 1 "CONFIRMED POSITIVE"
                       2 "NEGATIVE" ;
label define ICMNTS    -8 "MISSING" -1 "NO ABSTRACT DATA"
                       1 "YES, THERE ARE COMMENTS"
                       2 "NO, THERE AREN'T ANY COMMENTS" ;
label define I5CNTR    -8 "MISSING" -1 "NO ABSTRACT DATA" ;
label define IBIRTHWT  -8 "MISSING" -1 "NO ABSTRACT DATA"
                       1 "NORMAL (>= 2500 GRAMS)"
                       2 "INTERMEDIATE LBW(>= 1500 & < 2500 GRAMS)"
                       3 "VERY LBW (< 1500 GRAMS)" ;
label define IBWGRAMS  -8 "MISSING" -1 "NO ABSTRACT DATA" ;


#delimit cr


/***************************************************************************

 Section 4: Missing Values

 This section will replace numeric missing values (i.e., -9) with generic
 system missing ".".  By default the code in this section is commented out.
 Users wishing to apply the generic missing values should remove the comment
 at the beginning and end of this section.  Note that Stata allows you to
 specify up to 27 unique missing value codes.

****************************************************************/

/*
replace Q2_LB = . if (Q2_LB <= -1 )
replace Q2_OZ = . if (Q2_OZ <= -1 )
replace Q2_GR = . if (Q2_GR <= -1 )
replace Q3_WK = . if (Q3_WK <= -1 )
replace A_1 = . if (A_1 <= -1 )
replace XA_1A = . if (XA_1A <= -1 )
replace A_1B = . if (A_1B <= -1 )
replace A_1C = . if (A_1C <= -1 )
replace A_1D_01 = . if (A_1D_01 <= -1 )
replace A_1D_02 = . if (A_1D_02 <= -1 )
replace A_1D_03 = . if (A_1D_03 <= -1 )
replace A_1D_04 = . if (A_1D_04 <= -1 )
replace A_1D_05 = . if (A_1D_05 <= -1 )
replace A_1D_06 = . if (A_1D_06 <= -1 )
replace A_1D_07 = . if (A_1D_07 <= -1 )
replace A_1D_08 = . if (A_1D_08 <= -1 )
replace XA_2 = . if (XA_2 >= -999 & XA_2 <= -444)
replace XA_3 = . if (XA_3 <= -1 )
replace A_4 = . if (A_4 <= -1 )
replace A4_A_1 = . if (A4_A_1 <= -1 )
replace A4_A_2 = . if (A4_A_2 <= -1 )
replace A_5 = . if (A_5 <= -1 )
replace A_6 = . if (A_6 <= -1 )
replace A_6A = . if (A_6A <= -1 )
replace A_7_01 = . if (A_7_01 <= -1 )
replace A_7_02 = . if (A_7_02 <= -1 )
replace A_7_03 = . if (A_7_03 <= -1 )
replace A_7_04 = . if (A_7_04 <= -1 )
replace A_7_05 = . if (A_7_05 <= -1 )
replace A_7_06 = . if (A_7_06 <= -1 )
replace A_7_07 = . if (A_7_07 <= -1 )
replace A_7_08 = . if (A_7_08 <= -1 )
replace A_7_09 = . if (A_7_09 <= -1 )
replace A_7_10 = . if (A_7_10 <= -1 )
replace A_7_11 = . if (A_7_11 <= -1 )
replace A_7_12 = . if (A_7_12 <= -1 )
replace A_7_SP = . if (A_7_SP <= -1 )
replace A_8_1 = . if (A_8_1 <= -1 )
replace A_8A_1 = . if (A_8A_1 <= -1 )
replace A_8_2 = . if (A_8_2 <= -1 )
replace A_8A_2 = . if (A_8A_2 <= -1 )
replace A_8_3 = . if (A_8_3 <= -1 )
replace A_8A_3 = . if (A_8A_3 <= -1 )
replace A_8_4 = . if (A_8_4 <= -1 )
replace A_8A_4 = . if (A_8A_4 <= -1 )
replace A_8_5 = . if (A_8_5 <= -1 )
replace A_8A_5 = . if (A_8A_5 <= -1 )
replace A_8_6 = . if (A_8_6 <= -1 )
replace A_8A_6 = . if (A_8A_6 <= -1 )
replace A_8_SP = . if (A_8_SP <= -1 )
replace A_9 = . if (A_9 <= -1 )
replace A_9_SP = . if (A_9_SP <= -1 )
replace A_10 = . if (A_10 <= -1 )
replace A_10_A = . if (A_10_A <= -1 )
replace A_11 = . if (A_11 <= -1 )
replace A_12 = . if (A_12 <= -1 )
replace A_13_FT = . if (A_13_FT <= -1 )
replace A_13_IN = . if (A_13_IN <= -1 )
replace A_14 = . if (A_14 <= -1 )
replace A_14_A = . if (A_14_A <= -1 )
replace A_14_C = . if (A_14_C <= -1 )
replace A_15_A = . if (A_15_A <= -1 )
replace A_15_B = . if (A_15_B <= -1 )
replace A_15_C = . if (A_15_C <= -1 )
replace A_15_D = . if (A_15_D <= -1 )
replace A17A1_LB = . if (A17A1_LB <= -1 )
replace A17A1_OZ = . if (A17A1_OZ <= -1 )
replace XA17A1 = . if (XA17A1 <= -1 )
replace A17A1_MF = . if (A17A1_MF <= -1 )
replace A17A1_YN = . if (A17A1_YN <= -1 )
replace A17A2_LB = . if (A17A2_LB <= -1 )
replace A17A2_OZ = . if (A17A2_OZ <= -1 )
replace XA17A2 = . if (XA17A2 <= -1 )
replace A17A2_MF = . if (A17A2_MF <= -1 )
replace A17A2_YN = . if (A17A2_YN <= -1 )
replace A17A3_LB = . if (A17A3_LB <= -1 )
replace A17A3_OZ = . if (A17A3_OZ <= -1 )
replace XA17A3 = . if (XA17A3 <= -1 )
replace A17A3_MF = . if (A17A3_MF <= -1 )
replace A17A3_YN = . if (A17A3_YN <= -1 )
replace A17A4_LB = . if (A17A4_LB <= -1 )
replace A17A4_OZ = . if (A17A4_OZ <= -1 )
replace XA17A4 = . if (XA17A4 <= -1 )
replace A17A4_MF = . if (A17A4_MF <= -1 )
replace A17A4_YN = . if (A17A4_YN <= -1 )
replace A17A5_LB = . if (A17A5_LB <= -1 )
replace A17A5_OZ = . if (A17A5_OZ <= -1 )
replace XA17A5 = . if (XA17A5 <= -1 )
replace A17A5_MF = . if (A17A5_MF <= -1 )
replace A17A5_YN = . if (A17A5_YN <= -1 )
replace A17A6_LB = . if (A17A6_LB <= -1 )
replace A17A6_OZ = . if (A17A6_OZ <= -1 )
replace XA17A6 = . if (XA17A6 <= -1 )
replace A17A6_MF = . if (A17A6_MF <= -1 )
replace A17A6_YN = . if (A17A6_YN <= -1 )
replace A17A7_LB = . if (A17A7_LB <= -1 )
replace A17A7_OZ = . if (A17A7_OZ <= -1 )
replace XA17A7 = . if (XA17A7 <= -1 )
replace A17A7_MF = . if (A17A7_MF <= -1 )
replace A17A7_YN = . if (A17A7_YN <= -1 )
replace A17A8_LB = . if (A17A8_LB <= -1 )
replace A17A8_OZ = . if (A17A8_OZ <= -1 )
replace XA17A8 = . if (XA17A8 <= -1 )
replace A17A8_MF = . if (A17A8_MF <= -1 )
replace A17A8_YN = . if (A17A8_YN <= -1 )
replace A17A9_LB = . if (A17A9_LB <= -1 )
replace A17A9_OZ = . if (A17A9_OZ <= -1 )
replace XA17A9 = . if (XA17A9 <= -1 )
replace A17A9_MF = . if (A17A9_MF <= -1 )
replace A17A9_YN = . if (A17A9_YN <= -1 )
replace XAGECALC = . if (XAGECALC <= -1 )
replace B_2 = . if (B_2 <= -1 )
replace B_3 = . if (B_3 <= -1 )
replace B_4 = . if (B_4 <= -1 )
replace B_5 = . if (B_5 <= -1 )
replace B_6 = . if (B_6 <= -1 )
replace B_7 = . if (B_7 <= -1 )
replace C_1 = . if (C_1 <= -1 )
replace C_2 = . if (C_2 <= -1 )
replace C_3 = . if (C_3 <= -1 )
replace C_4 = . if (C_4 <= -1 )
replace C_5 = . if (C_5 <= -1 )
replace C_6 = . if (C_6 <= -1 )
replace C_7 = . if (C_7 <= -1 )
replace C_8 = . if (C_8 <= -1 )
replace C_9 = . if (C_9 <= -1 )
replace C_10 = . if (C_10 <= -1 )
replace C_11 = . if (C_11 <= -1 )
replace C_12 = . if (C_12 <= -1 )
replace C_13 = . if (C_13 <= -1 )
replace C_14 = . if (C_14 <= -1 )
replace C_15 = . if (C_15 <= -1 )
replace C_16 = . if (C_16 <= -1 )
replace C_17 = . if (C_17 <= -1 )
replace C_18 = . if (C_18 <= -1 )
replace C_19 = . if (C_19 <= -1 )
replace C_20 = . if (C_20 <= -1 )
replace C_21 = . if (C_21 <= -1 )
replace C_22 = . if (C_22 <= -1 )
replace C_23 = . if (C_23 <= -1 )
replace C_24 = . if (C_24 <= -1 )
replace C_25 = . if (C_25 <= -1 )
replace C_26 = . if (C_26 <= -1 )
replace C_27 = . if (C_27 <= -1 )
replace C_28 = . if (C_28 <= -1 )
replace C_29_01 = . if (C_29_01 <= -1 )
replace C_29_02 = . if (C_29_02 <= -1 )
replace C_29_03 = . if (C_29_03 <= -1 )
replace C_29_04 = . if (C_29_04 <= -1 )
replace C_29_05 = . if (C_29_05 <= -1 )
replace C_29_91 = . if (C_29_91 <= -1 )
replace C_30 = . if (C_30 <= -1 )
replace C_31 = . if (C_31 <= -1 )
replace C_32 = . if (C_32 <= -1 )
replace C_33 = . if (C_33 <= -1 )
replace C_34 = . if (C_34 <= -1 )
replace C_35 = . if (C_35 <= -1 )
replace D_1_01 = . if (D_1_01 <= -1 )
replace D_1_02 = . if (D_1_02 <= -1 )
replace D_1_03 = . if (D_1_03 <= -1 )
replace D_1_04 = . if (D_1_04 <= -1 )
replace D_1_05 = . if (D_1_05 <= -1 )
replace D_1_06 = . if (D_1_06 <= -1 )
replace D_1_07 = . if (D_1_07 <= -1 )
replace D_1_08 = . if (D_1_08 <= -1 )
replace D_1_09 = . if (D_1_09 <= -1 )
replace D_1_10 = . if (D_1_10 <= -1 )
replace D_1_11 = . if (D_1_11 <= -1 )
replace D_1_12 = . if (D_1_12 <= -1 )
replace D_1_13 = . if (D_1_13 <= -1 )
replace D_1_14 = . if (D_1_14 <= -1 )
replace D_1_15 = . if (D_1_15 <= -1 )
replace D_1_16 = . if (D_1_16 <= -1 )
replace D_1_91 = . if (D_1_91 <= -1 )
replace D_2 = . if (D_2 <= -1 )
replace D_3 = . if (D_3 <= -1 )
replace D_4 = . if (D_4 <= -1 )
replace D_5_A = . if (D_5_A <= -1 )
replace D_5_B = . if (D_5_B <= -1 )
replace D_5_C = . if (D_5_C <= -1 )
replace D_5_D = . if (D_5_D <= -1 )
replace D_5_E = . if (D_5_E <= -1 )
replace E_1 = . if (E_1 <= -1 )
replace E_2 = . if (E_2 <= -1 )
replace E_3 = . if (E_3 <= -1 )
replace E_4 = . if (E_4 <= -1 )
replace F_1_A = . if (F_1_A <= -1 )
replace F_1_B = . if (F_1_B <= -1 )
replace F_2_A = . if (F_2_A <= -1 )
replace F_2_B = . if (F_2_B <= -1 )
replace F_3_A = . if (F_3_A <= -1 )
replace F_3_B = . if (F_3_B <= -1 )
replace F_4_A = . if (F_4_A <= -1 )
replace F_4_B = . if (F_4_B <= -1 )
replace F_5_A = . if (F_5_A <= -1 )
replace F_5_B = . if (F_5_B <= -1 )
replace F_6_A = . if (F_6_A <= -1 )
replace F_6_B = . if (F_6_B <= -1 )
replace F_7_A = . if (F_7_A <= -1 )
replace F_7_B = . if (F_7_B <= -1 )
replace F_8_A = . if (F_8_A <= -1 )
replace F_8_B = . if (F_8_B <= -1 )
replace F_8_A_A = . if (F_8_A_A <= -1 )
replace F_8_A_B = . if (F_8_A_B <= -1 )
replace F_9 = . if (F_9 <= -1 )
replace F_10 = . if (F_10 <= -1 )
replace G_1 = . if (G_1 <= -1 )
replace G_2_INCO = . if (G_2_INCO <= -1 )
replace G_3_1 = . if (G_3_1 <= -1 )
replace G_3_2 = . if (G_3_2 <= -1 )
replace G_3_4 = . if (G_3_4 <= -1 )
replace G_3_5 = . if (G_3_5 <= -1 )
replace G_3_6 = . if (G_3_6 <= -1 )
replace G_3_7 = . if (G_3_7 <= -1 )
replace G_3_8 = . if (G_3_8 <= -1 )
replace G_3_9 = . if (G_3_9 <= -1 )
replace G_3_10 = . if (G_3_10 <= -1 )
replace G_3_11 = . if (G_3_11 <= -1 )
replace G_3_SP = . if (G_3_SP <= -1 )
replace H_1 = . if (H_1 <= -1 )
replace H_2 = . if (H_2 <= -1 )
replace H_3 = . if (H_3 <= -1 )
replace H_4_1 = . if (H_4_1 <= -1 )
replace H_4_2 = . if (H_4_2 <= -1 )
replace H_4_3 = . if (H_4_3 <= -1 )
replace H_4_4 = . if (H_4_4 <= -1 )
replace H_5_A = . if (H_5_A <= -1 )
replace H_5_B = . if (H_5_B <= -1 )
replace H_5_C = . if (H_5_C <= -1 )
replace H_6 = . if (H_6 <= -1 )
replace H_6_SP = . if (H_6_SP <= -1 )
replace MCOMPMN = . if (MCOMPMN <= -1 )
replace XMOMAGE = . if (XMOMAGE <= -1 )
replace M2RACE = . if (M2RACE <= -1 )
replace M2_OTH = . if (M2_OTH <= -1 )
replace XM3ADM = . if (XM3ADM <= -1 )
replace M4PAY = . if (M4PAY <= -1 )
replace M5_01A = . if (M5_01A <= -1 )
replace M5_02A = . if (M5_02A <= -1 )
replace M5_03A = . if (M5_03A <= -1 )
replace M5_04A = . if (M5_04A <= -1 )
replace M5_05A = . if (M5_05A <= -1 )
replace M5_06A = . if (M5_06A <= -1 )
replace M5_07A = . if (M5_07A <= -1 )
replace M5_08A = . if (M5_08A <= -1 )
replace M5_09A = . if (M5_09A <= -1 )
replace M5_10A = . if (M5_10A <= -1 )
replace XM6DIS = . if (XM6DIS <= -1 )
replace M7DISPO = . if (M7DISPO <= -1 )
replace M8REFER = . if (M8REFER <= -1 )
replace M8_OTH = . if (M8_OTH <= -1 )
replace M9LABOR = . if (M9LABOR <= -1 )
replace M10DEL = . if (M10DEL <= -1 )
replace M11ANEM = . if (M11ANEM <= -1 )
replace M12GES = . if (M12GES <= -1 )
replace M13DIA = . if (M13DIA <= -1 )
replace M14HRT = . if (M14HRT <= -1 )
replace M15HIV = . if (M15HIV <= -1 )
replace M16HYP = . if (M16HYP <= -1 )
replace M17SKL = . if (M17SKL <= -1 )
replace M18STD = . if (M18STD <= -1 )
replace M19ACAF = . if (M19ACAF <= -1 )
replace M19BTOB = . if (M19BTOB <= -1 )
replace M19CMAR = . if (M19CMAR <= -1 )
replace M19DALC = . if (M19DALC <= -1 )
replace M19EAMP = . if (M19EAMP <= -1 )
replace M19FHER = . if (M19FHER <= -1 )
replace M19GOPI = . if (M19GOPI <= -1 )
replace M19HMET = . if (M19HMET <= -1 )
replace M19ICRK = . if (M19ICRK <= -1 )
replace M19JCOC = . if (M19JCOC <= -1 )
replace M19KPCP = . if (M19KPCP <= -1 )
replace M20EVID = . if (M20EVID <= -1 )
replace M21ARSLT = . if (M21ARSLT <= -1 )
replace M21BRSLT = . if (M21BRSLT <= -1 )
replace M21CRSLT = . if (M21CRSLT <= -1 )
replace M21DRSLT = . if (M21DRSLT <= -1 )
replace M21ERSLT = . if (M21ERSLT <= -1 )
replace MBOXA_A1 = . if (MBOXA_A1 <= -1 )
replace MBOXA_A2 = . if (MBOXA_A2 <= -1 )
replace MSPECPRO = . if (MSPECPRO <= -1 )
replace M5CNTR = . if (M5CNTR <= -1 )
replace A_EDUC = . if (A_EDUC <= -1 )
replace AGE = . if (AGE <= -1 )
replace AGE_YR = . if (AGE_YR <= -1 )
replace ALC_AMT = . if (ALC_AMT <= -1 )
replace ALC_AMT3 = . if (ALC_AMT3 <= -1 )
replace ALC_CAT = . if (ALC_CAT <= -1 )
replace ALC_DAY = . if (ALC_DAY <= -1 )
replace ALCFLAG = . if (ALCFLAG <= -1 )
replace ALCMON = . if (ALCMON <= -1 )
replace ALCPREG = . if (ALCPREG <= -1 )
replace ALCYR = . if (ALCYR <= -1 )
replace ANYBWG = . if (ANYBWG <= -1 )
replace ANYBWT = . if (ANYBWT <= -1 )
replace ANYCARE = . if (ANYCARE <= -1 )
replace ANYFLAG = . if (ANYFLAG <= -1 )
replace ANYMON = . if (ANYMON <= -1 )
replace ANYPREG = . if (ANYPREG <= -1 )
replace ANYYR = . if (ANYYR <= -1 )
replace AV_ETHAN = . if (AV_ETHAN <= -1 )
replace BIRTHWT = . if (BIRTHWT <= -1 )
replace BW_GEST = . if (BW_GEST <= -1 )
replace BWGRAMS = . if (BWGRAMS <= -1 )
replace CIG_AMT = . if (CIG_AMT <= -1 )
replace CIGFLAG = . if (CIGFLAG <= -1 )
replace CIGMON = . if (CIGMON <= -1 )
replace CIGPREG = . if (CIGPREG <= -1 )
replace CIGYR = . if (CIGYR <= -1 )
replace COCFLAG = . if (COCFLAG <= -1 )
replace COCMON = . if (COCMON <= -1 )
replace COCPREG = . if (COCPREG <= -1 )
replace COCYR = . if (COCYR <= -1 )
replace COO_FRQ = . if (COO_FRQ <= -1 )
replace COOFLAG = . if (COOFLAG <= -1 )
replace COOMON = . if (COOMON <= -1 )
replace COOPREG = . if (COOPREG <= -1 )
replace COOYR = . if (COOYR <= -1 )
replace CONTRA = . if (CONTRA <= -1 )
replace CRK_FRQ = . if (CRK_FRQ <= -1 )
replace CRKFLAG = . if (CRKFLAG <= -1 )
replace CRKMON = . if (CRKMON <= -1 )
replace CRKPREG = . if (CRKPREG <= -1 )
replace CRKYR = . if (CRKYR <= -1 )
replace G3_GOVT = . if (G3_GOVT <= -1 )
replace G3_NONE = . if (G3_NONE <= -1 )
replace G3_OTH = . if (G3_OTH <= -1 )
replace GESTAGE = . if (GESTAGE <= -1 )
replace HERFLAG = . if (HERFLAG <= -1 )
replace HERMON = . if (HERMON <= -1 )
replace HERPREG = . if (HERPREG <= -1 )
replace HERYR = . if (HERYR <= -1 )
replace HH_INC = . if (HH_INC <= -1 )
replace HH_SIZ18 = . if (HH_SIZ18 <= -1 )
replace HH_SIZE = . if (HH_SIZE <= -1 )
replace HRDPRG = . if (HRDPRG <= -1 )
replace M_ANEMIA = . if (M_ANEMIA <= -1 )
replace M_DRUG = . if (M_DRUG <= -1 )
replace M_FDIS = . if (M_FDIS <= -1 )
replace M_GUI = . if (M_GUI <= -1 )
replace M_HYPER = . if (M_HYPER <= -1 )
replace M_IPC = . if (M_IPC <= -1 )
replace M_MENTAL = . if (M_MENTAL <= -1 )
replace M_RUPT = . if (M_RUPT <= -1 )
replace M_VD = . if (M_VD <= -1 )
replace MARITAL = . if (MARITAL <= -1 )
replace MET_PAY = . if (MET_PAY <= -1 )
replace MED_USE = . if (MED_USE <= -1 )
replace MRJ_FRQ = . if (MRJ_FRQ <= -1 )
replace MRJFLAG = . if (MRJFLAG <= -1 )
replace MRJMON = . if (MRJMON <= -1 )
replace MRJPREG = . if (MRJPREG <= -1 )
replace MRJYR = . if (MRJYR <= -1 )
replace NOMJFLAG = . if (NOMJFLAG <= -1 )
replace NOMJMON = . if (NOMJMON <= -1 )
replace NOMJPREG = . if (NOMJPREG <= -1 )
replace NOMJYR = . if (NOMJYR <= -1 )
replace PARITY = . if (PARITY <= -1 )
replace PDRINK = . if (PDRINK <= -1 )
replace PN_CARE = . if (PN_CARE <= -1 )
replace PN_NUM = . if (PN_NUM <= -1 )
replace PN_TRI = . if (PN_TRI <= -1 )
replace PN_WK = . if (PN_WK <= -1 )
replace PR_USE3 = . if (PR_USE3 <= -1 )
replace PR_USE8 = . if (PR_USE8 <= -1 )
replace PSYFLAG = . if (PSYFLAG <= -1 )
replace PSYMON = . if (PSYMON <= -1 )
replace PSYPREG = . if (PSYPREG <= -1 )
replace PSYYR = . if (PSYYR <= -1 )
replace R1BIRT = . if (R1BIRT <= -1 )
replace R2BIRT = . if (R2BIRT <= -1 )
replace R3BIRT = . if (R3BIRT <= -1 )
replace RACE = . if (RACE <= -1 )
replace RESIDE = . if (RESIDE <= -1 )
replace RISKLEV2 = . if (RISKLEV2 <= -1 )
replace STAFLAG = . if (STAFLAG <= -1 )
replace STAMON = . if (STAMON <= -1 )
replace STAPREG = . if (STAPREG <= -1 )
replace STAYR = . if (STAYR <= -1 )
replace STATUS = . if (STATUS <= -1 )
replace STMFLAG = . if (STMFLAG <= -1 )
replace STMMON = . if (STMMON <= -1 )
replace STMPREG = . if (STMPREG <= -1 )
replace STMYR = . if (STMYR <= -1 )
replace TWINS = . if (TWINS <= -1 )
replace XAGE = . if (XAGE <= -1 )
replace I_COC = . if (I_COC <= -1 )
replace I_DRUG = . if (I_DRUG <= -1 )
replace I_INF = . if (I_INF <= -1 )
replace I_JAUND = . if (I_JAUND <= -1 )
replace I_RDS = . if (I_RDS <= -1 )
replace I_RESP = . if (I_RESP <= -1 )
replace I_VENT = . if (I_VENT <= -1 )
replace IBCOMPMN = . if (IBCOMPMN <= -1 )
replace IINFNUM = . if (IINFNUM <= -1 )
replace ITOTNUM = . if (ITOTNUM <= -1 )
replace IB2RACE = . if (IB2RACE <= -1 )
replace IB2_OTH = . if (IB2_OTH <= -1 )
replace I3GEN = . if (I3GEN <= -1 )
replace I4_1MN = . if (I4_1MN <= -1 )
replace I4_5MN = . if (I4_5MN <= -1 )
replace IB5_01A = . if (IB5_01A <= -1 )
replace IB5_02A = . if (IB5_02A <= -1 )
replace IB5_03A = . if (IB5_03A <= -1 )
replace IB5_04A = . if (IB5_04A <= -1 )
replace IB5_05A = . if (IB5_05A <= -1 )
replace IB5_06A = . if (IB5_06A <= -1 )
replace IB5_07A = . if (IB5_07A <= -1 )
replace IB5_08A = . if (IB5_08A <= -1 )
replace IB5_09A = . if (IB5_09A <= -1 )
replace IB5_10A = . if (IB5_10A <= -1 )
replace I6WTGM = . if (I6WTGM <= -1 )
replace I6WTLB = . if (I6WTLB <= -1 )
replace I6WTOZ = . if (I6WTOZ <= -1 )
replace LONGIN = . if (LONGIN <= -1.0 )
replace LONGCM = . if (LONGCM <= -1.0 )
replace HEADIN = . if (HEADIN <= -1.0 )
replace HEADCM = . if (HEADCM <= -1.0 )
replace I9BIRTH = . if (I9BIRTH <= -1 )
replace I10RESUS = . if (I10RESUS <= -1 )
replace I11DIS = . if (I11DIS <= -1 )
replace I12STAT = . if (I12STAT <= -1 )
replace I13NORM = . if (I13NORM <= -1 )
replace I14SPEC = . if (I14SPEC <= -1 )
replace I15NICU = . if (I15NICU <= -1 )
replace I16ASTR = . if (I16ASTR <= -1 )
replace I16BMTR = . if (I16BMTR <= -1 )
replace I16CNUR = . if (I16CNUR <= -1 )
replace I16DCRY = . if (I16DCRY <= -1 )
replace I16ESWT = . if (I16ESWT <= -1 )
replace I16FHYP = . if (I16FHYP <= -1 )
replace I16GIRR = . if (I16GIRR <= -1 )
replace I16HDRG = . if (I16HDRG <= -1 )
replace I17EVID = . if (I17EVID <= -1 )
replace I18A = . if (I18A <= -1 )
replace I18ARSLT = . if (I18ARSLT <= -1 )
replace I18B = . if (I18B <= -1 )
replace I18BRSLT = . if (I18BRSLT <= -1 )
replace I18C = . if (I18C <= -1 )
replace I18CRSLT = . if (I18CRSLT <= -1 )
replace I18D = . if (I18D <= -1 )
replace I18DRSLT = . if (I18DRSLT <= -1 )
replace I18E = . if (I18E <= -1 )
replace I18ERSLT = . if (I18ERSLT <= -1 )
replace ICMNTS = . if (ICMNTS <= -1 )
replace I5CNTR = . if (I5CNTR <= -1 )
replace IBIRTHWT = . if (IBIRTHWT <= -1 )
replace IBWGRAMS = . if (IBWGRAMS <= -1 )


*/
/********************************************************************

 Section 5: Save Outfile

  This section saves out a Stata system format file.  There is no reason to
  modify it if the macros in Section 1 were specified correctly.

*********************************************************************/

save `outfile', replace

